<?php
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'Brook_VC_Icon_FontAwesome5' ) ) {
	class Brook_VC_Icon_FontAwesome5 {

		public function __construct() {
			add_action( 'load-post.php', array( $this, 'enqueue_scripts' ) );
			add_action( 'load-post-new.php', array( $this, 'enqueue_scripts' ) );

			add_filter( 'vc_iconpicker-type-fontawesome5', array( $this, 'add_fonts' ) );
			add_filter( 'brook_vc_icon_libraries', array( $this, 'add_to_libraries' ) );
			add_filter( 'brook_vc_icon_libraries_fields', array( $this, 'add_icon_picker_field' ), 10, 2 );

			add_action( 'vc_enqueue_font_icon_element', array( $this, 'vc_element_enqueue' ) );
		}

		public function add_to_libraries( $list ) {
			$list = $list + array( esc_html__( 'Font Awesome 5 Pro', 'brook' ) => 'fontawesome5' );

			return $list;
		}

		public function add_icon_picker_field( $fields, $args ) {
			$fields[] = array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'brook' ),
				'param_name'  => 'icon_fontawesome5',
				'value'       => 'fa fa-adjust',
				'settings'    => array(
					'emptyIcon'    => true,
					'type'         => 'fontawesome5',
					'iconsPerPage' => 300,
				),
				'dependency'  => array(
					'element' => $args['param_name'],
					'value'   => 'fontawesome5',
				),
				'description' => esc_html__( 'Select icon from library.', 'brook' ),
			);

			return $fields;
		}

		public function vc_element_enqueue( $font ) {
			switch ( $font ) {
				case 'fontawesome5':
					wp_enqueue_style( 'font-awesome' );
					break;
			}
		}

		public function enqueue_scripts() {
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		}

		function admin_enqueue_scripts() {
			wp_enqueue_style( 'font-awesome', BROOK_THEME_URI . '/assets/fonts/awesome/css/fontawesome-all.min.css', null, '5.6.3' );
		}

		public function add_fonts( $icons ) {
			$new_icons = array(
				esc_html__( 'Brands', 'brook' )  => array(
					array( 'fab fa-500px' => '500px' ),
					array( 'fab fa-accessible-icon' => 'accessible icon' ),
					array( 'fab fa-accusoft' => 'accusoft' ),
					array( 'fab fa-acquisitions-incorporated' => 'acquisitions incorporated' ),
					array( 'fab fa-adn' => 'adn' ),
					array( 'fab fa-adobe' => 'adobe' ),
					array( 'fab fa-adversal' => 'adversal' ),
					array( 'fab fa-affiliatetheme' => 'affiliatetheme' ),
					array( 'fab fa-airbnb' => 'airbnb' ),
					array( 'fab fa-algolia' => 'algolia' ),
					array( 'fab fa-alipay' => 'alipay' ),
					array( 'fab fa-amazon-pay' => 'amazon pay' ),
					array( 'fab fa-amazon' => 'amazon' ),
					array( 'fab fa-amilia' => 'amilia' ),
					array( 'fab fa-android' => 'android' ),
					array( 'fab fa-angellist' => 'angellist' ),
					array( 'fab fa-angrycreative' => 'angrycreative' ),
					array( 'fab fa-angular' => 'angular' ),
					array( 'fab fa-app-store-ios' => 'app store ios' ),
					array( 'fab fa-app-store' => 'app store' ),
					array( 'fab fa-apper' => 'apper' ),
					array( 'fab fa-apple-pay' => 'apple pay' ),
					array( 'fab fa-apple' => 'apple' ),
					array( 'fab fa-artstation' => 'artstation' ),
					array( 'fab fa-asymmetrik' => 'asymmetrik' ),
					array( 'fab fa-atlassian' => 'atlassian' ),
					array( 'fab fa-audible' => 'audible' ),
					array( 'fab fa-autoprefixer' => 'autoprefixer' ),
					array( 'fab fa-avianex' => 'avianex' ),
					array( 'fab fa-aviato' => 'aviato' ),
					array( 'fab fa-aws' => 'aws' ),
					array( 'fab fa-bandcamp' => 'bandcamp' ),
					array( 'fab fa-battle-net' => 'battle net' ),
					array( 'fab fa-behance-square' => 'behance square' ),
					array( 'fab fa-behance' => 'behance' ),
					array( 'fab fa-bimobject' => 'bimobject' ),
					array( 'fab fa-bitbucket' => 'bitbucket' ),
					array( 'fab fa-bitcoin' => 'bitcoin' ),
					array( 'fab fa-bity' => 'bity' ),
					array( 'fab fa-black-tie' => 'black tie' ),
					array( 'fab fa-blackberry' => 'blackberry' ),
					array( 'fab fa-blogger-b' => 'blogger b' ),
					array( 'fab fa-blogger' => 'blogger' ),
					array( 'fab fa-bluetooth-b' => 'bluetooth b' ),
					array( 'fab fa-bluetooth' => 'bluetooth' ),
					array( 'fab fa-bootstrap' => 'bootstrap' ),
					array( 'fab fa-btc' => 'btc' ),
					array( 'fab fa-buffer' => 'buffer' ),
					array( 'fab fa-buromobelexperte' => 'buromobelexperte' ),
					array( 'fab fa-buy-n-large' => 'buy n large' ),
					array( 'fab fa-buysellads' => 'buysellads' ),
					array( 'fab fa-canadian-maple-leaf' => 'canadian maple leaf' ),
					array( 'fab fa-cc-amazon-pay' => 'cc amazon pay' ),
					array( 'fab fa-cc-amex' => 'cc amex' ),
					array( 'fab fa-cc-apple-pay' => 'cc apple pay' ),
					array( 'fab fa-cc-diners-club' => 'cc diners club' ),
					array( 'fab fa-cc-discover' => 'cc discover' ),
					array( 'fab fa-cc-jcb' => 'cc jcb' ),
					array( 'fab fa-cc-mastercard' => 'cc mastercard' ),
					array( 'fab fa-cc-paypal' => 'cc paypal' ),
					array( 'fab fa-cc-stripe' => 'cc stripe' ),
					array( 'fab fa-cc-visa' => 'cc visa' ),
					array( 'fab fa-centercode' => 'centercode' ),
					array( 'fab fa-centos' => 'centos' ),
					array( 'fab fa-chrome' => 'chrome' ),
					array( 'fab fa-chromecast' => 'chromecast' ),
					array( 'fab fa-cloudscale' => 'cloudscale' ),
					array( 'fab fa-cloudsmith' => 'cloudsmith' ),
					array( 'fab fa-cloudversify' => 'cloudversify' ),
					array( 'fab fa-codepen' => 'codepen' ),
					array( 'fab fa-codiepie' => 'codiepie' ),
					array( 'fab fa-confluence' => 'confluence' ),
					array( 'fab fa-connectdevelop' => 'connectdevelop' ),
					array( 'fab fa-contao' => 'contao' ),
					array( 'fab fa-cotton-bureau' => 'cotton bureau' ),
					array( 'fab fa-cpanel' => 'cpanel' ),
					array( 'fab fa-creative-commons-by' => 'creative commons by' ),
					array( 'fab fa-creative-commons-nc-eu' => 'creative commons nc eu' ),
					array( 'fab fa-creative-commons-nc-jp' => 'creative commons nc jp' ),
					array( 'fab fa-creative-commons-nc' => 'creative commons nc' ),
					array( 'fab fa-creative-commons-nd' => 'creative commons nd' ),
					array( 'fab fa-creative-commons-pd-alt' => 'creative commons pd alt' ),
					array( 'fab fa-creative-commons-pd' => 'creative commons pd' ),
					array( 'fab fa-creative-commons-remix' => 'creative commons remix' ),
					array( 'fab fa-creative-commons-sa' => 'creative commons sa' ),
					array( 'fab fa-creative-commons-sampling-plus' => 'creative commons sampling plus' ),
					array( 'fab fa-creative-commons-sampling' => 'creative commons sampling' ),
					array( 'fab fa-creative-commons-share' => 'creative commons share' ),
					array( 'fab fa-creative-commons-zero' => 'creative commons zero' ),
					array( 'fab fa-creative-commons' => 'creative commons' ),
					array( 'fab fa-critical-role' => 'critical role' ),
					array( 'fab fa-css3-alt' => 'css3 alt' ),
					array( 'fab fa-css3' => 'css3' ),
					array( 'fab fa-cuttlefish' => 'cuttlefish' ),
					array( 'fab fa-d-and-d-beyond' => 'd and d beyond' ),
					array( 'fab fa-d-and-d' => 'd and d' ),
					array( 'fab fa-dailymotion' => 'dailymotion' ),
					array( 'fab fa-dashcube' => 'dashcube' ),
					array( 'fab fa-deezer' => 'deezer' ),
					array( 'fab fa-delicious' => 'delicious' ),
					array( 'fab fa-deploydog' => 'deploydog' ),
					array( 'fab fa-deskpro' => 'deskpro' ),
					array( 'fab fa-dev' => 'dev' ),
					array( 'fab fa-deviantart' => 'deviantart' ),
					array( 'fab fa-dhl' => 'dhl' ),
					array( 'fab fa-diaspora' => 'diaspora' ),
					array( 'fab fa-digg' => 'digg' ),
					array( 'fab fa-digital-ocean' => 'digital ocean' ),
					array( 'fab fa-discord' => 'discord' ),
					array( 'fab fa-discourse' => 'discourse' ),
					array( 'fab fa-dochub' => 'dochub' ),
					array( 'fab fa-docker' => 'docker' ),
					array( 'fab fa-draft2digital' => 'draft2digital' ),
					array( 'fab fa-dribbble-square' => 'dribbble square' ),
					array( 'fab fa-dribbble' => 'dribbble' ),
					array( 'fab fa-dropbox' => 'dropbox' ),
					array( 'fab fa-drupal' => 'drupal' ),
					array( 'fab fa-dyalog' => 'dyalog' ),
					array( 'fab fa-earlybirds' => 'earlybirds' ),
					array( 'fab fa-ebay' => 'ebay' ),
					array( 'fab fa-edge-legacy' => 'edge legacy' ),
					array( 'fab fa-edge' => 'edge' ),
					array( 'fab fa-elementor' => 'elementor' ),
					array( 'fab fa-ello' => 'ello' ),
					array( 'fab fa-ember' => 'ember' ),
					array( 'fab fa-empire' => 'empire' ),
					array( 'fab fa-envira' => 'envira' ),
					array( 'fab fa-erlang' => 'erlang' ),
					array( 'fab fa-ethereum' => 'ethereum' ),
					array( 'fab fa-etsy' => 'etsy' ),
					array( 'fab fa-evernote' => 'evernote' ),
					array( 'fab fa-expeditedssl' => 'expeditedssl' ),
					array( 'fab fa-facebook-f' => 'facebook f' ),
					array( 'fab fa-facebook-messenger' => 'facebook messenger' ),
					array( 'fab fa-facebook-square' => 'facebook square' ),
					array( 'fab fa-facebook' => 'facebook' ),
					array( 'fab fa-fantasy-flight-games' => 'fantasy flight games' ),
					array( 'fab fa-fedex' => 'fedex' ),
					array( 'fab fa-fedora' => 'fedora' ),
					array( 'fab fa-figma' => 'figma' ),
					array( 'fab fa-firefox-browser' => 'firefox browser' ),
					array( 'fab fa-firefox' => 'firefox' ),
					array( 'fab fa-first-order-alt' => 'first order alt' ),
					array( 'fab fa-first-order' => 'first order' ),
					array( 'fab fa-firstdraft' => 'firstdraft' ),
					array( 'fab fa-flickr' => 'flickr' ),
					array( 'fab fa-flipboard' => 'flipboard' ),
					array( 'fab fa-fly' => 'fly' ),
					array( 'fab fa-font-awesome-alt' => 'font awesome alt' ),
					array( 'fab fa-font-awesome-flag' => 'font awesome flag' ),
					array( 'fab fa-font-awesome-logo-full' => 'font awesome logo full' ),
					array( 'fab fa-font-awesome' => 'font awesome' ),
					array( 'fab fa-fonticons-fi' => 'fonticons fi' ),
					array( 'fab fa-fonticons' => 'fonticons' ),
					array( 'fab fa-fort-awesome-alt' => 'fort awesome alt' ),
					array( 'fab fa-fort-awesome' => 'fort awesome' ),
					array( 'fab fa-forumbee' => 'forumbee' ),
					array( 'fab fa-foursquare' => 'foursquare' ),
					array( 'fab fa-free-code-camp' => 'free code camp' ),
					array( 'fab fa-freebsd' => 'freebsd' ),
					array( 'fab fa-fulcrum' => 'fulcrum' ),
					array( 'fab fa-galactic-republic' => 'galactic republic' ),
					array( 'fab fa-galactic-senate' => 'galactic senate' ),
					array( 'fab fa-get-pocket' => 'get pocket' ),
					array( 'fab fa-gg-circle' => 'gg circle' ),
					array( 'fab fa-gg' => 'gg' ),
					array( 'fab fa-git-alt' => 'git alt' ),
					array( 'fab fa-git-square' => 'git square' ),
					array( 'fab fa-git' => 'git' ),
					array( 'fab fa-github-alt' => 'github alt' ),
					array( 'fab fa-github-square' => 'github square' ),
					array( 'fab fa-github' => 'github' ),
					array( 'fab fa-gitkraken' => 'gitkraken' ),
					array( 'fab fa-gitlab' => 'gitlab' ),
					array( 'fab fa-gitter' => 'gitter' ),
					array( 'fab fa-glide-g' => 'glide g' ),
					array( 'fab fa-glide' => 'glide' ),
					array( 'fab fa-gofore' => 'gofore' ),
					array( 'fab fa-goodreads-g' => 'goodreads g' ),
					array( 'fab fa-goodreads' => 'goodreads' ),
					array( 'fab fa-google-drive' => 'google drive' ),
					array( 'fab fa-google-pay' => 'google pay' ),
					array( 'fab fa-google-play' => 'google play' ),
					array( 'fab fa-google-plus-g' => 'google plus g' ),
					array( 'fab fa-google-plus-square' => 'google plus square' ),
					array( 'fab fa-google-plus' => 'google plus' ),
					array( 'fab fa-google-wallet' => 'google wallet' ),
					array( 'fab fa-google' => 'google' ),
					array( 'fab fa-gratipay' => 'gratipay' ),
					array( 'fab fa-grav' => 'grav' ),
					array( 'fab fa-gripfire' => 'gripfire' ),
					array( 'fab fa-grunt' => 'grunt' ),
					array( 'fab fa-gulp' => 'gulp' ),
					array( 'fab fa-hacker-news-square' => 'hacker news square' ),
					array( 'fab fa-hacker-news' => 'hacker news' ),
					array( 'fab fa-hackerrank' => 'hackerrank' ),
					array( 'fab fa-hips' => 'hips' ),
					array( 'fab fa-hire-a-helper' => 'hire a helper' ),
					array( 'fab fa-hooli' => 'hooli' ),
					array( 'fab fa-hornbill' => 'hornbill' ),
					array( 'fab fa-hotjar' => 'hotjar' ),
					array( 'fab fa-houzz' => 'houzz' ),
					array( 'fab fa-html5' => 'html5' ),
					array( 'fab fa-hubspot' => 'hubspot' ),
					array( 'fab fa-ideal' => 'ideal' ),
					array( 'fab fa-imdb' => 'imdb' ),
					array( 'fab fa-instagram-square' => 'instagram square' ),
					array( 'fab fa-instagram' => 'instagram' ),
					array( 'fab fa-intercom' => 'intercom' ),
					array( 'fab fa-internet-explorer' => 'internet explorer' ),
					array( 'fab fa-invision' => 'invision' ),
					array( 'fab fa-ioxhost' => 'ioxhost' ),
					array( 'fab fa-itch-io' => 'itch io' ),
					array( 'fab fa-itunes-note' => 'itunes note' ),
					array( 'fab fa-itunes' => 'itunes' ),
					array( 'fab fa-java' => 'java' ),
					array( 'fab fa-jedi-order' => 'jedi order' ),
					array( 'fab fa-jenkins' => 'jenkins' ),
					array( 'fab fa-jira' => 'jira' ),
					array( 'fab fa-joget' => 'joget' ),
					array( 'fab fa-joomla' => 'joomla' ),
					array( 'fab fa-js-square' => 'js square' ),
					array( 'fab fa-js' => 'js' ),
					array( 'fab fa-jsfiddle' => 'jsfiddle' ),
					array( 'fab fa-kaggle' => 'kaggle' ),
					array( 'fab fa-keybase' => 'keybase' ),
					array( 'fab fa-keycdn' => 'keycdn' ),
					array( 'fab fa-kickstarter-k' => 'kickstarter k' ),
					array( 'fab fa-kickstarter' => 'kickstarter' ),
					array( 'fab fa-korvue' => 'korvue' ),
					array( 'fab fa-laravel' => 'laravel' ),
					array( 'fab fa-lastfm-square' => 'lastfm square' ),
					array( 'fab fa-lastfm' => 'lastfm' ),
					array( 'fab fa-leanpub' => 'leanpub' ),
					array( 'fab fa-less' => 'less' ),
					array( 'fab fa-line' => 'line' ),
					array( 'fab fa-linkedin-in' => 'linkedin in' ),
					array( 'fab fa-linkedin' => 'linkedin' ),
					array( 'fab fa-linode' => 'linode' ),
					array( 'fab fa-linux' => 'linux' ),
					array( 'fab fa-lyft' => 'lyft' ),
					array( 'fab fa-magento' => 'magento' ),
					array( 'fab fa-mailchimp' => 'mailchimp' ),
					array( 'fab fa-mandalorian' => 'mandalorian' ),
					array( 'fab fa-markdown' => 'markdown' ),
					array( 'fab fa-mastodon' => 'mastodon' ),
					array( 'fab fa-maxcdn' => 'maxcdn' ),
					array( 'fab fa-mdb' => 'mdb' ),
					array( 'fab fa-medapps' => 'medapps' ),
					array( 'fab fa-medium-m' => 'medium m' ),
					array( 'fab fa-medium' => 'medium' ),
					array( 'fab fa-medrt' => 'medrt' ),
					array( 'fab fa-meetup' => 'meetup' ),
					array( 'fab fa-megaport' => 'megaport' ),
					array( 'fab fa-mendeley' => 'mendeley' ),
					array( 'fab fa-microblog' => 'microblog' ),
					array( 'fab fa-microsoft' => 'microsoft' ),
					array( 'fab fa-mix' => 'mix' ),
					array( 'fab fa-mixcloud' => 'mixcloud' ),
					array( 'fab fa-mixer' => 'mixer' ),
					array( 'fab fa-mizuni' => 'mizuni' ),
					array( 'fab fa-modx' => 'modx' ),
					array( 'fab fa-monero' => 'monero' ),
					array( 'fab fa-napster' => 'napster' ),
					array( 'fab fa-neos' => 'neos' ),
					array( 'fab fa-nimblr' => 'nimblr' ),
					array( 'fab fa-node-js' => 'node js' ),
					array( 'fab fa-node' => 'node' ),
					array( 'fab fa-npm' => 'npm' ),
					array( 'fab fa-ns8' => 'ns8' ),
					array( 'fab fa-nutritionix' => 'nutritionix' ),
					array( 'fab fa-odnoklassniki-square' => 'odnoklassniki square' ),
					array( 'fab fa-odnoklassniki' => 'odnoklassniki' ),
					array( 'fab fa-old-republic' => 'old republic' ),
					array( 'fab fa-opencart' => 'opencart' ),
					array( 'fab fa-openid' => 'openid' ),
					array( 'fab fa-opera' => 'opera' ),
					array( 'fab fa-optin-monster' => 'optin monster' ),
					array( 'fab fa-orcid' => 'orcid' ),
					array( 'fab fa-osi' => 'osi' ),
					array( 'fab fa-page4' => 'page4' ),
					array( 'fab fa-pagelines' => 'pagelines' ),
					array( 'fab fa-palfed' => 'palfed' ),
					array( 'fab fa-patreon' => 'patreon' ),
					array( 'fab fa-paypal' => 'paypal' ),
					array( 'fab fa-penny-arcade' => 'penny arcade' ),
					array( 'fab fa-periscope' => 'periscope' ),
					array( 'fab fa-phabricator' => 'phabricator' ),
					array( 'fab fa-phoenix-framework' => 'phoenix framework' ),
					array( 'fab fa-phoenix-squadron' => 'phoenix squadron' ),
					array( 'fab fa-php' => 'php' ),
					array( 'fab fa-pied-piper-alt' => 'pied piper alt' ),
					array( 'fab fa-pied-piper-hat' => 'pied piper hat' ),
					array( 'fab fa-pied-piper-pp' => 'pied piper pp' ),
					array( 'fab fa-pied-piper-square' => 'pied piper square' ),
					array( 'fab fa-pied-piper' => 'pied piper' ),
					array( 'fab fa-pinterest-p' => 'pinterest p' ),
					array( 'fab fa-pinterest-square' => 'pinterest square' ),
					array( 'fab fa-pinterest' => 'pinterest' ),
					array( 'fab fa-playstation' => 'playstation' ),
					array( 'fab fa-product-hunt' => 'product hunt' ),
					array( 'fab fa-pushed' => 'pushed' ),
					array( 'fab fa-python' => 'python' ),
					array( 'fab fa-qq' => 'qq' ),
					array( 'fab fa-quinscape' => 'quinscape' ),
					array( 'fab fa-quora' => 'quora' ),
					array( 'fab fa-r-project' => 'r project' ),
					array( 'fab fa-raspberry-pi' => 'raspberry pi' ),
					array( 'fab fa-ravelry' => 'ravelry' ),
					array( 'fab fa-react' => 'react' ),
					array( 'fab fa-reacteurope' => 'reacteurope' ),
					array( 'fab fa-readme' => 'readme' ),
					array( 'fab fa-rebel' => 'rebel' ),
					array( 'fab fa-red-river' => 'red river' ),
					array( 'fab fa-reddit-alien' => 'reddit alien' ),
					array( 'fab fa-reddit-square' => 'reddit square' ),
					array( 'fab fa-reddit' => 'reddit' ),
					array( 'fab fa-redhat' => 'redhat' ),
					array( 'fab fa-renren' => 'renren' ),
					array( 'fab fa-replyd' => 'replyd' ),
					array( 'fab fa-researchgate' => 'researchgate' ),
					array( 'fab fa-resolving' => 'resolving' ),
					array( 'fab fa-rev' => 'rev' ),
					array( 'fab fa-rocketchat' => 'rocketchat' ),
					array( 'fab fa-rockrms' => 'rockrms' ),
					array( 'fab fa-rust' => 'rust' ),
					array( 'fab fa-safari' => 'safari' ),
					array( 'fab fa-salesforce' => 'salesforce' ),
					array( 'fab fa-sass' => 'sass' ),
					array( 'fab fa-schlix' => 'schlix' ),
					array( 'fab fa-scribd' => 'scribd' ),
					array( 'fab fa-searchengin' => 'searchengin' ),
					array( 'fab fa-sellcast' => 'sellcast' ),
					array( 'fab fa-sellsy' => 'sellsy' ),
					array( 'fab fa-servicestack' => 'servicestack' ),
					array( 'fab fa-shirtsinbulk' => 'shirtsinbulk' ),
					array( 'fab fa-shopify' => 'shopify' ),
					array( 'fab fa-shopware' => 'shopware' ),
					array( 'fab fa-simplybuilt' => 'simplybuilt' ),
					array( 'fab fa-sistrix' => 'sistrix' ),
					array( 'fab fa-sith' => 'sith' ),
					array( 'fab fa-sketch' => 'sketch' ),
					array( 'fab fa-skyatlas' => 'skyatlas' ),
					array( 'fab fa-skype' => 'skype' ),
					array( 'fab fa-slack-hash' => 'slack hash' ),
					array( 'fab fa-slack' => 'slack' ),
					array( 'fab fa-slideshare' => 'slideshare' ),
					array( 'fab fa-snapchat-ghost' => 'snapchat ghost' ),
					array( 'fab fa-snapchat-square' => 'snapchat square' ),
					array( 'fab fa-snapchat' => 'snapchat' ),
					array( 'fab fa-soundcloud' => 'soundcloud' ),
					array( 'fab fa-sourcetree' => 'sourcetree' ),
					array( 'fab fa-speakap' => 'speakap' ),
					array( 'fab fa-speaker-deck' => 'speaker deck' ),
					array( 'fab fa-spotify' => 'spotify' ),
					array( 'fab fa-squarespace' => 'squarespace' ),
					array( 'fab fa-stack-exchange' => 'stack exchange' ),
					array( 'fab fa-stack-overflow' => 'stack overflow' ),
					array( 'fab fa-stackpath' => 'stackpath' ),
					array( 'fab fa-staylinked' => 'staylinked' ),
					array( 'fab fa-steam-square' => 'steam square' ),
					array( 'fab fa-steam-symbol' => 'steam symbol' ),
					array( 'fab fa-steam' => 'steam' ),
					array( 'fab fa-sticker-mule' => 'sticker mule' ),
					array( 'fab fa-strava' => 'strava' ),
					array( 'fab fa-stripe-s' => 'stripe s' ),
					array( 'fab fa-stripe' => 'stripe' ),
					array( 'fab fa-studiovinari' => 'studiovinari' ),
					array( 'fab fa-stumbleupon-circle' => 'stumbleupon circle' ),
					array( 'fab fa-stumbleupon' => 'stumbleupon' ),
					array( 'fab fa-superpowers' => 'superpowers' ),
					array( 'fab fa-supple' => 'supple' ),
					array( 'fab fa-suse' => 'suse' ),
					array( 'fab fa-swift' => 'swift' ),
					array( 'fab fa-symfony' => 'symfony' ),
					array( 'fab fa-teamspeak' => 'teamspeak' ),
					array( 'fab fa-telegram-plane' => 'telegram plane' ),
					array( 'fab fa-telegram' => 'telegram' ),
					array( 'fab fa-tencent-weibo' => 'tencent weibo' ),
					array( 'fab fa-the-red-yeti' => 'the red yeti' ),
					array( 'fab fa-themeco' => 'themeco' ),
					array( 'fab fa-themeisle' => 'themeisle' ),
					array( 'fab fa-think-peaks' => 'think peaks' ),
					array( 'fab fa-tiktok' => 'tiktok' ),
					array( 'fab fa-trade-federation' => 'trade federation' ),
					array( 'fab fa-trello' => 'trello' ),
					array( 'fab fa-tripadvisor' => 'tripadvisor' ),
					array( 'fab fa-tumblr-square' => 'tumblr square' ),
					array( 'fab fa-tumblr' => 'tumblr' ),
					array( 'fab fa-twitch' => 'twitch' ),
					array( 'fab fa-twitter-square' => 'twitter square' ),
					array( 'fab fa-twitter' => 'twitter' ),
					array( 'fab fa-typo3' => 'typo3' ),
					array( 'fab fa-uber' => 'uber' ),
					array( 'fab fa-ubuntu' => 'ubuntu' ),
					array( 'fab fa-uikit' => 'uikit' ),
					array( 'fab fa-umbraco' => 'umbraco' ),
					array( 'fab fa-uniregistry' => 'uniregistry' ),
					array( 'fab fa-unity' => 'unity' ),
					array( 'fab fa-unsplash' => 'unsplash' ),
					array( 'fab fa-untappd' => 'untappd' ),
					array( 'fab fa-ups' => 'ups' ),
					array( 'fab fa-usb' => 'usb' ),
					array( 'fab fa-usps' => 'usps' ),
					array( 'fab fa-ussunnah' => 'ussunnah' ),
					array( 'fab fa-vaadin' => 'vaadin' ),
					array( 'fab fa-viacoin' => 'viacoin' ),
					array( 'fab fa-viadeo-square' => 'viadeo square' ),
					array( 'fab fa-viadeo' => 'viadeo' ),
					array( 'fab fa-viber' => 'viber' ),
					array( 'fab fa-vimeo-square' => 'vimeo square' ),
					array( 'fab fa-vimeo-v' => 'vimeo v' ),
					array( 'fab fa-vimeo' => 'vimeo' ),
					array( 'fab fa-vine' => 'vine' ),
					array( 'fab fa-vk' => 'vk' ),
					array( 'fab fa-vnv' => 'vnv' ),
					array( 'fab fa-vuejs' => 'vuejs' ),
					array( 'fab fa-waze' => 'waze' ),
					array( 'fab fa-weebly' => 'weebly' ),
					array( 'fab fa-weibo' => 'weibo' ),
					array( 'fab fa-weixin' => 'weixin' ),
					array( 'fab fa-whatsapp-square' => 'whatsapp square' ),
					array( 'fab fa-whatsapp' => 'whatsapp' ),
					array( 'fab fa-whmcs' => 'whmcs' ),
					array( 'fab fa-wikipedia-w' => 'wikipedia w' ),
					array( 'fab fa-windows' => 'windows' ),
					array( 'fab fa-wix' => 'wix' ),
					array( 'fab fa-wizards-of-the-coast' => 'wizards of the coast' ),
					array( 'fab fa-wolf-pack-battalion' => 'wolf pack battalion' ),
					array( 'fab fa-wordpress-simple' => 'wordpress simple' ),
					array( 'fab fa-wordpress' => 'wordpress' ),
					array( 'fab fa-wpbeginner' => 'wpbeginner' ),
					array( 'fab fa-wpexplorer' => 'wpexplorer' ),
					array( 'fab fa-wpforms' => 'wpforms' ),
					array( 'fab fa-wpressr' => 'wpressr' ),
					array( 'fab fa-xbox' => 'xbox' ),
					array( 'fab fa-xing-square' => 'xing square' ),
					array( 'fab fa-xing' => 'xing' ),
					array( 'fab fa-y-combinator' => 'y combinator' ),
					array( 'fab fa-yahoo' => 'yahoo' ),
					array( 'fab fa-yammer' => 'yammer' ),
					array( 'fab fa-yandex-international' => 'yandex international' ),
					array( 'fab fa-yandex' => 'yandex' ),
					array( 'fab fa-yarn' => 'yarn' ),
					array( 'fab fa-yelp' => 'yelp' ),
					array( 'fab fa-yoast' => 'yoast' ),
					array( 'fab fa-youtube-square' => 'youtube square' ),
					array( 'fab fa-youtube' => 'youtube' ),
					array( 'fab fa-zhihu' => 'zhihu' ),
				),
				esc_html__( 'Regular', 'brook' ) => array(
					array( 'far fa-abacus' => 'abacus' ),
					array( 'far fa-acorn' => 'acorn' ),
					array( 'far fa-ad' => 'ad' ),
					array( 'far fa-address-book' => 'address book' ),
					array( 'far fa-address-card' => 'address card' ),
					array( 'far fa-adjust' => 'adjust' ),
					array( 'far fa-air-conditioner' => 'air conditioner' ),
					array( 'far fa-air-freshener' => 'air freshener' ),
					array( 'far fa-alarm-clock' => 'alarm clock' ),
					array( 'far fa-alarm-exclamation' => 'alarm exclamation' ),
					array( 'far fa-alarm-plus' => 'alarm plus' ),
					array( 'far fa-alarm-snooze' => 'alarm snooze' ),
					array( 'far fa-album-collection' => 'album collection' ),
					array( 'far fa-album' => 'album' ),
					array( 'far fa-alicorn' => 'alicorn' ),
					array( 'far fa-alien-monster' => 'alien monster' ),
					array( 'far fa-alien' => 'alien' ),
					array( 'far fa-align-center' => 'align center' ),
					array( 'far fa-align-justify' => 'align justify' ),
					array( 'far fa-align-left' => 'align left' ),
					array( 'far fa-align-right' => 'align right' ),
					array( 'far fa-align-slash' => 'align slash' ),
					array( 'far fa-allergies' => 'allergies' ),
					array( 'far fa-ambulance' => 'ambulance' ),
					array( 'far fa-american-sign-language-interpreting' => 'american sign language interpreting' ),
					array( 'far fa-amp-guitar' => 'amp guitar' ),
					array( 'far fa-analytics' => 'analytics' ),
					array( 'far fa-anchor' => 'anchor' ),
					array( 'far fa-angel' => 'angel' ),
					array( 'far fa-angle-double-down' => 'angle double down' ),
					array( 'far fa-angle-double-left' => 'angle double left' ),
					array( 'far fa-angle-double-right' => 'angle double right' ),
					array( 'far fa-angle-double-up' => 'angle double up' ),
					array( 'far fa-angle-down' => 'angle down' ),
					array( 'far fa-angle-left' => 'angle left' ),
					array( 'far fa-angle-right' => 'angle right' ),
					array( 'far fa-angle-up' => 'angle up' ),
					array( 'far fa-angry' => 'angry' ),
					array( 'far fa-ankh' => 'ankh' ),
					array( 'far fa-apple-alt' => 'apple alt' ),
					array( 'far fa-apple-crate' => 'apple crate' ),
					array( 'far fa-archive' => 'archive' ),
					array( 'far fa-archway' => 'archway' ),
					array( 'far fa-arrow-alt-circle-down' => 'arrow alt circle down' ),
					array( 'far fa-arrow-alt-circle-left' => 'arrow alt circle left' ),
					array( 'far fa-arrow-alt-circle-right' => 'arrow alt circle right' ),
					array( 'far fa-arrow-alt-circle-up' => 'arrow alt circle up' ),
					array( 'far fa-arrow-alt-down' => 'arrow alt down' ),
					array( 'far fa-arrow-alt-from-bottom' => 'arrow alt from bottom' ),
					array( 'far fa-arrow-alt-from-left' => 'arrow alt from left' ),
					array( 'far fa-arrow-alt-from-right' => 'arrow alt from right' ),
					array( 'far fa-arrow-alt-from-top' => 'arrow alt from top' ),
					array( 'far fa-arrow-alt-left' => 'arrow alt left' ),
					array( 'far fa-arrow-alt-right' => 'arrow alt right' ),
					array( 'far fa-arrow-alt-square-down' => 'arrow alt square down' ),
					array( 'far fa-arrow-alt-square-left' => 'arrow alt square left' ),
					array( 'far fa-arrow-alt-square-right' => 'arrow alt square right' ),
					array( 'far fa-arrow-alt-square-up' => 'arrow alt square up' ),
					array( 'far fa-arrow-alt-to-bottom' => 'arrow alt to bottom' ),
					array( 'far fa-arrow-alt-to-left' => 'arrow alt to left' ),
					array( 'far fa-arrow-alt-to-right' => 'arrow alt to right' ),
					array( 'far fa-arrow-alt-to-top' => 'arrow alt to top' ),
					array( 'far fa-arrow-alt-up' => 'arrow alt up' ),
					array( 'far fa-arrow-circle-down' => 'arrow circle down' ),
					array( 'far fa-arrow-circle-left' => 'arrow circle left' ),
					array( 'far fa-arrow-circle-right' => 'arrow circle right' ),
					array( 'far fa-arrow-circle-up' => 'arrow circle up' ),
					array( 'far fa-arrow-down' => 'arrow down' ),
					array( 'far fa-arrow-from-bottom' => 'arrow from bottom' ),
					array( 'far fa-arrow-from-left' => 'arrow from left' ),
					array( 'far fa-arrow-from-right' => 'arrow from right' ),
					array( 'far fa-arrow-from-top' => 'arrow from top' ),
					array( 'far fa-arrow-left' => 'arrow left' ),
					array( 'far fa-arrow-right' => 'arrow right' ),
					array( 'far fa-arrow-square-down' => 'arrow square down' ),
					array( 'far fa-arrow-square-left' => 'arrow square left' ),
					array( 'far fa-arrow-square-right' => 'arrow square right' ),
					array( 'far fa-arrow-square-up' => 'arrow square up' ),
					array( 'far fa-arrow-to-bottom' => 'arrow to bottom' ),
					array( 'far fa-arrow-to-left' => 'arrow to left' ),
					array( 'far fa-arrow-to-right' => 'arrow to right' ),
					array( 'far fa-arrow-to-top' => 'arrow to top' ),
					array( 'far fa-arrow-up' => 'arrow up' ),
					array( 'far fa-arrows-alt-h' => 'arrows alt h' ),
					array( 'far fa-arrows-alt-v' => 'arrows alt v' ),
					array( 'far fa-arrows-alt' => 'arrows alt' ),
					array( 'far fa-arrows-h' => 'arrows h' ),
					array( 'far fa-arrows-v' => 'arrows v' ),
					array( 'far fa-arrows' => 'arrows' ),
					array( 'far fa-assistive-listening-systems' => 'assistive listening systems' ),
					array( 'far fa-asterisk' => 'asterisk' ),
					array( 'far fa-at' => 'at' ),
					array( 'far fa-atlas' => 'atlas' ),
					array( 'far fa-atom-alt' => 'atom alt' ),
					array( 'far fa-atom' => 'atom' ),
					array( 'far fa-audio-description' => 'audio description' ),
					array( 'far fa-award' => 'award' ),
					array( 'far fa-axe-battle' => 'axe battle' ),
					array( 'far fa-axe' => 'axe' ),
					array( 'far fa-baby-carriage' => 'baby carriage' ),
					array( 'far fa-baby' => 'baby' ),
					array( 'far fa-backpack' => 'backpack' ),
					array( 'far fa-backspace' => 'backspace' ),
					array( 'far fa-backward' => 'backward' ),
					array( 'far fa-bacon' => 'bacon' ),
					array( 'far fa-bacteria' => 'bacteria' ),
					array( 'far fa-bacterium' => 'bacterium' ),
					array( 'far fa-badge-check' => 'badge check' ),
					array( 'far fa-badge-dollar' => 'badge dollar' ),
					array( 'far fa-badge-percent' => 'badge percent' ),
					array( 'far fa-badge-sheriff' => 'badge sheriff' ),
					array( 'far fa-badge' => 'badge' ),
					array( 'far fa-badger-honey' => 'badger honey' ),
					array( 'far fa-bags-shopping' => 'bags shopping' ),
					array( 'far fa-bahai' => 'bahai' ),
					array( 'far fa-balance-scale-left' => 'balance scale left' ),
					array( 'far fa-balance-scale-right' => 'balance scale right' ),
					array( 'far fa-balance-scale' => 'balance scale' ),
					array( 'far fa-ball-pile' => 'ball pile' ),
					array( 'far fa-ballot-check' => 'ballot check' ),
					array( 'far fa-ballot' => 'ballot' ),
					array( 'far fa-ban' => 'ban' ),
					array( 'far fa-band-aid' => 'band aid' ),
					array( 'far fa-banjo' => 'banjo' ),
					array( 'far fa-barcode-alt' => 'barcode alt' ),
					array( 'far fa-barcode-read' => 'barcode read' ),
					array( 'far fa-barcode-scan' => 'barcode scan' ),
					array( 'far fa-barcode' => 'barcode' ),
					array( 'far fa-bars' => 'bars' ),
					array( 'far fa-baseball-ball' => 'baseball ball' ),
					array( 'far fa-baseball' => 'baseball' ),
					array( 'far fa-basketball-ball' => 'basketball ball' ),
					array( 'far fa-basketball-hoop' => 'basketball hoop' ),
					array( 'far fa-bat' => 'bat' ),
					array( 'far fa-bath' => 'bath' ),
					array( 'far fa-battery-bolt' => 'battery bolt' ),
					array( 'far fa-battery-empty' => 'battery empty' ),
					array( 'far fa-battery-full' => 'battery full' ),
					array( 'far fa-battery-half' => 'battery half' ),
					array( 'far fa-battery-quarter' => 'battery quarter' ),
					array( 'far fa-battery-slash' => 'battery slash' ),
					array( 'far fa-battery-three-quarters' => 'battery three quarters' ),
					array( 'far fa-bed-alt' => 'bed alt' ),
					array( 'far fa-bed-bunk' => 'bed bunk' ),
					array( 'far fa-bed-empty' => 'bed empty' ),
					array( 'far fa-bed' => 'bed' ),
					array( 'far fa-beer' => 'beer' ),
					array( 'far fa-bell-exclamation' => 'bell exclamation' ),
					array( 'far fa-bell-on' => 'bell on' ),
					array( 'far fa-bell-plus' => 'bell plus' ),
					array( 'far fa-bell-school-slash' => 'bell school slash' ),
					array( 'far fa-bell-school' => 'bell school' ),
					array( 'far fa-bell-slash' => 'bell slash' ),
					array( 'far fa-bell' => 'bell' ),
					array( 'far fa-bells' => 'bells' ),
					array( 'far fa-betamax' => 'betamax' ),
					array( 'far fa-bezier-curve' => 'bezier curve' ),
					array( 'far fa-bible' => 'bible' ),
					array( 'far fa-bicycle' => 'bicycle' ),
					array( 'far fa-biking-mountain' => 'biking mountain' ),
					array( 'far fa-biking' => 'biking' ),
					array( 'far fa-binoculars' => 'binoculars' ),
					array( 'far fa-biohazard' => 'biohazard' ),
					array( 'far fa-birthday-cake' => 'birthday cake' ),
					array( 'far fa-blanket' => 'blanket' ),
					array( 'far fa-blender-phone' => 'blender phone' ),
					array( 'far fa-blender' => 'blender' ),
					array( 'far fa-blind' => 'blind' ),
					array( 'far fa-blinds-open' => 'blinds open' ),
					array( 'far fa-blinds-raised' => 'blinds raised' ),
					array( 'far fa-blinds' => 'blinds' ),
					array( 'far fa-blog' => 'blog' ),
					array( 'far fa-bold' => 'bold' ),
					array( 'far fa-bolt' => 'bolt' ),
					array( 'far fa-bomb' => 'bomb' ),
					array( 'far fa-bone-break' => 'bone break' ),
					array( 'far fa-bone' => 'bone' ),
					array( 'far fa-bong' => 'bong' ),
					array( 'far fa-book-alt' => 'book alt' ),
					array( 'far fa-book-dead' => 'book dead' ),
					array( 'far fa-book-heart' => 'book heart' ),
					array( 'far fa-book-medical' => 'book medical' ),
					array( 'far fa-book-open' => 'book open' ),
					array( 'far fa-book-reader' => 'book reader' ),
					array( 'far fa-book-spells' => 'book spells' ),
					array( 'far fa-book-user' => 'book user' ),
					array( 'far fa-book' => 'book' ),
					array( 'far fa-bookmark' => 'bookmark' ),
					array( 'far fa-books-medical' => 'books medical' ),
					array( 'far fa-books' => 'books' ),
					array( 'far fa-boombox' => 'boombox' ),
					array( 'far fa-boot' => 'boot' ),
					array( 'far fa-booth-curtain' => 'booth curtain' ),
					array( 'far fa-border-all' => 'border all' ),
					array( 'far fa-border-bottom' => 'border bottom' ),
					array( 'far fa-border-center-h' => 'border center h' ),
					array( 'far fa-border-center-v' => 'border center v' ),
					array( 'far fa-border-inner' => 'border inner' ),
					array( 'far fa-border-left' => 'border left' ),
					array( 'far fa-border-none' => 'border none' ),
					array( 'far fa-border-outer' => 'border outer' ),
					array( 'far fa-border-right' => 'border right' ),
					array( 'far fa-border-style-alt' => 'border style alt' ),
					array( 'far fa-border-style' => 'border style' ),
					array( 'far fa-border-top' => 'border top' ),
					array( 'far fa-bow-arrow' => 'bow arrow' ),
					array( 'far fa-bowling-ball' => 'bowling ball' ),
					array( 'far fa-bowling-pins' => 'bowling pins' ),
					array( 'far fa-box-alt' => 'box alt' ),
					array( 'far fa-box-ballot' => 'box ballot' ),
					array( 'far fa-box-check' => 'box check' ),
					array( 'far fa-box-fragile' => 'box fragile' ),
					array( 'far fa-box-full' => 'box full' ),
					array( 'far fa-box-heart' => 'box heart' ),
					array( 'far fa-box-open' => 'box open' ),
					array( 'far fa-box-tissue' => 'box tissue' ),
					array( 'far fa-box-up' => 'box up' ),
					array( 'far fa-box-usd' => 'box usd' ),
					array( 'far fa-box' => 'box' ),
					array( 'far fa-boxes-alt' => 'boxes alt' ),
					array( 'far fa-boxes' => 'boxes' ),
					array( 'far fa-boxing-glove' => 'boxing glove' ),
					array( 'far fa-brackets-curly' => 'brackets curly' ),
					array( 'far fa-brackets' => 'brackets' ),
					array( 'far fa-braille' => 'braille' ),
					array( 'far fa-brain' => 'brain' ),
					array( 'far fa-bread-loaf' => 'bread loaf' ),
					array( 'far fa-bread-slice' => 'bread slice' ),
					array( 'far fa-briefcase-medical' => 'briefcase medical' ),
					array( 'far fa-briefcase' => 'briefcase' ),
					array( 'far fa-bring-forward' => 'bring forward' ),
					array( 'far fa-bring-front' => 'bring front' ),
					array( 'far fa-broadcast-tower' => 'broadcast tower' ),
					array( 'far fa-broom' => 'broom' ),
					array( 'far fa-browser' => 'browser' ),
					array( 'far fa-brush' => 'brush' ),
					array( 'far fa-bug' => 'bug' ),
					array( 'far fa-building' => 'building' ),
					array( 'far fa-bullhorn' => 'bullhorn' ),
					array( 'far fa-bullseye-arrow' => 'bullseye arrow' ),
					array( 'far fa-bullseye-pointer' => 'bullseye pointer' ),
					array( 'far fa-bullseye' => 'bullseye' ),
					array( 'far fa-burger-soda' => 'burger soda' ),
					array( 'far fa-burn' => 'burn' ),
					array( 'far fa-burrito' => 'burrito' ),
					array( 'far fa-bus-alt' => 'bus alt' ),
					array( 'far fa-bus-school' => 'bus school' ),
					array( 'far fa-bus' => 'bus' ),
					array( 'far fa-business-time' => 'business time' ),
					array( 'far fa-cabinet-filing' => 'cabinet filing' ),
					array( 'far fa-cactus' => 'cactus' ),
					array( 'far fa-calculator-alt' => 'calculator alt' ),
					array( 'far fa-calculator' => 'calculator' ),
					array( 'far fa-calendar-alt' => 'calendar alt' ),
					array( 'far fa-calendar-check' => 'calendar check' ),
					array( 'far fa-calendar-day' => 'calendar day' ),
					array( 'far fa-calendar-edit' => 'calendar edit' ),
					array( 'far fa-calendar-exclamation' => 'calendar exclamation' ),
					array( 'far fa-calendar-minus' => 'calendar minus' ),
					array( 'far fa-calendar-plus' => 'calendar plus' ),
					array( 'far fa-calendar-star' => 'calendar star' ),
					array( 'far fa-calendar-times' => 'calendar times' ),
					array( 'far fa-calendar-week' => 'calendar week' ),
					array( 'far fa-calendar' => 'calendar' ),
					array( 'far fa-camcorder' => 'camcorder' ),
					array( 'far fa-camera-alt' => 'camera alt' ),
					array( 'far fa-camera-home' => 'camera home' ),
					array( 'far fa-camera-movie' => 'camera movie' ),
					array( 'far fa-camera-polaroid' => 'camera polaroid' ),
					array( 'far fa-camera-retro' => 'camera retro' ),
					array( 'far fa-camera' => 'camera' ),
					array( 'far fa-campfire' => 'campfire' ),
					array( 'far fa-campground' => 'campground' ),
					array( 'far fa-candle-holder' => 'candle holder' ),
					array( 'far fa-candy-cane' => 'candy cane' ),
					array( 'far fa-candy-corn' => 'candy corn' ),
					array( 'far fa-cannabis' => 'cannabis' ),
					array( 'far fa-capsules' => 'capsules' ),
					array( 'far fa-car-alt' => 'car alt' ),
					array( 'far fa-car-battery' => 'car battery' ),
					array( 'far fa-car-building' => 'car building' ),
					array( 'far fa-car-bump' => 'car bump' ),
					array( 'far fa-car-bus' => 'car bus' ),
					array( 'far fa-car-crash' => 'car crash' ),
					array( 'far fa-car-garage' => 'car garage' ),
					array( 'far fa-car-mechanic' => 'car mechanic' ),
					array( 'far fa-car-side' => 'car side' ),
					array( 'far fa-car-tilt' => 'car tilt' ),
					array( 'far fa-car-wash' => 'car wash' ),
					array( 'far fa-car' => 'car' ),
					array( 'far fa-caravan-alt' => 'caravan alt' ),
					array( 'far fa-caravan' => 'caravan' ),
					array( 'far fa-caret-circle-down' => 'caret circle down' ),
					array( 'far fa-caret-circle-left' => 'caret circle left' ),
					array( 'far fa-caret-circle-right' => 'caret circle right' ),
					array( 'far fa-caret-circle-up' => 'caret circle up' ),
					array( 'far fa-caret-down' => 'caret down' ),
					array( 'far fa-caret-left' => 'caret left' ),
					array( 'far fa-caret-right' => 'caret right' ),
					array( 'far fa-caret-square-down' => 'caret square down' ),
					array( 'far fa-caret-square-left' => 'caret square left' ),
					array( 'far fa-caret-square-right' => 'caret square right' ),
					array( 'far fa-caret-square-up' => 'caret square up' ),
					array( 'far fa-caret-up' => 'caret up' ),
					array( 'far fa-carrot' => 'carrot' ),
					array( 'far fa-cars' => 'cars' ),
					array( 'far fa-cart-arrow-down' => 'cart arrow down' ),
					array( 'far fa-cart-plus' => 'cart plus' ),
					array( 'far fa-cash-register' => 'cash register' ),
					array( 'far fa-cassette-tape' => 'cassette tape' ),
					array( 'far fa-cat-space' => 'cat space' ),
					array( 'far fa-cat' => 'cat' ),
					array( 'far fa-cauldron' => 'cauldron' ),
					array( 'far fa-cctv' => 'cctv' ),
					array( 'far fa-certificate' => 'certificate' ),
					array( 'far fa-chair-office' => 'chair office' ),
					array( 'far fa-chair' => 'chair' ),
					array( 'far fa-chalkboard-teacher' => 'chalkboard teacher' ),
					array( 'far fa-chalkboard' => 'chalkboard' ),
					array( 'far fa-charging-station' => 'charging station' ),
					array( 'far fa-chart-area' => 'chart area' ),
					array( 'far fa-chart-bar' => 'chart bar' ),
					array( 'far fa-chart-line-down' => 'chart line down' ),
					array( 'far fa-chart-line' => 'chart line' ),
					array( 'far fa-chart-network' => 'chart network' ),
					array( 'far fa-chart-pie-alt' => 'chart pie alt' ),
					array( 'far fa-chart-pie' => 'chart pie' ),
					array( 'far fa-chart-scatter' => 'chart scatter' ),
					array( 'far fa-check-circle' => 'check circle' ),
					array( 'far fa-check-double' => 'check double' ),
					array( 'far fa-check-square' => 'check square' ),
					array( 'far fa-check' => 'check' ),
					array( 'far fa-cheese-swiss' => 'cheese swiss' ),
					array( 'far fa-cheese' => 'cheese' ),
					array( 'far fa-cheeseburger' => 'cheeseburger' ),
					array( 'far fa-chess-bishop-alt' => 'chess bishop alt' ),
					array( 'far fa-chess-bishop' => 'chess bishop' ),
					array( 'far fa-chess-board' => 'chess board' ),
					array( 'far fa-chess-clock-alt' => 'chess clock alt' ),
					array( 'far fa-chess-clock' => 'chess clock' ),
					array( 'far fa-chess-king-alt' => 'chess king alt' ),
					array( 'far fa-chess-king' => 'chess king' ),
					array( 'far fa-chess-knight-alt' => 'chess knight alt' ),
					array( 'far fa-chess-knight' => 'chess knight' ),
					array( 'far fa-chess-pawn-alt' => 'chess pawn alt' ),
					array( 'far fa-chess-pawn' => 'chess pawn' ),
					array( 'far fa-chess-queen-alt' => 'chess queen alt' ),
					array( 'far fa-chess-queen' => 'chess queen' ),
					array( 'far fa-chess-rook-alt' => 'chess rook alt' ),
					array( 'far fa-chess-rook' => 'chess rook' ),
					array( 'far fa-chess' => 'chess' ),
					array( 'far fa-chevron-circle-down' => 'chevron circle down' ),
					array( 'far fa-chevron-circle-left' => 'chevron circle left' ),
					array( 'far fa-chevron-circle-right' => 'chevron circle right' ),
					array( 'far fa-chevron-circle-up' => 'chevron circle up' ),
					array( 'far fa-chevron-double-down' => 'chevron double down' ),
					array( 'far fa-chevron-double-left' => 'chevron double left' ),
					array( 'far fa-chevron-double-right' => 'chevron double right' ),
					array( 'far fa-chevron-double-up' => 'chevron double up' ),
					array( 'far fa-chevron-down' => 'chevron down' ),
					array( 'far fa-chevron-left' => 'chevron left' ),
					array( 'far fa-chevron-right' => 'chevron right' ),
					array( 'far fa-chevron-square-down' => 'chevron square down' ),
					array( 'far fa-chevron-square-left' => 'chevron square left' ),
					array( 'far fa-chevron-square-right' => 'chevron square right' ),
					array( 'far fa-chevron-square-up' => 'chevron square up' ),
					array( 'far fa-chevron-up' => 'chevron up' ),
					array( 'far fa-child' => 'child' ),
					array( 'far fa-chimney' => 'chimney' ),
					array( 'far fa-church' => 'church' ),
					array( 'far fa-circle-notch' => 'circle notch' ),
					array( 'far fa-circle' => 'circle' ),
					array( 'far fa-city' => 'city' ),
					array( 'far fa-clarinet' => 'clarinet' ),
					array( 'far fa-claw-marks' => 'claw marks' ),
					array( 'far fa-clinic-medical' => 'clinic medical' ),
					array( 'far fa-clipboard-check' => 'clipboard check' ),
					array( 'far fa-clipboard-list-check' => 'clipboard list check' ),
					array( 'far fa-clipboard-list' => 'clipboard list' ),
					array( 'far fa-clipboard-prescription' => 'clipboard prescription' ),
					array( 'far fa-clipboard-user' => 'clipboard user' ),
					array( 'far fa-clipboard' => 'clipboard' ),
					array( 'far fa-clock' => 'clock' ),
					array( 'far fa-clone' => 'clone' ),
					array( 'far fa-closed-captioning' => 'closed captioning' ),
					array( 'far fa-cloud-download-alt' => 'cloud download alt' ),
					array( 'far fa-cloud-download' => 'cloud download' ),
					array( 'far fa-cloud-drizzle' => 'cloud drizzle' ),
					array( 'far fa-cloud-hail-mixed' => 'cloud hail mixed' ),
					array( 'far fa-cloud-hail' => 'cloud hail' ),
					array( 'far fa-cloud-meatball' => 'cloud meatball' ),
					array( 'far fa-cloud-moon-rain' => 'cloud moon rain' ),
					array( 'far fa-cloud-moon' => 'cloud moon' ),
					array( 'far fa-cloud-music' => 'cloud music' ),
					array( 'far fa-cloud-rain' => 'cloud rain' ),
					array( 'far fa-cloud-rainbow' => 'cloud rainbow' ),
					array( 'far fa-cloud-showers-heavy' => 'cloud showers heavy' ),
					array( 'far fa-cloud-showers' => 'cloud showers' ),
					array( 'far fa-cloud-sleet' => 'cloud sleet' ),
					array( 'far fa-cloud-snow' => 'cloud snow' ),
					array( 'far fa-cloud-sun-rain' => 'cloud sun rain' ),
					array( 'far fa-cloud-sun' => 'cloud sun' ),
					array( 'far fa-cloud-upload-alt' => 'cloud upload alt' ),
					array( 'far fa-cloud-upload' => 'cloud upload' ),
					array( 'far fa-cloud' => 'cloud' ),
					array( 'far fa-clouds-moon' => 'clouds moon' ),
					array( 'far fa-clouds-sun' => 'clouds sun' ),
					array( 'far fa-clouds' => 'clouds' ),
					array( 'far fa-club' => 'club' ),
					array( 'far fa-cocktail' => 'cocktail' ),
					array( 'far fa-code-branch' => 'code branch' ),
					array( 'far fa-code-commit' => 'code commit' ),
					array( 'far fa-code-merge' => 'code merge' ),
					array( 'far fa-code' => 'code' ),
					array( 'far fa-coffee-pot' => 'coffee pot' ),
					array( 'far fa-coffee-togo' => 'coffee togo' ),
					array( 'far fa-coffee' => 'coffee' ),
					array( 'far fa-coffin-cross' => 'coffin cross' ),
					array( 'far fa-coffin' => 'coffin' ),
					array( 'far fa-cog' => 'cog' ),
					array( 'far fa-cogs' => 'cogs' ),
					array( 'far fa-coin' => 'coin' ),
					array( 'far fa-coins' => 'coins' ),
					array( 'far fa-columns' => 'columns' ),
					array( 'far fa-comet' => 'comet' ),
					array( 'far fa-comment-alt-check' => 'comment alt check' ),
					array( 'far fa-comment-alt-dollar' => 'comment alt dollar' ),
					array( 'far fa-comment-alt-dots' => 'comment alt dots' ),
					array( 'far fa-comment-alt-edit' => 'comment alt edit' ),
					array( 'far fa-comment-alt-exclamation' => 'comment alt exclamation' ),
					array( 'far fa-comment-alt-lines' => 'comment alt lines' ),
					array( 'far fa-comment-alt-medical' => 'comment alt medical' ),
					array( 'far fa-comment-alt-minus' => 'comment alt minus' ),
					array( 'far fa-comment-alt-music' => 'comment alt music' ),
					array( 'far fa-comment-alt-plus' => 'comment alt plus' ),
					array( 'far fa-comment-alt-slash' => 'comment alt slash' ),
					array( 'far fa-comment-alt-smile' => 'comment alt smile' ),
					array( 'far fa-comment-alt-times' => 'comment alt times' ),
					array( 'far fa-comment-alt' => 'comment alt' ),
					array( 'far fa-comment-check' => 'comment check' ),
					array( 'far fa-comment-dollar' => 'comment dollar' ),
					array( 'far fa-comment-dots' => 'comment dots' ),
					array( 'far fa-comment-edit' => 'comment edit' ),
					array( 'far fa-comment-exclamation' => 'comment exclamation' ),
					array( 'far fa-comment-lines' => 'comment lines' ),
					array( 'far fa-comment-medical' => 'comment medical' ),
					array( 'far fa-comment-minus' => 'comment minus' ),
					array( 'far fa-comment-music' => 'comment music' ),
					array( 'far fa-comment-plus' => 'comment plus' ),
					array( 'far fa-comment-slash' => 'comment slash' ),
					array( 'far fa-comment-smile' => 'comment smile' ),
					array( 'far fa-comment-times' => 'comment times' ),
					array( 'far fa-comment' => 'comment' ),
					array( 'far fa-comments-alt-dollar' => 'comments alt dollar' ),
					array( 'far fa-comments-alt' => 'comments alt' ),
					array( 'far fa-comments-dollar' => 'comments dollar' ),
					array( 'far fa-comments' => 'comments' ),
					array( 'far fa-compact-disc' => 'compact disc' ),
					array( 'far fa-compass-slash' => 'compass slash' ),
					array( 'far fa-compass' => 'compass' ),
					array( 'far fa-compress-alt' => 'compress alt' ),
					array( 'far fa-compress-arrows-alt' => 'compress arrows alt' ),
					array( 'far fa-compress-wide' => 'compress wide' ),
					array( 'far fa-compress' => 'compress' ),
					array( 'far fa-computer-classic' => 'computer classic' ),
					array( 'far fa-computer-speaker' => 'computer speaker' ),
					array( 'far fa-concierge-bell' => 'concierge bell' ),
					array( 'far fa-construction' => 'construction' ),
					array( 'far fa-container-storage' => 'container storage' ),
					array( 'far fa-conveyor-belt-alt' => 'conveyor belt alt' ),
					array( 'far fa-conveyor-belt' => 'conveyor belt' ),
					array( 'far fa-cookie-bite' => 'cookie bite' ),
					array( 'far fa-cookie' => 'cookie' ),
					array( 'far fa-copy' => 'copy' ),
					array( 'far fa-copyright' => 'copyright' ),
					array( 'far fa-corn' => 'corn' ),
					array( 'far fa-couch' => 'couch' ),
					array( 'far fa-cow' => 'cow' ),
					array( 'far fa-cowbell-more' => 'cowbell more' ),
					array( 'far fa-cowbell' => 'cowbell' ),
					array( 'far fa-credit-card-blank' => 'credit card blank' ),
					array( 'far fa-credit-card-front' => 'credit card front' ),
					array( 'far fa-credit-card' => 'credit card' ),
					array( 'far fa-cricket' => 'cricket' ),
					array( 'far fa-croissant' => 'croissant' ),
					array( 'far fa-crop-alt' => 'crop alt' ),
					array( 'far fa-crop' => 'crop' ),
					array( 'far fa-cross' => 'cross' ),
					array( 'far fa-crosshairs' => 'crosshairs' ),
					array( 'far fa-crow' => 'crow' ),
					array( 'far fa-crown' => 'crown' ),
					array( 'far fa-crutch' => 'crutch' ),
					array( 'far fa-crutches' => 'crutches' ),
					array( 'far fa-cube' => 'cube' ),
					array( 'far fa-cubes' => 'cubes' ),
					array( 'far fa-curling' => 'curling' ),
					array( 'far fa-cut' => 'cut' ),
					array( 'far fa-dagger' => 'dagger' ),
					array( 'far fa-database' => 'database' ),
					array( 'far fa-deaf' => 'deaf' ),
					array( 'far fa-debug' => 'debug' ),
					array( 'far fa-deer-rudolph' => 'deer rudolph' ),
					array( 'far fa-deer' => 'deer' ),
					array( 'far fa-democrat' => 'democrat' ),
					array( 'far fa-desktop-alt' => 'desktop alt' ),
					array( 'far fa-desktop' => 'desktop' ),
					array( 'far fa-dewpoint' => 'dewpoint' ),
					array( 'far fa-dharmachakra' => 'dharmachakra' ),
					array( 'far fa-diagnoses' => 'diagnoses' ),
					array( 'far fa-diamond' => 'diamond' ),
					array( 'far fa-dice-d10' => 'dice d10' ),
					array( 'far fa-dice-d12' => 'dice d12' ),
					array( 'far fa-dice-d20' => 'dice d20' ),
					array( 'far fa-dice-d4' => 'dice d4' ),
					array( 'far fa-dice-d6' => 'dice d6' ),
					array( 'far fa-dice-d8' => 'dice d8' ),
					array( 'far fa-dice-five' => 'dice five' ),
					array( 'far fa-dice-four' => 'dice four' ),
					array( 'far fa-dice-one' => 'dice one' ),
					array( 'far fa-dice-six' => 'dice six' ),
					array( 'far fa-dice-three' => 'dice three' ),
					array( 'far fa-dice-two' => 'dice two' ),
					array( 'far fa-dice' => 'dice' ),
					array( 'far fa-digging' => 'digging' ),
					array( 'far fa-digital-tachograph' => 'digital tachograph' ),
					array( 'far fa-diploma' => 'diploma' ),
					array( 'far fa-directions' => 'directions' ),
					array( 'far fa-disc-drive' => 'disc drive' ),
					array( 'far fa-disease' => 'disease' ),
					array( 'far fa-divide' => 'divide' ),
					array( 'far fa-dizzy' => 'dizzy' ),
					array( 'far fa-dna' => 'dna' ),
					array( 'far fa-do-not-enter' => 'do not enter' ),
					array( 'far fa-dog-leashed' => 'dog leashed' ),
					array( 'far fa-dog' => 'dog' ),
					array( 'far fa-dollar-sign' => 'dollar sign' ),
					array( 'far fa-dolly-empty' => 'dolly empty' ),
					array( 'far fa-dolly-flatbed-alt' => 'dolly flatbed alt' ),
					array( 'far fa-dolly-flatbed-empty' => 'dolly flatbed empty' ),
					array( 'far fa-dolly-flatbed' => 'dolly flatbed' ),
					array( 'far fa-dolly' => 'dolly' ),
					array( 'far fa-donate' => 'donate' ),
					array( 'far fa-door-closed' => 'door closed' ),
					array( 'far fa-door-open' => 'door open' ),
					array( 'far fa-dot-circle' => 'dot circle' ),
					array( 'far fa-dove' => 'dove' ),
					array( 'far fa-download' => 'download' ),
					array( 'far fa-drafting-compass' => 'drafting compass' ),
					array( 'far fa-dragon' => 'dragon' ),
					array( 'far fa-draw-circle' => 'draw circle' ),
					array( 'far fa-draw-polygon' => 'draw polygon' ),
					array( 'far fa-draw-square' => 'draw square' ),
					array( 'far fa-dreidel' => 'dreidel' ),
					array( 'far fa-drone-alt' => 'drone alt' ),
					array( 'far fa-drone' => 'drone' ),
					array( 'far fa-drum-steelpan' => 'drum steelpan' ),
					array( 'far fa-drum' => 'drum' ),
					array( 'far fa-drumstick-bite' => 'drumstick bite' ),
					array( 'far fa-drumstick' => 'drumstick' ),
					array( 'far fa-dryer-alt' => 'dryer alt' ),
					array( 'far fa-dryer' => 'dryer' ),
					array( 'far fa-duck' => 'duck' ),
					array( 'far fa-dumbbell' => 'dumbbell' ),
					array( 'far fa-dumpster-fire' => 'dumpster fire' ),
					array( 'far fa-dumpster' => 'dumpster' ),
					array( 'far fa-dungeon' => 'dungeon' ),
					array( 'far fa-ear-muffs' => 'ear muffs' ),
					array( 'far fa-ear' => 'ear' ),
					array( 'far fa-eclipse-alt' => 'eclipse alt' ),
					array( 'far fa-eclipse' => 'eclipse' ),
					array( 'far fa-edit' => 'edit' ),
					array( 'far fa-egg-fried' => 'egg fried' ),
					array( 'far fa-egg' => 'egg' ),
					array( 'far fa-eject' => 'eject' ),
					array( 'far fa-elephant' => 'elephant' ),
					array( 'far fa-ellipsis-h-alt' => 'ellipsis h alt' ),
					array( 'far fa-ellipsis-h' => 'ellipsis h' ),
					array( 'far fa-ellipsis-v-alt' => 'ellipsis v alt' ),
					array( 'far fa-ellipsis-v' => 'ellipsis v' ),
					array( 'far fa-empty-set' => 'empty set' ),
					array( 'far fa-engine-warning' => 'engine warning' ),
					array( 'far fa-envelope-open-dollar' => 'envelope open dollar' ),
					array( 'far fa-envelope-open-text' => 'envelope open text' ),
					array( 'far fa-envelope-open' => 'envelope open' ),
					array( 'far fa-envelope-square' => 'envelope square' ),
					array( 'far fa-envelope' => 'envelope' ),
					array( 'far fa-equals' => 'equals' ),
					array( 'far fa-eraser' => 'eraser' ),
					array( 'far fa-ethernet' => 'ethernet' ),
					array( 'far fa-euro-sign' => 'euro sign' ),
					array( 'far fa-exchange-alt' => 'exchange alt' ),
					array( 'far fa-exchange' => 'exchange' ),
					array( 'far fa-exclamation-circle' => 'exclamation circle' ),
					array( 'far fa-exclamation-square' => 'exclamation square' ),
					array( 'far fa-exclamation-triangle' => 'exclamation triangle' ),
					array( 'far fa-exclamation' => 'exclamation' ),
					array( 'far fa-expand-alt' => 'expand alt' ),
					array( 'far fa-expand-arrows-alt' => 'expand arrows alt' ),
					array( 'far fa-expand-arrows' => 'expand arrows' ),
					array( 'far fa-expand-wide' => 'expand wide' ),
					array( 'far fa-expand' => 'expand' ),
					array( 'far fa-external-link-alt' => 'external link alt' ),
					array( 'far fa-external-link-square-alt' => 'external link square alt' ),
					array( 'far fa-external-link-square' => 'external link square' ),
					array( 'far fa-external-link' => 'external link' ),
					array( 'far fa-eye-dropper' => 'eye dropper' ),
					array( 'far fa-eye-evil' => 'eye evil' ),
					array( 'far fa-eye-slash' => 'eye slash' ),
					array( 'far fa-eye' => 'eye' ),
					array( 'far fa-fan-table' => 'fan table' ),
					array( 'far fa-fan' => 'fan' ),
					array( 'far fa-farm' => 'farm' ),
					array( 'far fa-fast-backward' => 'fast backward' ),
					array( 'far fa-fast-forward' => 'fast forward' ),
					array( 'far fa-faucet-drip' => 'faucet drip' ),
					array( 'far fa-faucet' => 'faucet' ),
					array( 'far fa-fax' => 'fax' ),
					array( 'far fa-feather-alt' => 'feather alt' ),
					array( 'far fa-feather' => 'feather' ),
					array( 'far fa-female' => 'female' ),
					array( 'far fa-field-hockey' => 'field hockey' ),
					array( 'far fa-fighter-jet' => 'fighter jet' ),
					array( 'far fa-file-alt' => 'file alt' ),
					array( 'far fa-file-archive' => 'file archive' ),
					array( 'far fa-file-audio' => 'file audio' ),
					array( 'far fa-file-certificate' => 'file certificate' ),
					array( 'far fa-file-chart-line' => 'file chart line' ),
					array( 'far fa-file-chart-pie' => 'file chart pie' ),
					array( 'far fa-file-check' => 'file check' ),
					array( 'far fa-file-code' => 'file code' ),
					array( 'far fa-file-contract' => 'file contract' ),
					array( 'far fa-file-csv' => 'file csv' ),
					array( 'far fa-file-download' => 'file download' ),
					array( 'far fa-file-edit' => 'file edit' ),
					array( 'far fa-file-excel' => 'file excel' ),
					array( 'far fa-file-exclamation' => 'file exclamation' ),
					array( 'far fa-file-export' => 'file export' ),
					array( 'far fa-file-image' => 'file image' ),
					array( 'far fa-file-import' => 'file import' ),
					array( 'far fa-file-invoice-dollar' => 'file invoice dollar' ),
					array( 'far fa-file-invoice' => 'file invoice' ),
					array( 'far fa-file-medical-alt' => 'file medical alt' ),
					array( 'far fa-file-medical' => 'file medical' ),
					array( 'far fa-file-minus' => 'file minus' ),
					array( 'far fa-file-music' => 'file music' ),
					array( 'far fa-file-pdf' => 'file pdf' ),
					array( 'far fa-file-plus' => 'file plus' ),
					array( 'far fa-file-powerpoint' => 'file powerpoint' ),
					array( 'far fa-file-prescription' => 'file prescription' ),
					array( 'far fa-file-search' => 'file search' ),
					array( 'far fa-file-signature' => 'file signature' ),
					array( 'far fa-file-spreadsheet' => 'file spreadsheet' ),
					array( 'far fa-file-times' => 'file times' ),
					array( 'far fa-file-upload' => 'file upload' ),
					array( 'far fa-file-user' => 'file user' ),
					array( 'far fa-file-video' => 'file video' ),
					array( 'far fa-file-word' => 'file word' ),
					array( 'far fa-file' => 'file' ),
					array( 'far fa-files-medical' => 'files medical' ),
					array( 'far fa-fill-drip' => 'fill drip' ),
					array( 'far fa-fill' => 'fill' ),
					array( 'far fa-film-alt' => 'film alt' ),
					array( 'far fa-film-canister' => 'film canister' ),
					array( 'far fa-film' => 'film' ),
					array( 'far fa-filter' => 'filter' ),
					array( 'far fa-fingerprint' => 'fingerprint' ),
					array( 'far fa-fire-alt' => 'fire alt' ),
					array( 'far fa-fire-extinguisher' => 'fire extinguisher' ),
					array( 'far fa-fire-smoke' => 'fire smoke' ),
					array( 'far fa-fire' => 'fire' ),
					array( 'far fa-fireplace' => 'fireplace' ),
					array( 'far fa-first-aid' => 'first aid' ),
					array( 'far fa-fish-cooked' => 'fish cooked' ),
					array( 'far fa-fish' => 'fish' ),
					array( 'far fa-fist-raised' => 'fist raised' ),
					array( 'far fa-flag-alt' => 'flag alt' ),
					array( 'far fa-flag-checkered' => 'flag checkered' ),
					array( 'far fa-flag-usa' => 'flag usa' ),
					array( 'far fa-flag' => 'flag' ),
					array( 'far fa-flame' => 'flame' ),
					array( 'far fa-flashlight' => 'flashlight' ),
					array( 'far fa-flask-poison' => 'flask poison' ),
					array( 'far fa-flask-potion' => 'flask potion' ),
					array( 'far fa-flask' => 'flask' ),
					array( 'far fa-flower-daffodil' => 'flower daffodil' ),
					array( 'far fa-flower-tulip' => 'flower tulip' ),
					array( 'far fa-flower' => 'flower' ),
					array( 'far fa-flushed' => 'flushed' ),
					array( 'far fa-flute' => 'flute' ),
					array( 'far fa-flux-capacitor' => 'flux capacitor' ),
					array( 'far fa-fog' => 'fog' ),
					array( 'far fa-folder-download' => 'folder download' ),
					array( 'far fa-folder-minus' => 'folder minus' ),
					array( 'far fa-folder-open' => 'folder open' ),
					array( 'far fa-folder-plus' => 'folder plus' ),
					array( 'far fa-folder-times' => 'folder times' ),
					array( 'far fa-folder-tree' => 'folder tree' ),
					array( 'far fa-folder-upload' => 'folder upload' ),
					array( 'far fa-folder' => 'folder' ),
					array( 'far fa-folders' => 'folders' ),
					array( 'far fa-font-awesome-logo-full' => 'font awesome logo full' ),
					array( 'far fa-font-case' => 'font case' ),
					array( 'far fa-font' => 'font' ),
					array( 'far fa-football-ball' => 'football ball' ),
					array( 'far fa-football-helmet' => 'football helmet' ),
					array( 'far fa-forklift' => 'forklift' ),
					array( 'far fa-forward' => 'forward' ),
					array( 'far fa-fragile' => 'fragile' ),
					array( 'far fa-french-fries' => 'french fries' ),
					array( 'far fa-frog' => 'frog' ),
					array( 'far fa-frosty-head' => 'frosty head' ),
					array( 'far fa-frown-open' => 'frown open' ),
					array( 'far fa-frown' => 'frown' ),
					array( 'far fa-function' => 'function' ),
					array( 'far fa-funnel-dollar' => 'funnel dollar' ),
					array( 'far fa-futbol' => 'futbol' ),
					array( 'far fa-galaxy' => 'galaxy' ),
					array( 'far fa-game-board-alt' => 'game board alt' ),
					array( 'far fa-game-board' => 'game board' ),
					array( 'far fa-game-console-handheld' => 'game console handheld' ),
					array( 'far fa-gamepad-alt' => 'gamepad alt' ),
					array( 'far fa-gamepad' => 'gamepad' ),
					array( 'far fa-garage-car' => 'garage car' ),
					array( 'far fa-garage-open' => 'garage open' ),
					array( 'far fa-garage' => 'garage' ),
					array( 'far fa-gas-pump-slash' => 'gas pump slash' ),
					array( 'far fa-gas-pump' => 'gas pump' ),
					array( 'far fa-gavel' => 'gavel' ),
					array( 'far fa-gem' => 'gem' ),
					array( 'far fa-genderless' => 'genderless' ),
					array( 'far fa-ghost' => 'ghost' ),
					array( 'far fa-gift-card' => 'gift card' ),
					array( 'far fa-gift' => 'gift' ),
					array( 'far fa-gifts' => 'gifts' ),
					array( 'far fa-gingerbread-man' => 'gingerbread man' ),
					array( 'far fa-glass-champagne' => 'glass champagne' ),
					array( 'far fa-glass-cheers' => 'glass cheers' ),
					array( 'far fa-glass-citrus' => 'glass citrus' ),
					array( 'far fa-glass-martini-alt' => 'glass martini alt' ),
					array( 'far fa-glass-martini' => 'glass martini' ),
					array( 'far fa-glass-whiskey-rocks' => 'glass whiskey rocks' ),
					array( 'far fa-glass-whiskey' => 'glass whiskey' ),
					array( 'far fa-glass' => 'glass' ),
					array( 'far fa-glasses-alt' => 'glasses alt' ),
					array( 'far fa-glasses' => 'glasses' ),
					array( 'far fa-globe-africa' => 'globe africa' ),
					array( 'far fa-globe-americas' => 'globe americas' ),
					array( 'far fa-globe-asia' => 'globe asia' ),
					array( 'far fa-globe-europe' => 'globe europe' ),
					array( 'far fa-globe-snow' => 'globe snow' ),
					array( 'far fa-globe-stand' => 'globe stand' ),
					array( 'far fa-globe' => 'globe' ),
					array( 'far fa-golf-ball' => 'golf ball' ),
					array( 'far fa-golf-club' => 'golf club' ),
					array( 'far fa-gopuram' => 'gopuram' ),
					array( 'far fa-graduation-cap' => 'graduation cap' ),
					array( 'far fa-gramophone' => 'gramophone' ),
					array( 'far fa-greater-than-equal' => 'greater than equal' ),
					array( 'far fa-greater-than' => 'greater than' ),
					array( 'far fa-grimace' => 'grimace' ),
					array( 'far fa-grin-alt' => 'grin alt' ),
					array( 'far fa-grin-beam-sweat' => 'grin beam sweat' ),
					array( 'far fa-grin-beam' => 'grin beam' ),
					array( 'far fa-grin-hearts' => 'grin hearts' ),
					array( 'far fa-grin-squint-tears' => 'grin squint tears' ),
					array( 'far fa-grin-squint' => 'grin squint' ),
					array( 'far fa-grin-stars' => 'grin stars' ),
					array( 'far fa-grin-tears' => 'grin tears' ),
					array( 'far fa-grin-tongue-squint' => 'grin tongue squint' ),
					array( 'far fa-grin-tongue-wink' => 'grin tongue wink' ),
					array( 'far fa-grin-tongue' => 'grin tongue' ),
					array( 'far fa-grin-wink' => 'grin wink' ),
					array( 'far fa-grin' => 'grin' ),
					array( 'far fa-grip-horizontal' => 'grip horizontal' ),
					array( 'far fa-grip-lines-vertical' => 'grip lines vertical' ),
					array( 'far fa-grip-lines' => 'grip lines' ),
					array( 'far fa-grip-vertical' => 'grip vertical' ),
					array( 'far fa-guitar-electric' => 'guitar electric' ),
					array( 'far fa-guitar' => 'guitar' ),
					array( 'far fa-guitars' => 'guitars' ),
					array( 'far fa-h-square' => 'h square' ),
					array( 'far fa-h1' => 'h1' ),
					array( 'far fa-h2' => 'h2' ),
					array( 'far fa-h3' => 'h3' ),
					array( 'far fa-h4' => 'h4' ),
					array( 'far fa-hamburger' => 'hamburger' ),
					array( 'far fa-hammer-war' => 'hammer war' ),
					array( 'far fa-hammer' => 'hammer' ),
					array( 'far fa-hamsa' => 'hamsa' ),
					array( 'far fa-hand-heart' => 'hand heart' ),
					array( 'far fa-hand-holding-box' => 'hand holding box' ),
					array( 'far fa-hand-holding-heart' => 'hand holding heart' ),
					array( 'far fa-hand-holding-magic' => 'hand holding magic' ),
					array( 'far fa-hand-holding-medical' => 'hand holding medical' ),
					array( 'far fa-hand-holding-seedling' => 'hand holding seedling' ),
					array( 'far fa-hand-holding-usd' => 'hand holding usd' ),
					array( 'far fa-hand-holding-water' => 'hand holding water' ),
					array( 'far fa-hand-holding' => 'hand holding' ),
					array( 'far fa-hand-lizard' => 'hand lizard' ),
					array( 'far fa-hand-middle-finger' => 'hand middle finger' ),
					array( 'far fa-hand-paper' => 'hand paper' ),
					array( 'far fa-hand-peace' => 'hand peace' ),
					array( 'far fa-hand-point-down' => 'hand point down' ),
					array( 'far fa-hand-point-left' => 'hand point left' ),
					array( 'far fa-hand-point-right' => 'hand point right' ),
					array( 'far fa-hand-point-up' => 'hand point up' ),
					array( 'far fa-hand-pointer' => 'hand pointer' ),
					array( 'far fa-hand-receiving' => 'hand receiving' ),
					array( 'far fa-hand-rock' => 'hand rock' ),
					array( 'far fa-hand-scissors' => 'hand scissors' ),
					array( 'far fa-hand-sparkles' => 'hand sparkles' ),
					array( 'far fa-hand-spock' => 'hand spock' ),
					array( 'far fa-hands-heart' => 'hands heart' ),
					array( 'far fa-hands-helping' => 'hands helping' ),
					array( 'far fa-hands-usd' => 'hands usd' ),
					array( 'far fa-hands-wash' => 'hands wash' ),
					array( 'far fa-hands' => 'hands' ),
					array( 'far fa-handshake-alt-slash' => 'handshake alt slash' ),
					array( 'far fa-handshake-alt' => 'handshake alt' ),
					array( 'far fa-handshake-slash' => 'handshake slash' ),
					array( 'far fa-handshake' => 'handshake' ),
					array( 'far fa-hanukiah' => 'hanukiah' ),
					array( 'far fa-hard-hat' => 'hard hat' ),
					array( 'far fa-hashtag' => 'hashtag' ),
					array( 'far fa-hat-chef' => 'hat chef' ),
					array( 'far fa-hat-cowboy-side' => 'hat cowboy side' ),
					array( 'far fa-hat-cowboy' => 'hat cowboy' ),
					array( 'far fa-hat-santa' => 'hat santa' ),
					array( 'far fa-hat-winter' => 'hat winter' ),
					array( 'far fa-hat-witch' => 'hat witch' ),
					array( 'far fa-hat-wizard' => 'hat wizard' ),
					array( 'far fa-hdd' => 'hdd' ),
					array( 'far fa-head-side-brain' => 'head side brain' ),
					array( 'far fa-head-side-cough-slash' => 'head side cough slash' ),
					array( 'far fa-head-side-cough' => 'head side cough' ),
					array( 'far fa-head-side-headphones' => 'head side headphones' ),
					array( 'far fa-head-side-mask' => 'head side mask' ),
					array( 'far fa-head-side-medical' => 'head side medical' ),
					array( 'far fa-head-side-virus' => 'head side virus' ),
					array( 'far fa-head-side' => 'head side' ),
					array( 'far fa-head-vr' => 'head vr' ),
					array( 'far fa-heading' => 'heading' ),
					array( 'far fa-headphones-alt' => 'headphones alt' ),
					array( 'far fa-headphones' => 'headphones' ),
					array( 'far fa-headset' => 'headset' ),
					array( 'far fa-heart-broken' => 'heart broken' ),
					array( 'far fa-heart-circle' => 'heart circle' ),
					array( 'far fa-heart-rate' => 'heart rate' ),
					array( 'far fa-heart-square' => 'heart square' ),
					array( 'far fa-heart' => 'heart' ),
					array( 'far fa-heartbeat' => 'heartbeat' ),
					array( 'far fa-heat' => 'heat' ),
					array( 'far fa-helicopter' => 'helicopter' ),
					array( 'far fa-helmet-battle' => 'helmet battle' ),
					array( 'far fa-hexagon' => 'hexagon' ),
					array( 'far fa-highlighter' => 'highlighter' ),
					array( 'far fa-hiking' => 'hiking' ),
					array( 'far fa-hippo' => 'hippo' ),
					array( 'far fa-history' => 'history' ),
					array( 'far fa-hockey-mask' => 'hockey mask' ),
					array( 'far fa-hockey-puck' => 'hockey puck' ),
					array( 'far fa-hockey-sticks' => 'hockey sticks' ),
					array( 'far fa-holly-berry' => 'holly berry' ),
					array( 'far fa-home-alt' => 'home alt' ),
					array( 'far fa-home-heart' => 'home heart' ),
					array( 'far fa-home-lg-alt' => 'home lg alt' ),
					array( 'far fa-home-lg' => 'home lg' ),
					array( 'far fa-home' => 'home' ),
					array( 'far fa-hood-cloak' => 'hood cloak' ),
					array( 'far fa-horizontal-rule' => 'horizontal rule' ),
					array( 'far fa-horse-head' => 'horse head' ),
					array( 'far fa-horse-saddle' => 'horse saddle' ),
					array( 'far fa-horse' => 'horse' ),
					array( 'far fa-hospital-alt' => 'hospital alt' ),
					array( 'far fa-hospital-symbol' => 'hospital symbol' ),
					array( 'far fa-hospital-user' => 'hospital user' ),
					array( 'far fa-hospital' => 'hospital' ),
					array( 'far fa-hospitals' => 'hospitals' ),
					array( 'far fa-hot-tub' => 'hot tub' ),
					array( 'far fa-hotdog' => 'hotdog' ),
					array( 'far fa-hotel' => 'hotel' ),
					array( 'far fa-hourglass-end' => 'hourglass end' ),
					array( 'far fa-hourglass-half' => 'hourglass half' ),
					array( 'far fa-hourglass-start' => 'hourglass start' ),
					array( 'far fa-hourglass' => 'hourglass' ),
					array( 'far fa-house-damage' => 'house damage' ),
					array( 'far fa-house-day' => 'house day' ),
					array( 'far fa-house-flood' => 'house flood' ),
					array( 'far fa-house-leave' => 'house leave' ),
					array( 'far fa-house-night' => 'house night' ),
					array( 'far fa-house-return' => 'house return' ),
					array( 'far fa-house-signal' => 'house signal' ),
					array( 'far fa-house-user' => 'house user' ),
					array( 'far fa-house' => 'house' ),
					array( 'far fa-hryvnia' => 'hryvnia' ),
					array( 'far fa-humidity' => 'humidity' ),
					array( 'far fa-hurricane' => 'hurricane' ),
					array( 'far fa-i-cursor' => 'i cursor' ),
					array( 'far fa-ice-cream' => 'ice cream' ),
					array( 'far fa-ice-skate' => 'ice skate' ),
					array( 'far fa-icicles' => 'icicles' ),
					array( 'far fa-icons-alt' => 'icons alt' ),
					array( 'far fa-icons' => 'icons' ),
					array( 'far fa-id-badge' => 'id badge' ),
					array( 'far fa-id-card-alt' => 'id card alt' ),
					array( 'far fa-id-card' => 'id card' ),
					array( 'far fa-igloo' => 'igloo' ),
					array( 'far fa-image-polaroid' => 'image polaroid' ),
					array( 'far fa-image' => 'image' ),
					array( 'far fa-images' => 'images' ),
					array( 'far fa-inbox-in' => 'inbox in' ),
					array( 'far fa-inbox-out' => 'inbox out' ),
					array( 'far fa-inbox' => 'inbox' ),
					array( 'far fa-indent' => 'indent' ),
					array( 'far fa-industry-alt' => 'industry alt' ),
					array( 'far fa-industry' => 'industry' ),
					array( 'far fa-infinity' => 'infinity' ),
					array( 'far fa-info-circle' => 'info circle' ),
					array( 'far fa-info-square' => 'info square' ),
					array( 'far fa-info' => 'info' ),
					array( 'far fa-inhaler' => 'inhaler' ),
					array( 'far fa-integral' => 'integral' ),
					array( 'far fa-intersection' => 'intersection' ),
					array( 'far fa-inventory' => 'inventory' ),
					array( 'far fa-island-tropical' => 'island tropical' ),
					array( 'far fa-italic' => 'italic' ),
					array( 'far fa-jack-o-lantern' => 'jack o lantern' ),
					array( 'far fa-jedi' => 'jedi' ),
					array( 'far fa-joint' => 'joint' ),
					array( 'far fa-journal-whills' => 'journal whills' ),
					array( 'far fa-joystick' => 'joystick' ),
					array( 'far fa-jug' => 'jug' ),
					array( 'far fa-kaaba' => 'kaaba' ),
					array( 'far fa-kazoo' => 'kazoo' ),
					array( 'far fa-kerning' => 'kerning' ),
					array( 'far fa-key-skeleton' => 'key skeleton' ),
					array( 'far fa-key' => 'key' ),
					array( 'far fa-keyboard' => 'keyboard' ),
					array( 'far fa-keynote' => 'keynote' ),
					array( 'far fa-khanda' => 'khanda' ),
					array( 'far fa-kidneys' => 'kidneys' ),
					array( 'far fa-kiss-beam' => 'kiss beam' ),
					array( 'far fa-kiss-wink-heart' => 'kiss wink heart' ),
					array( 'far fa-kiss' => 'kiss' ),
					array( 'far fa-kite' => 'kite' ),
					array( 'far fa-kiwi-bird' => 'kiwi bird' ),
					array( 'far fa-knife-kitchen' => 'knife kitchen' ),
					array( 'far fa-lambda' => 'lambda' ),
					array( 'far fa-lamp-desk' => 'lamp desk' ),
					array( 'far fa-lamp-floor' => 'lamp floor' ),
					array( 'far fa-lamp' => 'lamp' ),
					array( 'far fa-landmark-alt' => 'landmark alt' ),
					array( 'far fa-landmark' => 'landmark' ),
					array( 'far fa-language' => 'language' ),
					array( 'far fa-laptop-code' => 'laptop code' ),
					array( 'far fa-laptop-house' => 'laptop house' ),
					array( 'far fa-laptop-medical' => 'laptop medical' ),
					array( 'far fa-laptop' => 'laptop' ),
					array( 'far fa-lasso' => 'lasso' ),
					array( 'far fa-laugh-beam' => 'laugh beam' ),
					array( 'far fa-laugh-squint' => 'laugh squint' ),
					array( 'far fa-laugh-wink' => 'laugh wink' ),
					array( 'far fa-laugh' => 'laugh' ),
					array( 'far fa-layer-group' => 'layer group' ),
					array( 'far fa-layer-minus' => 'layer minus' ),
					array( 'far fa-layer-plus' => 'layer plus' ),
					array( 'far fa-leaf-heart' => 'leaf heart' ),
					array( 'far fa-leaf-maple' => 'leaf maple' ),
					array( 'far fa-leaf-oak' => 'leaf oak' ),
					array( 'far fa-leaf' => 'leaf' ),
					array( 'far fa-lemon' => 'lemon' ),
					array( 'far fa-less-than-equal' => 'less than equal' ),
					array( 'far fa-less-than' => 'less than' ),
					array( 'far fa-level-down-alt' => 'level down alt' ),
					array( 'far fa-level-down' => 'level down' ),
					array( 'far fa-level-up-alt' => 'level up alt' ),
					array( 'far fa-level-up' => 'level up' ),
					array( 'far fa-life-ring' => 'life ring' ),
					array( 'far fa-light-ceiling' => 'light ceiling' ),
					array( 'far fa-light-switch-off' => 'light switch off' ),
					array( 'far fa-light-switch-on' => 'light switch on' ),
					array( 'far fa-light-switch' => 'light switch' ),
					array( 'far fa-lightbulb-dollar' => 'lightbulb dollar' ),
					array( 'far fa-lightbulb-exclamation' => 'lightbulb exclamation' ),
					array( 'far fa-lightbulb-on' => 'lightbulb on' ),
					array( 'far fa-lightbulb-slash' => 'lightbulb slash' ),
					array( 'far fa-lightbulb' => 'lightbulb' ),
					array( 'far fa-lights-holiday' => 'lights holiday' ),
					array( 'far fa-line-columns' => 'line columns' ),
					array( 'far fa-line-height' => 'line height' ),
					array( 'far fa-link' => 'link' ),
					array( 'far fa-lips' => 'lips' ),
					array( 'far fa-lira-sign' => 'lira sign' ),
					array( 'far fa-list-alt' => 'list alt' ),
					array( 'far fa-list-music' => 'list music' ),
					array( 'far fa-list-ol' => 'list ol' ),
					array( 'far fa-list-ul' => 'list ul' ),
					array( 'far fa-list' => 'list' ),
					array( 'far fa-location-arrow' => 'location arrow' ),
					array( 'far fa-location-circle' => 'location circle' ),
					array( 'far fa-location-slash' => 'location slash' ),
					array( 'far fa-location' => 'location' ),
					array( 'far fa-lock-alt' => 'lock alt' ),
					array( 'far fa-lock-open-alt' => 'lock open alt' ),
					array( 'far fa-lock-open' => 'lock open' ),
					array( 'far fa-lock' => 'lock' ),
					array( 'far fa-long-arrow-alt-down' => 'long arrow alt down' ),
					array( 'far fa-long-arrow-alt-left' => 'long arrow alt left' ),
					array( 'far fa-long-arrow-alt-right' => 'long arrow alt right' ),
					array( 'far fa-long-arrow-alt-up' => 'long arrow alt up' ),
					array( 'far fa-long-arrow-down' => 'long arrow down' ),
					array( 'far fa-long-arrow-left' => 'long arrow left' ),
					array( 'far fa-long-arrow-right' => 'long arrow right' ),
					array( 'far fa-long-arrow-up' => 'long arrow up' ),
					array( 'far fa-loveseat' => 'loveseat' ),
					array( 'far fa-low-vision' => 'low vision' ),
					array( 'far fa-luchador' => 'luchador' ),
					array( 'far fa-luggage-cart' => 'luggage cart' ),
					array( 'far fa-lungs-virus' => 'lungs virus' ),
					array( 'far fa-lungs' => 'lungs' ),
					array( 'far fa-mace' => 'mace' ),
					array( 'far fa-magic' => 'magic' ),
					array( 'far fa-magnet' => 'magnet' ),
					array( 'far fa-mail-bulk' => 'mail bulk' ),
					array( 'far fa-mailbox' => 'mailbox' ),
					array( 'far fa-male' => 'male' ),
					array( 'far fa-mandolin' => 'mandolin' ),
					array( 'far fa-map-marked-alt' => 'map marked alt' ),
					array( 'far fa-map-marked' => 'map marked' ),
					array( 'far fa-map-marker-alt-slash' => 'map marker alt slash' ),
					array( 'far fa-map-marker-alt' => 'map marker alt' ),
					array( 'far fa-map-marker-check' => 'map marker check' ),
					array( 'far fa-map-marker-edit' => 'map marker edit' ),
					array( 'far fa-map-marker-exclamation' => 'map marker exclamation' ),
					array( 'far fa-map-marker-minus' => 'map marker minus' ),
					array( 'far fa-map-marker-plus' => 'map marker plus' ),
					array( 'far fa-map-marker-question' => 'map marker question' ),
					array( 'far fa-map-marker-slash' => 'map marker slash' ),
					array( 'far fa-map-marker-smile' => 'map marker smile' ),
					array( 'far fa-map-marker-times' => 'map marker times' ),
					array( 'far fa-map-marker' => 'map marker' ),
					array( 'far fa-map-pin' => 'map pin' ),
					array( 'far fa-map-signs' => 'map signs' ),
					array( 'far fa-map' => 'map' ),
					array( 'far fa-marker' => 'marker' ),
					array( 'far fa-mars-double' => 'mars double' ),
					array( 'far fa-mars-stroke-h' => 'mars stroke h' ),
					array( 'far fa-mars-stroke-v' => 'mars stroke v' ),
					array( 'far fa-mars-stroke' => 'mars stroke' ),
					array( 'far fa-mars' => 'mars' ),
					array( 'far fa-mask' => 'mask' ),
					array( 'far fa-meat' => 'meat' ),
					array( 'far fa-medal' => 'medal' ),
					array( 'far fa-medkit' => 'medkit' ),
					array( 'far fa-megaphone' => 'megaphone' ),
					array( 'far fa-meh-blank' => 'meh blank' ),
					array( 'far fa-meh-rolling-eyes' => 'meh rolling eyes' ),
					array( 'far fa-meh' => 'meh' ),
					array( 'far fa-memory' => 'memory' ),
					array( 'far fa-menorah' => 'menorah' ),
					array( 'far fa-mercury' => 'mercury' ),
					array( 'far fa-meteor' => 'meteor' ),
					array( 'far fa-microchip' => 'microchip' ),
					array( 'far fa-microphone-alt-slash' => 'microphone alt slash' ),
					array( 'far fa-microphone-alt' => 'microphone alt' ),
					array( 'far fa-microphone-slash' => 'microphone slash' ),
					array( 'far fa-microphone-stand' => 'microphone stand' ),
					array( 'far fa-microphone' => 'microphone' ),
					array( 'far fa-microscope' => 'microscope' ),
					array( 'far fa-microwave' => 'microwave' ),
					array( 'far fa-mind-share' => 'mind share' ),
					array( 'far fa-minus-circle' => 'minus circle' ),
					array( 'far fa-minus-hexagon' => 'minus hexagon' ),
					array( 'far fa-minus-octagon' => 'minus octagon' ),
					array( 'far fa-minus-square' => 'minus square' ),
					array( 'far fa-minus' => 'minus' ),
					array( 'far fa-mistletoe' => 'mistletoe' ),
					array( 'far fa-mitten' => 'mitten' ),
					array( 'far fa-mobile-alt' => 'mobile alt' ),
					array( 'far fa-mobile-android-alt' => 'mobile android alt' ),
					array( 'far fa-mobile-android' => 'mobile android' ),
					array( 'far fa-mobile' => 'mobile' ),
					array( 'far fa-money-bill-alt' => 'money bill alt' ),
					array( 'far fa-money-bill-wave-alt' => 'money bill wave alt' ),
					array( 'far fa-money-bill-wave' => 'money bill wave' ),
					array( 'far fa-money-bill' => 'money bill' ),
					array( 'far fa-money-check-alt' => 'money check alt' ),
					array( 'far fa-money-check-edit-alt' => 'money check edit alt' ),
					array( 'far fa-money-check-edit' => 'money check edit' ),
					array( 'far fa-money-check' => 'money check' ),
					array( 'far fa-monitor-heart-rate' => 'monitor heart rate' ),
					array( 'far fa-monkey' => 'monkey' ),
					array( 'far fa-monument' => 'monument' ),
					array( 'far fa-moon-cloud' => 'moon cloud' ),
					array( 'far fa-moon-stars' => 'moon stars' ),
					array( 'far fa-moon' => 'moon' ),
					array( 'far fa-mortar-pestle' => 'mortar pestle' ),
					array( 'far fa-mosque' => 'mosque' ),
					array( 'far fa-motorcycle' => 'motorcycle' ),
					array( 'far fa-mountain' => 'mountain' ),
					array( 'far fa-mountains' => 'mountains' ),
					array( 'far fa-mouse-alt' => 'mouse alt' ),
					array( 'far fa-mouse-pointer' => 'mouse pointer' ),
					array( 'far fa-mouse' => 'mouse' ),
					array( 'far fa-mp3-player' => 'mp3 player' ),
					array( 'far fa-mug-hot' => 'mug hot' ),
					array( 'far fa-mug-marshmallows' => 'mug marshmallows' ),
					array( 'far fa-mug-tea' => 'mug tea' ),
					array( 'far fa-mug' => 'mug' ),
					array( 'far fa-music-alt-slash' => 'music alt slash' ),
					array( 'far fa-music-alt' => 'music alt' ),
					array( 'far fa-music-slash' => 'music slash' ),
					array( 'far fa-music' => 'music' ),
					array( 'far fa-narwhal' => 'narwhal' ),
					array( 'far fa-network-wired' => 'network wired' ),
					array( 'far fa-neuter' => 'neuter' ),
					array( 'far fa-newspaper' => 'newspaper' ),
					array( 'far fa-not-equal' => 'not equal' ),
					array( 'far fa-notes-medical' => 'notes medical' ),
					array( 'far fa-object-group' => 'object group' ),
					array( 'far fa-object-ungroup' => 'object ungroup' ),
					array( 'far fa-octagon' => 'octagon' ),
					array( 'far fa-oil-can' => 'oil can' ),
					array( 'far fa-oil-temp' => 'oil temp' ),
					array( 'far fa-om' => 'om' ),
					array( 'far fa-omega' => 'omega' ),
					array( 'far fa-ornament' => 'ornament' ),
					array( 'far fa-otter' => 'otter' ),
					array( 'far fa-outdent' => 'outdent' ),
					array( 'far fa-outlet' => 'outlet' ),
					array( 'far fa-oven' => 'oven' ),
					array( 'far fa-overline' => 'overline' ),
					array( 'far fa-page-break' => 'page break' ),
					array( 'far fa-pager' => 'pager' ),
					array( 'far fa-paint-brush-alt' => 'paint brush alt' ),
					array( 'far fa-paint-brush' => 'paint brush' ),
					array( 'far fa-paint-roller' => 'paint roller' ),
					array( 'far fa-palette' => 'palette' ),
					array( 'far fa-pallet-alt' => 'pallet alt' ),
					array( 'far fa-pallet' => 'pallet' ),
					array( 'far fa-paper-plane' => 'paper plane' ),
					array( 'far fa-paperclip' => 'paperclip' ),
					array( 'far fa-parachute-box' => 'parachute box' ),
					array( 'far fa-paragraph-rtl' => 'paragraph rtl' ),
					array( 'far fa-paragraph' => 'paragraph' ),
					array( 'far fa-parking-circle-slash' => 'parking circle slash' ),
					array( 'far fa-parking-circle' => 'parking circle' ),
					array( 'far fa-parking-slash' => 'parking slash' ),
					array( 'far fa-parking' => 'parking' ),
					array( 'far fa-passport' => 'passport' ),
					array( 'far fa-pastafarianism' => 'pastafarianism' ),
					array( 'far fa-paste' => 'paste' ),
					array( 'far fa-pause-circle' => 'pause circle' ),
					array( 'far fa-pause' => 'pause' ),
					array( 'far fa-paw-alt' => 'paw alt' ),
					array( 'far fa-paw-claws' => 'paw claws' ),
					array( 'far fa-paw' => 'paw' ),
					array( 'far fa-peace' => 'peace' ),
					array( 'far fa-pegasus' => 'pegasus' ),
					array( 'far fa-pen-alt' => 'pen alt' ),
					array( 'far fa-pen-fancy' => 'pen fancy' ),
					array( 'far fa-pen-nib' => 'pen nib' ),
					array( 'far fa-pen-square' => 'pen square' ),
					array( 'far fa-pen' => 'pen' ),
					array( 'far fa-pencil-alt' => 'pencil alt' ),
					array( 'far fa-pencil-paintbrush' => 'pencil paintbrush' ),
					array( 'far fa-pencil-ruler' => 'pencil ruler' ),
					array( 'far fa-pencil' => 'pencil' ),
					array( 'far fa-pennant' => 'pennant' ),
					array( 'far fa-people-arrows' => 'people arrows' ),
					array( 'far fa-people-carry' => 'people carry' ),
					array( 'far fa-pepper-hot' => 'pepper hot' ),
					array( 'far fa-percent' => 'percent' ),
					array( 'far fa-percentage' => 'percentage' ),
					array( 'far fa-person-booth' => 'person booth' ),
					array( 'far fa-person-carry' => 'person carry' ),
					array( 'far fa-person-dolly-empty' => 'person dolly empty' ),
					array( 'far fa-person-dolly' => 'person dolly' ),
					array( 'far fa-person-sign' => 'person sign' ),
					array( 'far fa-phone-alt' => 'phone alt' ),
					array( 'far fa-phone-laptop' => 'phone laptop' ),
					array( 'far fa-phone-office' => 'phone office' ),
					array( 'far fa-phone-plus' => 'phone plus' ),
					array( 'far fa-phone-rotary' => 'phone rotary' ),
					array( 'far fa-phone-slash' => 'phone slash' ),
					array( 'far fa-phone-square-alt' => 'phone square alt' ),
					array( 'far fa-phone-square' => 'phone square' ),
					array( 'far fa-phone-volume' => 'phone volume' ),
					array( 'far fa-phone' => 'phone' ),
					array( 'far fa-photo-video' => 'photo video' ),
					array( 'far fa-pi' => 'pi' ),
					array( 'far fa-piano-keyboard' => 'piano keyboard' ),
					array( 'far fa-piano' => 'piano' ),
					array( 'far fa-pie' => 'pie' ),
					array( 'far fa-pig' => 'pig' ),
					array( 'far fa-piggy-bank' => 'piggy bank' ),
					array( 'far fa-pills' => 'pills' ),
					array( 'far fa-pizza-slice' => 'pizza slice' ),
					array( 'far fa-pizza' => 'pizza' ),
					array( 'far fa-place-of-worship' => 'place of worship' ),
					array( 'far fa-plane-alt' => 'plane alt' ),
					array( 'far fa-plane-arrival' => 'plane arrival' ),
					array( 'far fa-plane-departure' => 'plane departure' ),
					array( 'far fa-plane-slash' => 'plane slash' ),
					array( 'far fa-plane' => 'plane' ),
					array( 'far fa-planet-moon' => 'planet moon' ),
					array( 'far fa-planet-ringed' => 'planet ringed' ),
					array( 'far fa-play-circle' => 'play circle' ),
					array( 'far fa-play' => 'play' ),
					array( 'far fa-plug' => 'plug' ),
					array( 'far fa-plus-circle' => 'plus circle' ),
					array( 'far fa-plus-hexagon' => 'plus hexagon' ),
					array( 'far fa-plus-octagon' => 'plus octagon' ),
					array( 'far fa-plus-square' => 'plus square' ),
					array( 'far fa-plus' => 'plus' ),
					array( 'far fa-podcast' => 'podcast' ),
					array( 'far fa-podium-star' => 'podium star' ),
					array( 'far fa-podium' => 'podium' ),
					array( 'far fa-police-box' => 'police box' ),
					array( 'far fa-poll-h' => 'poll h' ),
					array( 'far fa-poll-people' => 'poll people' ),
					array( 'far fa-poll' => 'poll' ),
					array( 'far fa-poo-storm' => 'poo storm' ),
					array( 'far fa-poo' => 'poo' ),
					array( 'far fa-poop' => 'poop' ),
					array( 'far fa-popcorn' => 'popcorn' ),
					array( 'far fa-portal-enter' => 'portal enter' ),
					array( 'far fa-portal-exit' => 'portal exit' ),
					array( 'far fa-portrait' => 'portrait' ),
					array( 'far fa-pound-sign' => 'pound sign' ),
					array( 'far fa-power-off' => 'power off' ),
					array( 'far fa-pray' => 'pray' ),
					array( 'far fa-praying-hands' => 'praying hands' ),
					array( 'far fa-prescription-bottle-alt' => 'prescription bottle alt' ),
					array( 'far fa-prescription-bottle' => 'prescription bottle' ),
					array( 'far fa-prescription' => 'prescription' ),
					array( 'far fa-presentation' => 'presentation' ),
					array( 'far fa-print-search' => 'print search' ),
					array( 'far fa-print-slash' => 'print slash' ),
					array( 'far fa-print' => 'print' ),
					array( 'far fa-procedures' => 'procedures' ),
					array( 'far fa-project-diagram' => 'project diagram' ),
					array( 'far fa-projector' => 'projector' ),
					array( 'far fa-pump-medical' => 'pump medical' ),
					array( 'far fa-pump-soap' => 'pump soap' ),
					array( 'far fa-pumpkin' => 'pumpkin' ),
					array( 'far fa-puzzle-piece' => 'puzzle piece' ),
					array( 'far fa-qrcode' => 'qrcode' ),
					array( 'far fa-question-circle' => 'question circle' ),
					array( 'far fa-question-square' => 'question square' ),
					array( 'far fa-question' => 'question' ),
					array( 'far fa-quidditch' => 'quidditch' ),
					array( 'far fa-quote-left' => 'quote left' ),
					array( 'far fa-quote-right' => 'quote right' ),
					array( 'far fa-quran' => 'quran' ),
					array( 'far fa-rabbit-fast' => 'rabbit fast' ),
					array( 'far fa-rabbit' => 'rabbit' ),
					array( 'far fa-racquet' => 'racquet' ),
					array( 'far fa-radar' => 'radar' ),
					array( 'far fa-radiation-alt' => 'radiation alt' ),
					array( 'far fa-radiation' => 'radiation' ),
					array( 'far fa-radio-alt' => 'radio alt' ),
					array( 'far fa-radio' => 'radio' ),
					array( 'far fa-rainbow' => 'rainbow' ),
					array( 'far fa-raindrops' => 'raindrops' ),
					array( 'far fa-ram' => 'ram' ),
					array( 'far fa-ramp-loading' => 'ramp loading' ),
					array( 'far fa-random' => 'random' ),
					array( 'far fa-raygun' => 'raygun' ),
					array( 'far fa-receipt' => 'receipt' ),
					array( 'far fa-record-vinyl' => 'record vinyl' ),
					array( 'far fa-rectangle-landscape' => 'rectangle landscape' ),
					array( 'far fa-rectangle-portrait' => 'rectangle portrait' ),
					array( 'far fa-rectangle-wide' => 'rectangle wide' ),
					array( 'far fa-recycle' => 'recycle' ),
					array( 'far fa-redo-alt' => 'redo alt' ),
					array( 'far fa-redo' => 'redo' ),
					array( 'far fa-refrigerator' => 'refrigerator' ),
					array( 'far fa-registered' => 'registered' ),
					array( 'far fa-remove-format' => 'remove format' ),
					array( 'far fa-repeat-1-alt' => 'repeat 1 alt' ),
					array( 'far fa-repeat-1' => 'repeat 1' ),
					array( 'far fa-repeat-alt' => 'repeat alt' ),
					array( 'far fa-repeat' => 'repeat' ),
					array( 'far fa-reply-all' => 'reply all' ),
					array( 'far fa-reply' => 'reply' ),
					array( 'far fa-republican' => 'republican' ),
					array( 'far fa-restroom' => 'restroom' ),
					array( 'far fa-retweet-alt' => 'retweet alt' ),
					array( 'far fa-retweet' => 'retweet' ),
					array( 'far fa-ribbon' => 'ribbon' ),
					array( 'far fa-ring' => 'ring' ),
					array( 'far fa-rings-wedding' => 'rings wedding' ),
					array( 'far fa-road' => 'road' ),
					array( 'far fa-robot' => 'robot' ),
					array( 'far fa-rocket-launch' => 'rocket launch' ),
					array( 'far fa-rocket' => 'rocket' ),
					array( 'far fa-route-highway' => 'route highway' ),
					array( 'far fa-route-interstate' => 'route interstate' ),
					array( 'far fa-route' => 'route' ),
					array( 'far fa-router' => 'router' ),
					array( 'far fa-rss-square' => 'rss square' ),
					array( 'far fa-rss' => 'rss' ),
					array( 'far fa-ruble-sign' => 'ruble sign' ),
					array( 'far fa-ruler-combined' => 'ruler combined' ),
					array( 'far fa-ruler-horizontal' => 'ruler horizontal' ),
					array( 'far fa-ruler-triangle' => 'ruler triangle' ),
					array( 'far fa-ruler-vertical' => 'ruler vertical' ),
					array( 'far fa-ruler' => 'ruler' ),
					array( 'far fa-running' => 'running' ),
					array( 'far fa-rupee-sign' => 'rupee sign' ),
					array( 'far fa-rv' => 'rv' ),
					array( 'far fa-sack-dollar' => 'sack dollar' ),
					array( 'far fa-sack' => 'sack' ),
					array( 'far fa-sad-cry' => 'sad cry' ),
					array( 'far fa-sad-tear' => 'sad tear' ),
					array( 'far fa-salad' => 'salad' ),
					array( 'far fa-sandwich' => 'sandwich' ),
					array( 'far fa-satellite-dish' => 'satellite dish' ),
					array( 'far fa-satellite' => 'satellite' ),
					array( 'far fa-sausage' => 'sausage' ),
					array( 'far fa-save' => 'save' ),
					array( 'far fa-sax-hot' => 'sax hot' ),
					array( 'far fa-saxophone' => 'saxophone' ),
					array( 'far fa-scalpel-path' => 'scalpel path' ),
					array( 'far fa-scalpel' => 'scalpel' ),
					array( 'far fa-scanner-image' => 'scanner image' ),
					array( 'far fa-scanner-keyboard' => 'scanner keyboard' ),
					array( 'far fa-scanner-touchscreen' => 'scanner touchscreen' ),
					array( 'far fa-scanner' => 'scanner' ),
					array( 'far fa-scarecrow' => 'scarecrow' ),
					array( 'far fa-scarf' => 'scarf' ),
					array( 'far fa-school' => 'school' ),
					array( 'far fa-screwdriver' => 'screwdriver' ),
					array( 'far fa-scroll-old' => 'scroll old' ),
					array( 'far fa-scroll' => 'scroll' ),
					array( 'far fa-scrubber' => 'scrubber' ),
					array( 'far fa-scythe' => 'scythe' ),
					array( 'far fa-sd-card' => 'sd card' ),
					array( 'far fa-search-dollar' => 'search dollar' ),
					array( 'far fa-search-location' => 'search location' ),
					array( 'far fa-search-minus' => 'search minus' ),
					array( 'far fa-search-plus' => 'search plus' ),
					array( 'far fa-search' => 'search' ),
					array( 'far fa-seedling' => 'seedling' ),
					array( 'far fa-send-back' => 'send back' ),
					array( 'far fa-send-backward' => 'send backward' ),
					array( 'far fa-sensor-alert' => 'sensor alert' ),
					array( 'far fa-sensor-fire' => 'sensor fire' ),
					array( 'far fa-sensor-on' => 'sensor on' ),
					array( 'far fa-sensor-smoke' => 'sensor smoke' ),
					array( 'far fa-sensor' => 'sensor' ),
					array( 'far fa-server' => 'server' ),
					array( 'far fa-shapes' => 'shapes' ),
					array( 'far fa-share-all' => 'share all' ),
					array( 'far fa-share-alt-square' => 'share alt square' ),
					array( 'far fa-share-alt' => 'share alt' ),
					array( 'far fa-share-square' => 'share square' ),
					array( 'far fa-share' => 'share' ),
					array( 'far fa-sheep' => 'sheep' ),
					array( 'far fa-shekel-sign' => 'shekel sign' ),
					array( 'far fa-shield-alt' => 'shield alt' ),
					array( 'far fa-shield-check' => 'shield check' ),
					array( 'far fa-shield-cross' => 'shield cross' ),
					array( 'far fa-shield-virus' => 'shield virus' ),
					array( 'far fa-shield' => 'shield' ),
					array( 'far fa-ship' => 'ship' ),
					array( 'far fa-shipping-fast' => 'shipping fast' ),
					array( 'far fa-shipping-timed' => 'shipping timed' ),
					array( 'far fa-shish-kebab' => 'shish kebab' ),
					array( 'far fa-shoe-prints' => 'shoe prints' ),
					array( 'far fa-shopping-bag' => 'shopping bag' ),
					array( 'far fa-shopping-basket' => 'shopping basket' ),
					array( 'far fa-shopping-cart' => 'shopping cart' ),
					array( 'far fa-shovel-snow' => 'shovel snow' ),
					array( 'far fa-shovel' => 'shovel' ),
					array( 'far fa-shower' => 'shower' ),
					array( 'far fa-shredder' => 'shredder' ),
					array( 'far fa-shuttle-van' => 'shuttle van' ),
					array( 'far fa-shuttlecock' => 'shuttlecock' ),
					array( 'far fa-sickle' => 'sickle' ),
					array( 'far fa-sigma' => 'sigma' ),
					array( 'far fa-sign-in-alt' => 'sign in alt' ),
					array( 'far fa-sign-in' => 'sign in' ),
					array( 'far fa-sign-language' => 'sign language' ),
					array( 'far fa-sign-out-alt' => 'sign out alt' ),
					array( 'far fa-sign-out' => 'sign out' ),
					array( 'far fa-sign' => 'sign' ),
					array( 'far fa-signal-1' => 'signal 1' ),
					array( 'far fa-signal-2' => 'signal 2' ),
					array( 'far fa-signal-3' => 'signal 3' ),
					array( 'far fa-signal-4' => 'signal 4' ),
					array( 'far fa-signal-alt-1' => 'signal alt 1' ),
					array( 'far fa-signal-alt-2' => 'signal alt 2' ),
					array( 'far fa-signal-alt-3' => 'signal alt 3' ),
					array( 'far fa-signal-alt-slash' => 'signal alt slash' ),
					array( 'far fa-signal-alt' => 'signal alt' ),
					array( 'far fa-signal-slash' => 'signal slash' ),
					array( 'far fa-signal-stream' => 'signal stream' ),
					array( 'far fa-signal' => 'signal' ),
					array( 'far fa-signature' => 'signature' ),
					array( 'far fa-sim-card' => 'sim card' ),
					array( 'far fa-sink' => 'sink' ),
					array( 'far fa-siren-on' => 'siren on' ),
					array( 'far fa-siren' => 'siren' ),
					array( 'far fa-sitemap' => 'sitemap' ),
					array( 'far fa-skating' => 'skating' ),
					array( 'far fa-skeleton' => 'skeleton' ),
					array( 'far fa-ski-jump' => 'ski jump' ),
					array( 'far fa-ski-lift' => 'ski lift' ),
					array( 'far fa-skiing-nordic' => 'skiing nordic' ),
					array( 'far fa-skiing' => 'skiing' ),
					array( 'far fa-skull-cow' => 'skull cow' ),
					array( 'far fa-skull-crossbones' => 'skull crossbones' ),
					array( 'far fa-skull' => 'skull' ),
					array( 'far fa-slash' => 'slash' ),
					array( 'far fa-sledding' => 'sledding' ),
					array( 'far fa-sleigh' => 'sleigh' ),
					array( 'far fa-sliders-h-square' => 'sliders h square' ),
					array( 'far fa-sliders-h' => 'sliders h' ),
					array( 'far fa-sliders-v-square' => 'sliders v square' ),
					array( 'far fa-sliders-v' => 'sliders v' ),
					array( 'far fa-smile-beam' => 'smile beam' ),
					array( 'far fa-smile-plus' => 'smile plus' ),
					array( 'far fa-smile-wink' => 'smile wink' ),
					array( 'far fa-smile' => 'smile' ),
					array( 'far fa-smog' => 'smog' ),
					array( 'far fa-smoke' => 'smoke' ),
					array( 'far fa-smoking-ban' => 'smoking ban' ),
					array( 'far fa-smoking' => 'smoking' ),
					array( 'far fa-sms' => 'sms' ),
					array( 'far fa-snake' => 'snake' ),
					array( 'far fa-snooze' => 'snooze' ),
					array( 'far fa-snow-blowing' => 'snow blowing' ),
					array( 'far fa-snowboarding' => 'snowboarding' ),
					array( 'far fa-snowflake' => 'snowflake' ),
					array( 'far fa-snowflakes' => 'snowflakes' ),
					array( 'far fa-snowman' => 'snowman' ),
					array( 'far fa-snowmobile' => 'snowmobile' ),
					array( 'far fa-snowplow' => 'snowplow' ),
					array( 'far fa-soap' => 'soap' ),
					array( 'far fa-socks' => 'socks' ),
					array( 'far fa-solar-panel' => 'solar panel' ),
					array( 'far fa-solar-system' => 'solar system' ),
					array( 'far fa-sort-alpha-down-alt' => 'sort alpha down alt' ),
					array( 'far fa-sort-alpha-down' => 'sort alpha down' ),
					array( 'far fa-sort-alpha-up-alt' => 'sort alpha up alt' ),
					array( 'far fa-sort-alpha-up' => 'sort alpha up' ),
					array( 'far fa-sort-alt' => 'sort alt' ),
					array( 'far fa-sort-amount-down-alt' => 'sort amount down alt' ),
					array( 'far fa-sort-amount-down' => 'sort amount down' ),
					array( 'far fa-sort-amount-up-alt' => 'sort amount up alt' ),
					array( 'far fa-sort-amount-up' => 'sort amount up' ),
					array( 'far fa-sort-circle-down' => 'sort circle down' ),
					array( 'far fa-sort-circle-up' => 'sort circle up' ),
					array( 'far fa-sort-circle' => 'sort circle' ),
					array( 'far fa-sort-down' => 'sort down' ),
					array( 'far fa-sort-numeric-down-alt' => 'sort numeric down alt' ),
					array( 'far fa-sort-numeric-down' => 'sort numeric down' ),
					array( 'far fa-sort-numeric-up-alt' => 'sort numeric up alt' ),
					array( 'far fa-sort-numeric-up' => 'sort numeric up' ),
					array( 'far fa-sort-shapes-down-alt' => 'sort shapes down alt' ),
					array( 'far fa-sort-shapes-down' => 'sort shapes down' ),
					array( 'far fa-sort-shapes-up-alt' => 'sort shapes up alt' ),
					array( 'far fa-sort-shapes-up' => 'sort shapes up' ),
					array( 'far fa-sort-size-down-alt' => 'sort size down alt' ),
					array( 'far fa-sort-size-down' => 'sort size down' ),
					array( 'far fa-sort-size-up-alt' => 'sort size up alt' ),
					array( 'far fa-sort-size-up' => 'sort size up' ),
					array( 'far fa-sort-up' => 'sort up' ),
					array( 'far fa-sort' => 'sort' ),
					array( 'far fa-soup' => 'soup' ),
					array( 'far fa-spa' => 'spa' ),
					array( 'far fa-space-shuttle' => 'space shuttle' ),
					array( 'far fa-space-station-moon-alt' => 'space station moon alt' ),
					array( 'far fa-space-station-moon' => 'space station moon' ),
					array( 'far fa-spade' => 'spade' ),
					array( 'far fa-sparkles' => 'sparkles' ),
					array( 'far fa-speaker' => 'speaker' ),
					array( 'far fa-speakers' => 'speakers' ),
					array( 'far fa-spell-check' => 'spell check' ),
					array( 'far fa-spider-black-widow' => 'spider black widow' ),
					array( 'far fa-spider-web' => 'spider web' ),
					array( 'far fa-spider' => 'spider' ),
					array( 'far fa-spinner-third' => 'spinner third' ),
					array( 'far fa-spinner' => 'spinner' ),
					array( 'far fa-splotch' => 'splotch' ),
					array( 'far fa-spray-can' => 'spray can' ),
					array( 'far fa-sprinkler' => 'sprinkler' ),
					array( 'far fa-square-full' => 'square full' ),
					array( 'far fa-square-root-alt' => 'square root alt' ),
					array( 'far fa-square-root' => 'square root' ),
					array( 'far fa-square' => 'square' ),
					array( 'far fa-squirrel' => 'squirrel' ),
					array( 'far fa-staff' => 'staff' ),
					array( 'far fa-stamp' => 'stamp' ),
					array( 'far fa-star-and-crescent' => 'star and crescent' ),
					array( 'far fa-star-christmas' => 'star christmas' ),
					array( 'far fa-star-exclamation' => 'star exclamation' ),
					array( 'far fa-star-half-alt' => 'star half alt' ),
					array( 'far fa-star-half' => 'star half' ),
					array( 'far fa-star-of-david' => 'star of david' ),
					array( 'far fa-star-of-life' => 'star of life' ),
					array( 'far fa-star-shooting' => 'star shooting' ),
					array( 'far fa-star' => 'star' ),
					array( 'far fa-starfighter-alt' => 'starfighter alt' ),
					array( 'far fa-starfighter' => 'starfighter' ),
					array( 'far fa-stars' => 'stars' ),
					array( 'far fa-starship-freighter' => 'starship freighter' ),
					array( 'far fa-starship' => 'starship' ),
					array( 'far fa-steak' => 'steak' ),
					array( 'far fa-steering-wheel' => 'steering wheel' ),
					array( 'far fa-step-backward' => 'step backward' ),
					array( 'far fa-step-forward' => 'step forward' ),
					array( 'far fa-stethoscope' => 'stethoscope' ),
					array( 'far fa-sticky-note' => 'sticky note' ),
					array( 'far fa-stocking' => 'stocking' ),
					array( 'far fa-stomach' => 'stomach' ),
					array( 'far fa-stop-circle' => 'stop circle' ),
					array( 'far fa-stop' => 'stop' ),
					array( 'far fa-stopwatch-20' => 'stopwatch 20' ),
					array( 'far fa-stopwatch' => 'stopwatch' ),
					array( 'far fa-store-alt-slash' => 'store alt slash' ),
					array( 'far fa-store-alt' => 'store alt' ),
					array( 'far fa-store-slash' => 'store slash' ),
					array( 'far fa-store' => 'store' ),
					array( 'far fa-stream' => 'stream' ),
					array( 'far fa-street-view' => 'street view' ),
					array( 'far fa-stretcher' => 'stretcher' ),
					array( 'far fa-strikethrough' => 'strikethrough' ),
					array( 'far fa-stroopwafel' => 'stroopwafel' ),
					array( 'far fa-subscript' => 'subscript' ),
					array( 'far fa-subway' => 'subway' ),
					array( 'far fa-suitcase-rolling' => 'suitcase rolling' ),
					array( 'far fa-suitcase' => 'suitcase' ),
					array( 'far fa-sun-cloud' => 'sun cloud' ),
					array( 'far fa-sun-dust' => 'sun dust' ),
					array( 'far fa-sun-haze' => 'sun haze' ),
					array( 'far fa-sun' => 'sun' ),
					array( 'far fa-sunglasses' => 'sunglasses' ),
					array( 'far fa-sunrise' => 'sunrise' ),
					array( 'far fa-sunset' => 'sunset' ),
					array( 'far fa-superscript' => 'superscript' ),
					array( 'far fa-surprise' => 'surprise' ),
					array( 'far fa-swatchbook' => 'swatchbook' ),
					array( 'far fa-swimmer' => 'swimmer' ),
					array( 'far fa-swimming-pool' => 'swimming pool' ),
					array( 'far fa-sword-laser-alt' => 'sword laser alt' ),
					array( 'far fa-sword-laser' => 'sword laser' ),
					array( 'far fa-sword' => 'sword' ),
					array( 'far fa-swords-laser' => 'swords laser' ),
					array( 'far fa-swords' => 'swords' ),
					array( 'far fa-synagogue' => 'synagogue' ),
					array( 'far fa-sync-alt' => 'sync alt' ),
					array( 'far fa-sync' => 'sync' ),
					array( 'far fa-syringe' => 'syringe' ),
					array( 'far fa-table-tennis' => 'table tennis' ),
					array( 'far fa-table' => 'table' ),
					array( 'far fa-tablet-alt' => 'tablet alt' ),
					array( 'far fa-tablet-android-alt' => 'tablet android alt' ),
					array( 'far fa-tablet-android' => 'tablet android' ),
					array( 'far fa-tablet-rugged' => 'tablet rugged' ),
					array( 'far fa-tablet' => 'tablet' ),
					array( 'far fa-tablets' => 'tablets' ),
					array( 'far fa-tachometer-alt-average' => 'tachometer alt average' ),
					array( 'far fa-tachometer-alt-fast' => 'tachometer alt fast' ),
					array( 'far fa-tachometer-alt-fastest' => 'tachometer alt fastest' ),
					array( 'far fa-tachometer-alt-slow' => 'tachometer alt slow' ),
					array( 'far fa-tachometer-alt-slowest' => 'tachometer alt slowest' ),
					array( 'far fa-tachometer-alt' => 'tachometer alt' ),
					array( 'far fa-tachometer-average' => 'tachometer average' ),
					array( 'far fa-tachometer-fast' => 'tachometer fast' ),
					array( 'far fa-tachometer-fastest' => 'tachometer fastest' ),
					array( 'far fa-tachometer-slow' => 'tachometer slow' ),
					array( 'far fa-tachometer-slowest' => 'tachometer slowest' ),
					array( 'far fa-tachometer' => 'tachometer' ),
					array( 'far fa-taco' => 'taco' ),
					array( 'far fa-tag' => 'tag' ),
					array( 'far fa-tags' => 'tags' ),
					array( 'far fa-tally' => 'tally' ),
					array( 'far fa-tanakh' => 'tanakh' ),
					array( 'far fa-tape' => 'tape' ),
					array( 'far fa-tasks-alt' => 'tasks alt' ),
					array( 'far fa-tasks' => 'tasks' ),
					array( 'far fa-taxi' => 'taxi' ),
					array( 'far fa-teeth-open' => 'teeth open' ),
					array( 'far fa-teeth' => 'teeth' ),
					array( 'far fa-telescope' => 'telescope' ),
					array( 'far fa-temperature-down' => 'temperature down' ),
					array( 'far fa-temperature-frigid' => 'temperature frigid' ),
					array( 'far fa-temperature-high' => 'temperature high' ),
					array( 'far fa-temperature-hot' => 'temperature hot' ),
					array( 'far fa-temperature-low' => 'temperature low' ),
					array( 'far fa-temperature-up' => 'temperature up' ),
					array( 'far fa-tenge' => 'tenge' ),
					array( 'far fa-tennis-ball' => 'tennis ball' ),
					array( 'far fa-terminal' => 'terminal' ),
					array( 'far fa-text-height' => 'text height' ),
					array( 'far fa-text-size' => 'text size' ),
					array( 'far fa-text-width' => 'text width' ),
					array( 'far fa-text' => 'text' ),
					array( 'far fa-th-large' => 'th large' ),
					array( 'far fa-th-list' => 'th list' ),
					array( 'far fa-th' => 'th' ),
					array( 'far fa-theater-masks' => 'theater masks' ),
					array( 'far fa-thermometer-empty' => 'thermometer empty' ),
					array( 'far fa-thermometer-full' => 'thermometer full' ),
					array( 'far fa-thermometer-half' => 'thermometer half' ),
					array( 'far fa-thermometer-quarter' => 'thermometer quarter' ),
					array( 'far fa-thermometer-three-quarters' => 'thermometer three quarters' ),
					array( 'far fa-thermometer' => 'thermometer' ),
					array( 'far fa-theta' => 'theta' ),
					array( 'far fa-thumbs-down' => 'thumbs down' ),
					array( 'far fa-thumbs-up' => 'thumbs up' ),
					array( 'far fa-thumbtack' => 'thumbtack' ),
					array( 'far fa-thunderstorm-moon' => 'thunderstorm moon' ),
					array( 'far fa-thunderstorm-sun' => 'thunderstorm sun' ),
					array( 'far fa-thunderstorm' => 'thunderstorm' ),
					array( 'far fa-ticket-alt' => 'ticket alt' ),
					array( 'far fa-ticket' => 'ticket' ),
					array( 'far fa-tilde' => 'tilde' ),
					array( 'far fa-times-circle' => 'times circle' ),
					array( 'far fa-times-hexagon' => 'times hexagon' ),
					array( 'far fa-times-octagon' => 'times octagon' ),
					array( 'far fa-times-square' => 'times square' ),
					array( 'far fa-times' => 'times' ),
					array( 'far fa-tint-slash' => 'tint slash' ),
					array( 'far fa-tint' => 'tint' ),
					array( 'far fa-tire-flat' => 'tire flat' ),
					array( 'far fa-tire-pressure-warning' => 'tire pressure warning' ),
					array( 'far fa-tire-rugged' => 'tire rugged' ),
					array( 'far fa-tire' => 'tire' ),
					array( 'far fa-tired' => 'tired' ),
					array( 'far fa-toggle-off' => 'toggle off' ),
					array( 'far fa-toggle-on' => 'toggle on' ),
					array( 'far fa-toilet-paper-alt' => 'toilet paper alt' ),
					array( 'far fa-toilet-paper-slash' => 'toilet paper slash' ),
					array( 'far fa-toilet-paper' => 'toilet paper' ),
					array( 'far fa-toilet' => 'toilet' ),
					array( 'far fa-tombstone-alt' => 'tombstone alt' ),
					array( 'far fa-tombstone' => 'tombstone' ),
					array( 'far fa-toolbox' => 'toolbox' ),
					array( 'far fa-tools' => 'tools' ),
					array( 'far fa-tooth' => 'tooth' ),
					array( 'far fa-toothbrush' => 'toothbrush' ),
					array( 'far fa-torah' => 'torah' ),
					array( 'far fa-torii-gate' => 'torii gate' ),
					array( 'far fa-tornado' => 'tornado' ),
					array( 'far fa-tractor' => 'tractor' ),
					array( 'far fa-trademark' => 'trademark' ),
					array( 'far fa-traffic-cone' => 'traffic cone' ),
					array( 'far fa-traffic-light-go' => 'traffic light go' ),
					array( 'far fa-traffic-light-slow' => 'traffic light slow' ),
					array( 'far fa-traffic-light-stop' => 'traffic light stop' ),
					array( 'far fa-traffic-light' => 'traffic light' ),
					array( 'far fa-trailer' => 'trailer' ),
					array( 'far fa-train' => 'train' ),
					array( 'far fa-tram' => 'tram' ),
					array( 'far fa-transgender-alt' => 'transgender alt' ),
					array( 'far fa-transgender' => 'transgender' ),
					array( 'far fa-transporter-1' => 'transporter 1' ),
					array( 'far fa-transporter-2' => 'transporter 2' ),
					array( 'far fa-transporter-3' => 'transporter 3' ),
					array( 'far fa-transporter-empty' => 'transporter empty' ),
					array( 'far fa-transporter' => 'transporter' ),
					array( 'far fa-trash-alt' => 'trash alt' ),
					array( 'far fa-trash-restore-alt' => 'trash restore alt' ),
					array( 'far fa-trash-restore' => 'trash restore' ),
					array( 'far fa-trash-undo-alt' => 'trash undo alt' ),
					array( 'far fa-trash-undo' => 'trash undo' ),
					array( 'far fa-trash' => 'trash' ),
					array( 'far fa-treasure-chest' => 'treasure chest' ),
					array( 'far fa-tree-alt' => 'tree alt' ),
					array( 'far fa-tree-christmas' => 'tree christmas' ),
					array( 'far fa-tree-decorated' => 'tree decorated' ),
					array( 'far fa-tree-large' => 'tree large' ),
					array( 'far fa-tree-palm' => 'tree palm' ),
					array( 'far fa-tree' => 'tree' ),
					array( 'far fa-trees' => 'trees' ),
					array( 'far fa-triangle-music' => 'triangle music' ),
					array( 'far fa-triangle' => 'triangle' ),
					array( 'far fa-trophy-alt' => 'trophy alt' ),
					array( 'far fa-trophy' => 'trophy' ),
					array( 'far fa-truck-container' => 'truck container' ),
					array( 'far fa-truck-couch' => 'truck couch' ),
					array( 'far fa-truck-loading' => 'truck loading' ),
					array( 'far fa-truck-monster' => 'truck monster' ),
					array( 'far fa-truck-moving' => 'truck moving' ),
					array( 'far fa-truck-pickup' => 'truck pickup' ),
					array( 'far fa-truck-plow' => 'truck plow' ),
					array( 'far fa-truck-ramp' => 'truck ramp' ),
					array( 'far fa-truck' => 'truck' ),
					array( 'far fa-trumpet' => 'trumpet' ),
					array( 'far fa-tshirt' => 'tshirt' ),
					array( 'far fa-tty' => 'tty' ),
					array( 'far fa-turkey' => 'turkey' ),
					array( 'far fa-turntable' => 'turntable' ),
					array( 'far fa-turtle' => 'turtle' ),
					array( 'far fa-tv-alt' => 'tv alt' ),
					array( 'far fa-tv-music' => 'tv music' ),
					array( 'far fa-tv-retro' => 'tv retro' ),
					array( 'far fa-tv' => 'tv' ),
					array( 'far fa-typewriter' => 'typewriter' ),
					array( 'far fa-ufo-beam' => 'ufo beam' ),
					array( 'far fa-ufo' => 'ufo' ),
					array( 'far fa-umbrella-beach' => 'umbrella beach' ),
					array( 'far fa-umbrella' => 'umbrella' ),
					array( 'far fa-underline' => 'underline' ),
					array( 'far fa-undo-alt' => 'undo alt' ),
					array( 'far fa-undo' => 'undo' ),
					array( 'far fa-unicorn' => 'unicorn' ),
					array( 'far fa-union' => 'union' ),
					array( 'far fa-universal-access' => 'universal access' ),
					array( 'far fa-university' => 'university' ),
					array( 'far fa-unlink' => 'unlink' ),
					array( 'far fa-unlock-alt' => 'unlock alt' ),
					array( 'far fa-unlock' => 'unlock' ),
					array( 'far fa-upload' => 'upload' ),
					array( 'far fa-usb-drive' => 'usb drive' ),
					array( 'far fa-usd-circle' => 'usd circle' ),
					array( 'far fa-usd-square' => 'usd square' ),
					array( 'far fa-user-alien' => 'user alien' ),
					array( 'far fa-user-alt-slash' => 'user alt slash' ),
					array( 'far fa-user-alt' => 'user alt' ),
					array( 'far fa-user-astronaut' => 'user astronaut' ),
					array( 'far fa-user-chart' => 'user chart' ),
					array( 'far fa-user-check' => 'user check' ),
					array( 'far fa-user-circle' => 'user circle' ),
					array( 'far fa-user-clock' => 'user clock' ),
					array( 'far fa-user-cog' => 'user cog' ),
					array( 'far fa-user-cowboy' => 'user cowboy' ),
					array( 'far fa-user-crown' => 'user crown' ),
					array( 'far fa-user-edit' => 'user edit' ),
					array( 'far fa-user-friends' => 'user friends' ),
					array( 'far fa-user-graduate' => 'user graduate' ),
					array( 'far fa-user-hard-hat' => 'user hard hat' ),
					array( 'far fa-user-headset' => 'user headset' ),
					array( 'far fa-user-injured' => 'user injured' ),
					array( 'far fa-user-lock' => 'user lock' ),
					array( 'far fa-user-md-chat' => 'user md chat' ),
					array( 'far fa-user-md' => 'user md' ),
					array( 'far fa-user-minus' => 'user minus' ),
					array( 'far fa-user-music' => 'user music' ),
					array( 'far fa-user-ninja' => 'user ninja' ),
					array( 'far fa-user-nurse' => 'user nurse' ),
					array( 'far fa-user-plus' => 'user plus' ),
					array( 'far fa-user-robot' => 'user robot' ),
					array( 'far fa-user-secret' => 'user secret' ),
					array( 'far fa-user-shield' => 'user shield' ),
					array( 'far fa-user-slash' => 'user slash' ),
					array( 'far fa-user-tag' => 'user tag' ),
					array( 'far fa-user-tie' => 'user tie' ),
					array( 'far fa-user-times' => 'user times' ),
					array( 'far fa-user-unlock' => 'user unlock' ),
					array( 'far fa-user-visor' => 'user visor' ),
					array( 'far fa-user' => 'user' ),
					array( 'far fa-users-class' => 'users class' ),
					array( 'far fa-users-cog' => 'users cog' ),
					array( 'far fa-users-crown' => 'users crown' ),
					array( 'far fa-users-medical' => 'users medical' ),
					array( 'far fa-users-slash' => 'users slash' ),
					array( 'far fa-users' => 'users' ),
					array( 'far fa-utensil-fork' => 'utensil fork' ),
					array( 'far fa-utensil-knife' => 'utensil knife' ),
					array( 'far fa-utensil-spoon' => 'utensil spoon' ),
					array( 'far fa-utensils-alt' => 'utensils alt' ),
					array( 'far fa-utensils' => 'utensils' ),
					array( 'far fa-vacuum-robot' => 'vacuum robot' ),
					array( 'far fa-vacuum' => 'vacuum' ),
					array( 'far fa-value-absolute' => 'value absolute' ),
					array( 'far fa-vector-square' => 'vector square' ),
					array( 'far fa-venus-double' => 'venus double' ),
					array( 'far fa-venus-mars' => 'venus mars' ),
					array( 'far fa-venus' => 'venus' ),
					array( 'far fa-vhs' => 'vhs' ),
					array( 'far fa-vial' => 'vial' ),
					array( 'far fa-vials' => 'vials' ),
					array( 'far fa-video-plus' => 'video plus' ),
					array( 'far fa-video-slash' => 'video slash' ),
					array( 'far fa-video' => 'video' ),
					array( 'far fa-vihara' => 'vihara' ),
					array( 'far fa-violin' => 'violin' ),
					array( 'far fa-virus-slash' => 'virus slash' ),
					array( 'far fa-virus' => 'virus' ),
					array( 'far fa-viruses' => 'viruses' ),
					array( 'far fa-voicemail' => 'voicemail' ),
					array( 'far fa-volcano' => 'volcano' ),
					array( 'far fa-volleyball-ball' => 'volleyball ball' ),
					array( 'far fa-volume-down' => 'volume down' ),
					array( 'far fa-volume-mute' => 'volume mute' ),
					array( 'far fa-volume-off' => 'volume off' ),
					array( 'far fa-volume-slash' => 'volume slash' ),
					array( 'far fa-volume-up' => 'volume up' ),
					array( 'far fa-volume' => 'volume' ),
					array( 'far fa-vote-nay' => 'vote nay' ),
					array( 'far fa-vote-yea' => 'vote yea' ),
					array( 'far fa-vr-cardboard' => 'vr cardboard' ),
					array( 'far fa-wagon-covered' => 'wagon covered' ),
					array( 'far fa-walker' => 'walker' ),
					array( 'far fa-walkie-talkie' => 'walkie talkie' ),
					array( 'far fa-walking' => 'walking' ),
					array( 'far fa-wallet' => 'wallet' ),
					array( 'far fa-wand-magic' => 'wand magic' ),
					array( 'far fa-wand' => 'wand' ),
					array( 'far fa-warehouse-alt' => 'warehouse alt' ),
					array( 'far fa-warehouse' => 'warehouse' ),
					array( 'far fa-washer' => 'washer' ),
					array( 'far fa-watch-calculator' => 'watch calculator' ),
					array( 'far fa-watch-fitness' => 'watch fitness' ),
					array( 'far fa-watch' => 'watch' ),
					array( 'far fa-water-lower' => 'water lower' ),
					array( 'far fa-water-rise' => 'water rise' ),
					array( 'far fa-water' => 'water' ),
					array( 'far fa-wave-sine' => 'wave sine' ),
					array( 'far fa-wave-square' => 'wave square' ),
					array( 'far fa-wave-triangle' => 'wave triangle' ),
					array( 'far fa-waveform-path' => 'waveform path' ),
					array( 'far fa-waveform' => 'waveform' ),
					array( 'far fa-webcam-slash' => 'webcam slash' ),
					array( 'far fa-webcam' => 'webcam' ),
					array( 'far fa-weight-hanging' => 'weight hanging' ),
					array( 'far fa-weight' => 'weight' ),
					array( 'far fa-whale' => 'whale' ),
					array( 'far fa-wheat' => 'wheat' ),
					array( 'far fa-wheelchair' => 'wheelchair' ),
					array( 'far fa-whistle' => 'whistle' ),
					array( 'far fa-wifi-1' => 'wifi 1' ),
					array( 'far fa-wifi-2' => 'wifi 2' ),
					array( 'far fa-wifi-slash' => 'wifi slash' ),
					array( 'far fa-wifi' => 'wifi' ),
					array( 'far fa-wind-turbine' => 'wind turbine' ),
					array( 'far fa-wind-warning' => 'wind warning' ),
					array( 'far fa-wind' => 'wind' ),
					array( 'far fa-window-alt' => 'window alt' ),
					array( 'far fa-window-close' => 'window close' ),
					array( 'far fa-window-frame-open' => 'window frame open' ),
					array( 'far fa-window-frame' => 'window frame' ),
					array( 'far fa-window-maximize' => 'window maximize' ),
					array( 'far fa-window-minimize' => 'window minimize' ),
					array( 'far fa-window-restore' => 'window restore' ),
					array( 'far fa-window' => 'window' ),
					array( 'far fa-windsock' => 'windsock' ),
					array( 'far fa-wine-bottle' => 'wine bottle' ),
					array( 'far fa-wine-glass-alt' => 'wine glass alt' ),
					array( 'far fa-wine-glass' => 'wine glass' ),
					array( 'far fa-won-sign' => 'won sign' ),
					array( 'far fa-wreath' => 'wreath' ),
					array( 'far fa-wrench' => 'wrench' ),
					array( 'far fa-x-ray' => 'x ray' ),
					array( 'far fa-yen-sign' => 'yen sign' ),
					array( 'far fa-yin-yang' => 'yin yang' ),
				),
				esc_html__( 'Solid', 'brook' )   => array(
					array( 'fa fa-abacus' => 'abacus' ),
					array( 'fa fa-acorn' => 'acorn' ),
					array( 'fa fa-ad' => 'ad' ),
					array( 'fa fa-address-book' => 'address book' ),
					array( 'fa fa-address-card' => 'address card' ),
					array( 'fa fa-adjust' => 'adjust' ),
					array( 'fa fa-air-conditioner' => 'air conditioner' ),
					array( 'fa fa-air-freshener' => 'air freshener' ),
					array( 'fa fa-alarm-clock' => 'alarm clock' ),
					array( 'fa fa-alarm-exclamation' => 'alarm exclamation' ),
					array( 'fa fa-alarm-plus' => 'alarm plus' ),
					array( 'fa fa-alarm-snooze' => 'alarm snooze' ),
					array( 'fa fa-album-collection' => 'album collection' ),
					array( 'fa fa-album' => 'album' ),
					array( 'fa fa-alicorn' => 'alicorn' ),
					array( 'fa fa-alien-monster' => 'alien monster' ),
					array( 'fa fa-alien' => 'alien' ),
					array( 'fa fa-align-center' => 'align center' ),
					array( 'fa fa-align-justify' => 'align justify' ),
					array( 'fa fa-align-left' => 'align left' ),
					array( 'fa fa-align-right' => 'align right' ),
					array( 'fa fa-align-slash' => 'align slash' ),
					array( 'fa fa-allergies' => 'allergies' ),
					array( 'fa fa-ambulance' => 'ambulance' ),
					array( 'fa fa-american-sign-language-interpreting' => 'american sign language interpreting' ),
					array( 'fa fa-amp-guitar' => 'amp guitar' ),
					array( 'fa fa-analytics' => 'analytics' ),
					array( 'fa fa-anchor' => 'anchor' ),
					array( 'fa fa-angel' => 'angel' ),
					array( 'fa fa-angle-double-down' => 'angle double down' ),
					array( 'fa fa-angle-double-left' => 'angle double left' ),
					array( 'fa fa-angle-double-right' => 'angle double right' ),
					array( 'fa fa-angle-double-up' => 'angle double up' ),
					array( 'fa fa-angle-down' => 'angle down' ),
					array( 'fa fa-angle-left' => 'angle left' ),
					array( 'fa fa-angle-right' => 'angle right' ),
					array( 'fa fa-angle-up' => 'angle up' ),
					array( 'fa fa-angry' => 'angry' ),
					array( 'fa fa-ankh' => 'ankh' ),
					array( 'fa fa-apple-alt' => 'apple alt' ),
					array( 'fa fa-apple-crate' => 'apple crate' ),
					array( 'fa fa-archive' => 'archive' ),
					array( 'fa fa-archway' => 'archway' ),
					array( 'fa fa-arrow-alt-circle-down' => 'arrow alt circle down' ),
					array( 'fa fa-arrow-alt-circle-left' => 'arrow alt circle left' ),
					array( 'fa fa-arrow-alt-circle-right' => 'arrow alt circle right' ),
					array( 'fa fa-arrow-alt-circle-up' => 'arrow alt circle up' ),
					array( 'fa fa-arrow-alt-down' => 'arrow alt down' ),
					array( 'fa fa-arrow-alt-from-bottom' => 'arrow alt from bottom' ),
					array( 'fa fa-arrow-alt-from-left' => 'arrow alt from left' ),
					array( 'fa fa-arrow-alt-from-right' => 'arrow alt from right' ),
					array( 'fa fa-arrow-alt-from-top' => 'arrow alt from top' ),
					array( 'fa fa-arrow-alt-left' => 'arrow alt left' ),
					array( 'fa fa-arrow-alt-right' => 'arrow alt right' ),
					array( 'fa fa-arrow-alt-square-down' => 'arrow alt square down' ),
					array( 'fa fa-arrow-alt-square-left' => 'arrow alt square left' ),
					array( 'fa fa-arrow-alt-square-right' => 'arrow alt square right' ),
					array( 'fa fa-arrow-alt-square-up' => 'arrow alt square up' ),
					array( 'fa fa-arrow-alt-to-bottom' => 'arrow alt to bottom' ),
					array( 'fa fa-arrow-alt-to-left' => 'arrow alt to left' ),
					array( 'fa fa-arrow-alt-to-right' => 'arrow alt to right' ),
					array( 'fa fa-arrow-alt-to-top' => 'arrow alt to top' ),
					array( 'fa fa-arrow-alt-up' => 'arrow alt up' ),
					array( 'fa fa-arrow-circle-down' => 'arrow circle down' ),
					array( 'fa fa-arrow-circle-left' => 'arrow circle left' ),
					array( 'fa fa-arrow-circle-right' => 'arrow circle right' ),
					array( 'fa fa-arrow-circle-up' => 'arrow circle up' ),
					array( 'fa fa-arrow-down' => 'arrow down' ),
					array( 'fa fa-arrow-from-bottom' => 'arrow from bottom' ),
					array( 'fa fa-arrow-from-left' => 'arrow from left' ),
					array( 'fa fa-arrow-from-right' => 'arrow from right' ),
					array( 'fa fa-arrow-from-top' => 'arrow from top' ),
					array( 'fa fa-arrow-left' => 'arrow left' ),
					array( 'fa fa-arrow-right' => 'arrow right' ),
					array( 'fa fa-arrow-square-down' => 'arrow square down' ),
					array( 'fa fa-arrow-square-left' => 'arrow square left' ),
					array( 'fa fa-arrow-square-right' => 'arrow square right' ),
					array( 'fa fa-arrow-square-up' => 'arrow square up' ),
					array( 'fa fa-arrow-to-bottom' => 'arrow to bottom' ),
					array( 'fa fa-arrow-to-left' => 'arrow to left' ),
					array( 'fa fa-arrow-to-right' => 'arrow to right' ),
					array( 'fa fa-arrow-to-top' => 'arrow to top' ),
					array( 'fa fa-arrow-up' => 'arrow up' ),
					array( 'fa fa-arrows-alt-h' => 'arrows alt h' ),
					array( 'fa fa-arrows-alt-v' => 'arrows alt v' ),
					array( 'fa fa-arrows-alt' => 'arrows alt' ),
					array( 'fa fa-arrows-h' => 'arrows h' ),
					array( 'fa fa-arrows-v' => 'arrows v' ),
					array( 'fa fa-arrows' => 'arrows' ),
					array( 'fa fa-assistive-listening-systems' => 'assistive listening systems' ),
					array( 'fa fa-asterisk' => 'asterisk' ),
					array( 'fa fa-at' => 'at' ),
					array( 'fa fa-atlas' => 'atlas' ),
					array( 'fa fa-atom-alt' => 'atom alt' ),
					array( 'fa fa-atom' => 'atom' ),
					array( 'fa fa-audio-description' => 'audio description' ),
					array( 'fa fa-award' => 'award' ),
					array( 'fa fa-axe-battle' => 'axe battle' ),
					array( 'fa fa-axe' => 'axe' ),
					array( 'fa fa-baby-carriage' => 'baby carriage' ),
					array( 'fa fa-baby' => 'baby' ),
					array( 'fa fa-backpack' => 'backpack' ),
					array( 'fa fa-backspace' => 'backspace' ),
					array( 'fa fa-backward' => 'backward' ),
					array( 'fa fa-bacon' => 'bacon' ),
					array( 'fa fa-bacteria' => 'bacteria' ),
					array( 'fa fa-bacterium' => 'bacterium' ),
					array( 'fa fa-badge-check' => 'badge check' ),
					array( 'fa fa-badge-dollar' => 'badge dollar' ),
					array( 'fa fa-badge-percent' => 'badge percent' ),
					array( 'fa fa-badge-sheriff' => 'badge sheriff' ),
					array( 'fa fa-badge' => 'badge' ),
					array( 'fa fa-badger-honey' => 'badger honey' ),
					array( 'fa fa-bags-shopping' => 'bags shopping' ),
					array( 'fa fa-bahai' => 'bahai' ),
					array( 'fa fa-balance-scale-left' => 'balance scale left' ),
					array( 'fa fa-balance-scale-right' => 'balance scale right' ),
					array( 'fa fa-balance-scale' => 'balance scale' ),
					array( 'fa fa-ball-pile' => 'ball pile' ),
					array( 'fa fa-ballot-check' => 'ballot check' ),
					array( 'fa fa-ballot' => 'ballot' ),
					array( 'fa fa-ban' => 'ban' ),
					array( 'fa fa-band-aid' => 'band aid' ),
					array( 'fa fa-banjo' => 'banjo' ),
					array( 'fa fa-barcode-alt' => 'barcode alt' ),
					array( 'fa fa-barcode-read' => 'barcode read' ),
					array( 'fa fa-barcode-scan' => 'barcode scan' ),
					array( 'fa fa-barcode' => 'barcode' ),
					array( 'fa fa-bars' => 'bars' ),
					array( 'fa fa-baseball-ball' => 'baseball ball' ),
					array( 'fa fa-baseball' => 'baseball' ),
					array( 'fa fa-basketball-ball' => 'basketball ball' ),
					array( 'fa fa-basketball-hoop' => 'basketball hoop' ),
					array( 'fa fa-bat' => 'bat' ),
					array( 'fa fa-bath' => 'bath' ),
					array( 'fa fa-battery-bolt' => 'battery bolt' ),
					array( 'fa fa-battery-empty' => 'battery empty' ),
					array( 'fa fa-battery-full' => 'battery full' ),
					array( 'fa fa-battery-half' => 'battery half' ),
					array( 'fa fa-battery-quarter' => 'battery quarter' ),
					array( 'fa fa-battery-slash' => 'battery slash' ),
					array( 'fa fa-battery-three-quarters' => 'battery three quarters' ),
					array( 'fa fa-bed-alt' => 'bed alt' ),
					array( 'fa fa-bed-bunk' => 'bed bunk' ),
					array( 'fa fa-bed-empty' => 'bed empty' ),
					array( 'fa fa-bed' => 'bed' ),
					array( 'fa fa-beer' => 'beer' ),
					array( 'fa fa-bell-exclamation' => 'bell exclamation' ),
					array( 'fa fa-bell-on' => 'bell on' ),
					array( 'fa fa-bell-plus' => 'bell plus' ),
					array( 'fa fa-bell-school-slash' => 'bell school slash' ),
					array( 'fa fa-bell-school' => 'bell school' ),
					array( 'fa fa-bell-slash' => 'bell slash' ),
					array( 'fa fa-bell' => 'bell' ),
					array( 'fa fa-bells' => 'bells' ),
					array( 'fa fa-betamax' => 'betamax' ),
					array( 'fa fa-bezier-curve' => 'bezier curve' ),
					array( 'fa fa-bible' => 'bible' ),
					array( 'fa fa-bicycle' => 'bicycle' ),
					array( 'fa fa-biking-mountain' => 'biking mountain' ),
					array( 'fa fa-biking' => 'biking' ),
					array( 'fa fa-binoculars' => 'binoculars' ),
					array( 'fa fa-biohazard' => 'biohazard' ),
					array( 'fa fa-birthday-cake' => 'birthday cake' ),
					array( 'fa fa-blanket' => 'blanket' ),
					array( 'fa fa-blender-phone' => 'blender phone' ),
					array( 'fa fa-blender' => 'blender' ),
					array( 'fa fa-blind' => 'blind' ),
					array( 'fa fa-blinds-open' => 'blinds open' ),
					array( 'fa fa-blinds-raised' => 'blinds raised' ),
					array( 'fa fa-blinds' => 'blinds' ),
					array( 'fa fa-blog' => 'blog' ),
					array( 'fa fa-bold' => 'bold' ),
					array( 'fa fa-bolt' => 'bolt' ),
					array( 'fa fa-bomb' => 'bomb' ),
					array( 'fa fa-bone-break' => 'bone break' ),
					array( 'fa fa-bone' => 'bone' ),
					array( 'fa fa-bong' => 'bong' ),
					array( 'fa fa-book-alt' => 'book alt' ),
					array( 'fa fa-book-dead' => 'book dead' ),
					array( 'fa fa-book-heart' => 'book heart' ),
					array( 'fa fa-book-medical' => 'book medical' ),
					array( 'fa fa-book-open' => 'book open' ),
					array( 'fa fa-book-reader' => 'book reader' ),
					array( 'fa fa-book-spells' => 'book spells' ),
					array( 'fa fa-book-user' => 'book user' ),
					array( 'fa fa-book' => 'book' ),
					array( 'fa fa-bookmark' => 'bookmark' ),
					array( 'fa fa-books-medical' => 'books medical' ),
					array( 'fa fa-books' => 'books' ),
					array( 'fa fa-boombox' => 'boombox' ),
					array( 'fa fa-boot' => 'boot' ),
					array( 'fa fa-booth-curtain' => 'booth curtain' ),
					array( 'fa fa-border-all' => 'border all' ),
					array( 'fa fa-border-bottom' => 'border bottom' ),
					array( 'fa fa-border-center-h' => 'border center h' ),
					array( 'fa fa-border-center-v' => 'border center v' ),
					array( 'fa fa-border-inner' => 'border inner' ),
					array( 'fa fa-border-left' => 'border left' ),
					array( 'fa fa-border-none' => 'border none' ),
					array( 'fa fa-border-outer' => 'border outer' ),
					array( 'fa fa-border-right' => 'border right' ),
					array( 'fa fa-border-style-alt' => 'border style alt' ),
					array( 'fa fa-border-style' => 'border style' ),
					array( 'fa fa-border-top' => 'border top' ),
					array( 'fa fa-bow-arrow' => 'bow arrow' ),
					array( 'fa fa-bowling-ball' => 'bowling ball' ),
					array( 'fa fa-bowling-pins' => 'bowling pins' ),
					array( 'fa fa-box-alt' => 'box alt' ),
					array( 'fa fa-box-ballot' => 'box ballot' ),
					array( 'fa fa-box-check' => 'box check' ),
					array( 'fa fa-box-fragile' => 'box fragile' ),
					array( 'fa fa-box-full' => 'box full' ),
					array( 'fa fa-box-heart' => 'box heart' ),
					array( 'fa fa-box-open' => 'box open' ),
					array( 'fa fa-box-tissue' => 'box tissue' ),
					array( 'fa fa-box-up' => 'box up' ),
					array( 'fa fa-box-usd' => 'box usd' ),
					array( 'fa fa-box' => 'box' ),
					array( 'fa fa-boxes-alt' => 'boxes alt' ),
					array( 'fa fa-boxes' => 'boxes' ),
					array( 'fa fa-boxing-glove' => 'boxing glove' ),
					array( 'fa fa-brackets-curly' => 'brackets curly' ),
					array( 'fa fa-brackets' => 'brackets' ),
					array( 'fa fa-braille' => 'braille' ),
					array( 'fa fa-brain' => 'brain' ),
					array( 'fa fa-bread-loaf' => 'bread loaf' ),
					array( 'fa fa-bread-slice' => 'bread slice' ),
					array( 'fa fa-briefcase-medical' => 'briefcase medical' ),
					array( 'fa fa-briefcase' => 'briefcase' ),
					array( 'fa fa-bring-forward' => 'bring forward' ),
					array( 'fa fa-bring-front' => 'bring front' ),
					array( 'fa fa-broadcast-tower' => 'broadcast tower' ),
					array( 'fa fa-broom' => 'broom' ),
					array( 'fa fa-browser' => 'browser' ),
					array( 'fa fa-brush' => 'brush' ),
					array( 'fa fa-bug' => 'bug' ),
					array( 'fa fa-building' => 'building' ),
					array( 'fa fa-bullhorn' => 'bullhorn' ),
					array( 'fa fa-bullseye-arrow' => 'bullseye arrow' ),
					array( 'fa fa-bullseye-pointer' => 'bullseye pointer' ),
					array( 'fa fa-bullseye' => 'bullseye' ),
					array( 'fa fa-burger-soda' => 'burger soda' ),
					array( 'fa fa-burn' => 'burn' ),
					array( 'fa fa-burrito' => 'burrito' ),
					array( 'fa fa-bus-alt' => 'bus alt' ),
					array( 'fa fa-bus-school' => 'bus school' ),
					array( 'fa fa-bus' => 'bus' ),
					array( 'fa fa-business-time' => 'business time' ),
					array( 'fa fa-cabinet-filing' => 'cabinet filing' ),
					array( 'fa fa-cactus' => 'cactus' ),
					array( 'fa fa-calculator-alt' => 'calculator alt' ),
					array( 'fa fa-calculator' => 'calculator' ),
					array( 'fa fa-calendar-alt' => 'calendar alt' ),
					array( 'fa fa-calendar-check' => 'calendar check' ),
					array( 'fa fa-calendar-day' => 'calendar day' ),
					array( 'fa fa-calendar-edit' => 'calendar edit' ),
					array( 'fa fa-calendar-exclamation' => 'calendar exclamation' ),
					array( 'fa fa-calendar-minus' => 'calendar minus' ),
					array( 'fa fa-calendar-plus' => 'calendar plus' ),
					array( 'fa fa-calendar-star' => 'calendar star' ),
					array( 'fa fa-calendar-times' => 'calendar times' ),
					array( 'fa fa-calendar-week' => 'calendar week' ),
					array( 'fa fa-calendar' => 'calendar' ),
					array( 'fa fa-camcorder' => 'camcorder' ),
					array( 'fa fa-camera-alt' => 'camera alt' ),
					array( 'fa fa-camera-home' => 'camera home' ),
					array( 'fa fa-camera-movie' => 'camera movie' ),
					array( 'fa fa-camera-polaroid' => 'camera polaroid' ),
					array( 'fa fa-camera-retro' => 'camera retro' ),
					array( 'fa fa-camera' => 'camera' ),
					array( 'fa fa-campfire' => 'campfire' ),
					array( 'fa fa-campground' => 'campground' ),
					array( 'fa fa-candle-holder' => 'candle holder' ),
					array( 'fa fa-candy-cane' => 'candy cane' ),
					array( 'fa fa-candy-corn' => 'candy corn' ),
					array( 'fa fa-cannabis' => 'cannabis' ),
					array( 'fa fa-capsules' => 'capsules' ),
					array( 'fa fa-car-alt' => 'car alt' ),
					array( 'fa fa-car-battery' => 'car battery' ),
					array( 'fa fa-car-building' => 'car building' ),
					array( 'fa fa-car-bump' => 'car bump' ),
					array( 'fa fa-car-bus' => 'car bus' ),
					array( 'fa fa-car-crash' => 'car crash' ),
					array( 'fa fa-car-garage' => 'car garage' ),
					array( 'fa fa-car-mechanic' => 'car mechanic' ),
					array( 'fa fa-car-side' => 'car side' ),
					array( 'fa fa-car-tilt' => 'car tilt' ),
					array( 'fa fa-car-wash' => 'car wash' ),
					array( 'fa fa-car' => 'car' ),
					array( 'fa fa-caravan-alt' => 'caravan alt' ),
					array( 'fa fa-caravan' => 'caravan' ),
					array( 'fa fa-caret-circle-down' => 'caret circle down' ),
					array( 'fa fa-caret-circle-left' => 'caret circle left' ),
					array( 'fa fa-caret-circle-right' => 'caret circle right' ),
					array( 'fa fa-caret-circle-up' => 'caret circle up' ),
					array( 'fa fa-caret-down' => 'caret down' ),
					array( 'fa fa-caret-left' => 'caret left' ),
					array( 'fa fa-caret-right' => 'caret right' ),
					array( 'fa fa-caret-square-down' => 'caret square down' ),
					array( 'fa fa-caret-square-left' => 'caret square left' ),
					array( 'fa fa-caret-square-right' => 'caret square right' ),
					array( 'fa fa-caret-square-up' => 'caret square up' ),
					array( 'fa fa-caret-up' => 'caret up' ),
					array( 'fa fa-carrot' => 'carrot' ),
					array( 'fa fa-cars' => 'cars' ),
					array( 'fa fa-cart-arrow-down' => 'cart arrow down' ),
					array( 'fa fa-cart-plus' => 'cart plus' ),
					array( 'fa fa-cash-register' => 'cash register' ),
					array( 'fa fa-cassette-tape' => 'cassette tape' ),
					array( 'fa fa-cat-space' => 'cat space' ),
					array( 'fa fa-cat' => 'cat' ),
					array( 'fa fa-cauldron' => 'cauldron' ),
					array( 'fa fa-cctv' => 'cctv' ),
					array( 'fa fa-certificate' => 'certificate' ),
					array( 'fa fa-chair-office' => 'chair office' ),
					array( 'fa fa-chair' => 'chair' ),
					array( 'fa fa-chalkboard-teacher' => 'chalkboard teacher' ),
					array( 'fa fa-chalkboard' => 'chalkboard' ),
					array( 'fa fa-charging-station' => 'charging station' ),
					array( 'fa fa-chart-area' => 'chart area' ),
					array( 'fa fa-chart-bar' => 'chart bar' ),
					array( 'fa fa-chart-line-down' => 'chart line down' ),
					array( 'fa fa-chart-line' => 'chart line' ),
					array( 'fa fa-chart-network' => 'chart network' ),
					array( 'fa fa-chart-pie-alt' => 'chart pie alt' ),
					array( 'fa fa-chart-pie' => 'chart pie' ),
					array( 'fa fa-chart-scatter' => 'chart scatter' ),
					array( 'fa fa-check-circle' => 'check circle' ),
					array( 'fa fa-check-double' => 'check double' ),
					array( 'fa fa-check-square' => 'check square' ),
					array( 'fa fa-check' => 'check' ),
					array( 'fa fa-cheese-swiss' => 'cheese swiss' ),
					array( 'fa fa-cheese' => 'cheese' ),
					array( 'fa fa-cheeseburger' => 'cheeseburger' ),
					array( 'fa fa-chess-bishop-alt' => 'chess bishop alt' ),
					array( 'fa fa-chess-bishop' => 'chess bishop' ),
					array( 'fa fa-chess-board' => 'chess board' ),
					array( 'fa fa-chess-clock-alt' => 'chess clock alt' ),
					array( 'fa fa-chess-clock' => 'chess clock' ),
					array( 'fa fa-chess-king-alt' => 'chess king alt' ),
					array( 'fa fa-chess-king' => 'chess king' ),
					array( 'fa fa-chess-knight-alt' => 'chess knight alt' ),
					array( 'fa fa-chess-knight' => 'chess knight' ),
					array( 'fa fa-chess-pawn-alt' => 'chess pawn alt' ),
					array( 'fa fa-chess-pawn' => 'chess pawn' ),
					array( 'fa fa-chess-queen-alt' => 'chess queen alt' ),
					array( 'fa fa-chess-queen' => 'chess queen' ),
					array( 'fa fa-chess-rook-alt' => 'chess rook alt' ),
					array( 'fa fa-chess-rook' => 'chess rook' ),
					array( 'fa fa-chess' => 'chess' ),
					array( 'fa fa-chevron-circle-down' => 'chevron circle down' ),
					array( 'fa fa-chevron-circle-left' => 'chevron circle left' ),
					array( 'fa fa-chevron-circle-right' => 'chevron circle right' ),
					array( 'fa fa-chevron-circle-up' => 'chevron circle up' ),
					array( 'fa fa-chevron-double-down' => 'chevron double down' ),
					array( 'fa fa-chevron-double-left' => 'chevron double left' ),
					array( 'fa fa-chevron-double-right' => 'chevron double right' ),
					array( 'fa fa-chevron-double-up' => 'chevron double up' ),
					array( 'fa fa-chevron-down' => 'chevron down' ),
					array( 'fa fa-chevron-left' => 'chevron left' ),
					array( 'fa fa-chevron-right' => 'chevron right' ),
					array( 'fa fa-chevron-square-down' => 'chevron square down' ),
					array( 'fa fa-chevron-square-left' => 'chevron square left' ),
					array( 'fa fa-chevron-square-right' => 'chevron square right' ),
					array( 'fa fa-chevron-square-up' => 'chevron square up' ),
					array( 'fa fa-chevron-up' => 'chevron up' ),
					array( 'fa fa-child' => 'child' ),
					array( 'fa fa-chimney' => 'chimney' ),
					array( 'fa fa-church' => 'church' ),
					array( 'fa fa-circle-notch' => 'circle notch' ),
					array( 'fa fa-circle' => 'circle' ),
					array( 'fa fa-city' => 'city' ),
					array( 'fa fa-clarinet' => 'clarinet' ),
					array( 'fa fa-claw-marks' => 'claw marks' ),
					array( 'fa fa-clinic-medical' => 'clinic medical' ),
					array( 'fa fa-clipboard-check' => 'clipboard check' ),
					array( 'fa fa-clipboard-list-check' => 'clipboard list check' ),
					array( 'fa fa-clipboard-list' => 'clipboard list' ),
					array( 'fa fa-clipboard-prescription' => 'clipboard prescription' ),
					array( 'fa fa-clipboard-user' => 'clipboard user' ),
					array( 'fa fa-clipboard' => 'clipboard' ),
					array( 'fa fa-clock' => 'clock' ),
					array( 'fa fa-clone' => 'clone' ),
					array( 'fa fa-closed-captioning' => 'closed captioning' ),
					array( 'fa fa-cloud-download-alt' => 'cloud download alt' ),
					array( 'fa fa-cloud-download' => 'cloud download' ),
					array( 'fa fa-cloud-drizzle' => 'cloud drizzle' ),
					array( 'fa fa-cloud-hail-mixed' => 'cloud hail mixed' ),
					array( 'fa fa-cloud-hail' => 'cloud hail' ),
					array( 'fa fa-cloud-meatball' => 'cloud meatball' ),
					array( 'fa fa-cloud-moon-rain' => 'cloud moon rain' ),
					array( 'fa fa-cloud-moon' => 'cloud moon' ),
					array( 'fa fa-cloud-music' => 'cloud music' ),
					array( 'fa fa-cloud-rain' => 'cloud rain' ),
					array( 'fa fa-cloud-rainbow' => 'cloud rainbow' ),
					array( 'fa fa-cloud-showers-heavy' => 'cloud showers heavy' ),
					array( 'fa fa-cloud-showers' => 'cloud showers' ),
					array( 'fa fa-cloud-sleet' => 'cloud sleet' ),
					array( 'fa fa-cloud-snow' => 'cloud snow' ),
					array( 'fa fa-cloud-sun-rain' => 'cloud sun rain' ),
					array( 'fa fa-cloud-sun' => 'cloud sun' ),
					array( 'fa fa-cloud-upload-alt' => 'cloud upload alt' ),
					array( 'fa fa-cloud-upload' => 'cloud upload' ),
					array( 'fa fa-cloud' => 'cloud' ),
					array( 'fa fa-clouds-moon' => 'clouds moon' ),
					array( 'fa fa-clouds-sun' => 'clouds sun' ),
					array( 'fa fa-clouds' => 'clouds' ),
					array( 'fa fa-club' => 'club' ),
					array( 'fa fa-cocktail' => 'cocktail' ),
					array( 'fa fa-code-branch' => 'code branch' ),
					array( 'fa fa-code-commit' => 'code commit' ),
					array( 'fa fa-code-merge' => 'code merge' ),
					array( 'fa fa-code' => 'code' ),
					array( 'fa fa-coffee-pot' => 'coffee pot' ),
					array( 'fa fa-coffee-togo' => 'coffee togo' ),
					array( 'fa fa-coffee' => 'coffee' ),
					array( 'fa fa-coffin-cross' => 'coffin cross' ),
					array( 'fa fa-coffin' => 'coffin' ),
					array( 'fa fa-cog' => 'cog' ),
					array( 'fa fa-cogs' => 'cogs' ),
					array( 'fa fa-coin' => 'coin' ),
					array( 'fa fa-coins' => 'coins' ),
					array( 'fa fa-columns' => 'columns' ),
					array( 'fa fa-comet' => 'comet' ),
					array( 'fa fa-comment-alt-check' => 'comment alt check' ),
					array( 'fa fa-comment-alt-dollar' => 'comment alt dollar' ),
					array( 'fa fa-comment-alt-dots' => 'comment alt dots' ),
					array( 'fa fa-comment-alt-edit' => 'comment alt edit' ),
					array( 'fa fa-comment-alt-exclamation' => 'comment alt exclamation' ),
					array( 'fa fa-comment-alt-lines' => 'comment alt lines' ),
					array( 'fa fa-comment-alt-medical' => 'comment alt medical' ),
					array( 'fa fa-comment-alt-minus' => 'comment alt minus' ),
					array( 'fa fa-comment-alt-music' => 'comment alt music' ),
					array( 'fa fa-comment-alt-plus' => 'comment alt plus' ),
					array( 'fa fa-comment-alt-slash' => 'comment alt slash' ),
					array( 'fa fa-comment-alt-smile' => 'comment alt smile' ),
					array( 'fa fa-comment-alt-times' => 'comment alt times' ),
					array( 'fa fa-comment-alt' => 'comment alt' ),
					array( 'fa fa-comment-check' => 'comment check' ),
					array( 'fa fa-comment-dollar' => 'comment dollar' ),
					array( 'fa fa-comment-dots' => 'comment dots' ),
					array( 'fa fa-comment-edit' => 'comment edit' ),
					array( 'fa fa-comment-exclamation' => 'comment exclamation' ),
					array( 'fa fa-comment-lines' => 'comment lines' ),
					array( 'fa fa-comment-medical' => 'comment medical' ),
					array( 'fa fa-comment-minus' => 'comment minus' ),
					array( 'fa fa-comment-music' => 'comment music' ),
					array( 'fa fa-comment-plus' => 'comment plus' ),
					array( 'fa fa-comment-slash' => 'comment slash' ),
					array( 'fa fa-comment-smile' => 'comment smile' ),
					array( 'fa fa-comment-times' => 'comment times' ),
					array( 'fa fa-comment' => 'comment' ),
					array( 'fa fa-comments-alt-dollar' => 'comments alt dollar' ),
					array( 'fa fa-comments-alt' => 'comments alt' ),
					array( 'fa fa-comments-dollar' => 'comments dollar' ),
					array( 'fa fa-comments' => 'comments' ),
					array( 'fa fa-compact-disc' => 'compact disc' ),
					array( 'fa fa-compass-slash' => 'compass slash' ),
					array( 'fa fa-compass' => 'compass' ),
					array( 'fa fa-compress-alt' => 'compress alt' ),
					array( 'fa fa-compress-arrows-alt' => 'compress arrows alt' ),
					array( 'fa fa-compress-wide' => 'compress wide' ),
					array( 'fa fa-compress' => 'compress' ),
					array( 'fa fa-computer-classic' => 'computer classic' ),
					array( 'fa fa-computer-speaker' => 'computer speaker' ),
					array( 'fa fa-concierge-bell' => 'concierge bell' ),
					array( 'fa fa-construction' => 'construction' ),
					array( 'fa fa-container-storage' => 'container storage' ),
					array( 'fa fa-conveyor-belt-alt' => 'conveyor belt alt' ),
					array( 'fa fa-conveyor-belt' => 'conveyor belt' ),
					array( 'fa fa-cookie-bite' => 'cookie bite' ),
					array( 'fa fa-cookie' => 'cookie' ),
					array( 'fa fa-copy' => 'copy' ),
					array( 'fa fa-copyright' => 'copyright' ),
					array( 'fa fa-corn' => 'corn' ),
					array( 'fa fa-couch' => 'couch' ),
					array( 'fa fa-cow' => 'cow' ),
					array( 'fa fa-cowbell-more' => 'cowbell more' ),
					array( 'fa fa-cowbell' => 'cowbell' ),
					array( 'fa fa-credit-card-blank' => 'credit card blank' ),
					array( 'fa fa-credit-card-front' => 'credit card front' ),
					array( 'fa fa-credit-card' => 'credit card' ),
					array( 'fa fa-cricket' => 'cricket' ),
					array( 'fa fa-croissant' => 'croissant' ),
					array( 'fa fa-crop-alt' => 'crop alt' ),
					array( 'fa fa-crop' => 'crop' ),
					array( 'fa fa-cross' => 'cross' ),
					array( 'fa fa-crosshairs' => 'crosshairs' ),
					array( 'fa fa-crow' => 'crow' ),
					array( 'fa fa-crown' => 'crown' ),
					array( 'fa fa-crutch' => 'crutch' ),
					array( 'fa fa-crutches' => 'crutches' ),
					array( 'fa fa-cube' => 'cube' ),
					array( 'fa fa-cubes' => 'cubes' ),
					array( 'fa fa-curling' => 'curling' ),
					array( 'fa fa-cut' => 'cut' ),
					array( 'fa fa-dagger' => 'dagger' ),
					array( 'fa fa-database' => 'database' ),
					array( 'fa fa-deaf' => 'deaf' ),
					array( 'fa fa-debug' => 'debug' ),
					array( 'fa fa-deer-rudolph' => 'deer rudolph' ),
					array( 'fa fa-deer' => 'deer' ),
					array( 'fa fa-democrat' => 'democrat' ),
					array( 'fa fa-desktop-alt' => 'desktop alt' ),
					array( 'fa fa-desktop' => 'desktop' ),
					array( 'fa fa-dewpoint' => 'dewpoint' ),
					array( 'fa fa-dharmachakra' => 'dharmachakra' ),
					array( 'fa fa-diagnoses' => 'diagnoses' ),
					array( 'fa fa-diamond' => 'diamond' ),
					array( 'fa fa-dice-d10' => 'dice d10' ),
					array( 'fa fa-dice-d12' => 'dice d12' ),
					array( 'fa fa-dice-d20' => 'dice d20' ),
					array( 'fa fa-dice-d4' => 'dice d4' ),
					array( 'fa fa-dice-d6' => 'dice d6' ),
					array( 'fa fa-dice-d8' => 'dice d8' ),
					array( 'fa fa-dice-five' => 'dice five' ),
					array( 'fa fa-dice-four' => 'dice four' ),
					array( 'fa fa-dice-one' => 'dice one' ),
					array( 'fa fa-dice-six' => 'dice six' ),
					array( 'fa fa-dice-three' => 'dice three' ),
					array( 'fa fa-dice-two' => 'dice two' ),
					array( 'fa fa-dice' => 'dice' ),
					array( 'fa fa-digging' => 'digging' ),
					array( 'fa fa-digital-tachograph' => 'digital tachograph' ),
					array( 'fa fa-diploma' => 'diploma' ),
					array( 'fa fa-directions' => 'directions' ),
					array( 'fa fa-disc-drive' => 'disc drive' ),
					array( 'fa fa-disease' => 'disease' ),
					array( 'fa fa-divide' => 'divide' ),
					array( 'fa fa-dizzy' => 'dizzy' ),
					array( 'fa fa-dna' => 'dna' ),
					array( 'fa fa-do-not-enter' => 'do not enter' ),
					array( 'fa fa-dog-leashed' => 'dog leashed' ),
					array( 'fa fa-dog' => 'dog' ),
					array( 'fa fa-dollar-sign' => 'dollar sign' ),
					array( 'fa fa-dolly-empty' => 'dolly empty' ),
					array( 'fa fa-dolly-flatbed-alt' => 'dolly flatbed alt' ),
					array( 'fa fa-dolly-flatbed-empty' => 'dolly flatbed empty' ),
					array( 'fa fa-dolly-flatbed' => 'dolly flatbed' ),
					array( 'fa fa-dolly' => 'dolly' ),
					array( 'fa fa-donate' => 'donate' ),
					array( 'fa fa-door-closed' => 'door closed' ),
					array( 'fa fa-door-open' => 'door open' ),
					array( 'fa fa-dot-circle' => 'dot circle' ),
					array( 'fa fa-dove' => 'dove' ),
					array( 'fa fa-download' => 'download' ),
					array( 'fa fa-drafting-compass' => 'drafting compass' ),
					array( 'fa fa-dragon' => 'dragon' ),
					array( 'fa fa-draw-circle' => 'draw circle' ),
					array( 'fa fa-draw-polygon' => 'draw polygon' ),
					array( 'fa fa-draw-square' => 'draw square' ),
					array( 'fa fa-dreidel' => 'dreidel' ),
					array( 'fa fa-drone-alt' => 'drone alt' ),
					array( 'fa fa-drone' => 'drone' ),
					array( 'fa fa-drum-steelpan' => 'drum steelpan' ),
					array( 'fa fa-drum' => 'drum' ),
					array( 'fa fa-drumstick-bite' => 'drumstick bite' ),
					array( 'fa fa-drumstick' => 'drumstick' ),
					array( 'fa fa-dryer-alt' => 'dryer alt' ),
					array( 'fa fa-dryer' => 'dryer' ),
					array( 'fa fa-duck' => 'duck' ),
					array( 'fa fa-dumbbell' => 'dumbbell' ),
					array( 'fa fa-dumpster-fire' => 'dumpster fire' ),
					array( 'fa fa-dumpster' => 'dumpster' ),
					array( 'fa fa-dungeon' => 'dungeon' ),
					array( 'fa fa-ear-muffs' => 'ear muffs' ),
					array( 'fa fa-ear' => 'ear' ),
					array( 'fa fa-eclipse-alt' => 'eclipse alt' ),
					array( 'fa fa-eclipse' => 'eclipse' ),
					array( 'fa fa-edit' => 'edit' ),
					array( 'fa fa-egg-fried' => 'egg fried' ),
					array( 'fa fa-egg' => 'egg' ),
					array( 'fa fa-eject' => 'eject' ),
					array( 'fa fa-elephant' => 'elephant' ),
					array( 'fa fa-ellipsis-h-alt' => 'ellipsis h alt' ),
					array( 'fa fa-ellipsis-h' => 'ellipsis h' ),
					array( 'fa fa-ellipsis-v-alt' => 'ellipsis v alt' ),
					array( 'fa fa-ellipsis-v' => 'ellipsis v' ),
					array( 'fa fa-empty-set' => 'empty set' ),
					array( 'fa fa-engine-warning' => 'engine warning' ),
					array( 'fa fa-envelope-open-dollar' => 'envelope open dollar' ),
					array( 'fa fa-envelope-open-text' => 'envelope open text' ),
					array( 'fa fa-envelope-open' => 'envelope open' ),
					array( 'fa fa-envelope-square' => 'envelope square' ),
					array( 'fa fa-envelope' => 'envelope' ),
					array( 'fa fa-equals' => 'equals' ),
					array( 'fa fa-eraser' => 'eraser' ),
					array( 'fa fa-ethernet' => 'ethernet' ),
					array( 'fa fa-euro-sign' => 'euro sign' ),
					array( 'fa fa-exchange-alt' => 'exchange alt' ),
					array( 'fa fa-exchange' => 'exchange' ),
					array( 'fa fa-exclamation-circle' => 'exclamation circle' ),
					array( 'fa fa-exclamation-square' => 'exclamation square' ),
					array( 'fa fa-exclamation-triangle' => 'exclamation triangle' ),
					array( 'fa fa-exclamation' => 'exclamation' ),
					array( 'fa fa-expand-alt' => 'expand alt' ),
					array( 'fa fa-expand-arrows-alt' => 'expand arrows alt' ),
					array( 'fa fa-expand-arrows' => 'expand arrows' ),
					array( 'fa fa-expand-wide' => 'expand wide' ),
					array( 'fa fa-expand' => 'expand' ),
					array( 'fa fa-external-link-alt' => 'external link alt' ),
					array( 'fa fa-external-link-square-alt' => 'external link square alt' ),
					array( 'fa fa-external-link-square' => 'external link square' ),
					array( 'fa fa-external-link' => 'external link' ),
					array( 'fa fa-eye-dropper' => 'eye dropper' ),
					array( 'fa fa-eye-evil' => 'eye evil' ),
					array( 'fa fa-eye-slash' => 'eye slash' ),
					array( 'fa fa-eye' => 'eye' ),
					array( 'fa fa-fan-table' => 'fan table' ),
					array( 'fa fa-fan' => 'fan' ),
					array( 'fa fa-farm' => 'farm' ),
					array( 'fa fa-fast-backward' => 'fast backward' ),
					array( 'fa fa-fast-forward' => 'fast forward' ),
					array( 'fa fa-faucet-drip' => 'faucet drip' ),
					array( 'fa fa-faucet' => 'faucet' ),
					array( 'fa fa-fax' => 'fax' ),
					array( 'fa fa-feather-alt' => 'feather alt' ),
					array( 'fa fa-feather' => 'feather' ),
					array( 'fa fa-female' => 'female' ),
					array( 'fa fa-field-hockey' => 'field hockey' ),
					array( 'fa fa-fighter-jet' => 'fighter jet' ),
					array( 'fa fa-file-alt' => 'file alt' ),
					array( 'fa fa-file-archive' => 'file archive' ),
					array( 'fa fa-file-audio' => 'file audio' ),
					array( 'fa fa-file-certificate' => 'file certificate' ),
					array( 'fa fa-file-chart-line' => 'file chart line' ),
					array( 'fa fa-file-chart-pie' => 'file chart pie' ),
					array( 'fa fa-file-check' => 'file check' ),
					array( 'fa fa-file-code' => 'file code' ),
					array( 'fa fa-file-contract' => 'file contract' ),
					array( 'fa fa-file-csv' => 'file csv' ),
					array( 'fa fa-file-download' => 'file download' ),
					array( 'fa fa-file-edit' => 'file edit' ),
					array( 'fa fa-file-excel' => 'file excel' ),
					array( 'fa fa-file-exclamation' => 'file exclamation' ),
					array( 'fa fa-file-export' => 'file export' ),
					array( 'fa fa-file-image' => 'file image' ),
					array( 'fa fa-file-import' => 'file import' ),
					array( 'fa fa-file-invoice-dollar' => 'file invoice dollar' ),
					array( 'fa fa-file-invoice' => 'file invoice' ),
					array( 'fa fa-file-medical-alt' => 'file medical alt' ),
					array( 'fa fa-file-medical' => 'file medical' ),
					array( 'fa fa-file-minus' => 'file minus' ),
					array( 'fa fa-file-music' => 'file music' ),
					array( 'fa fa-file-pdf' => 'file pdf' ),
					array( 'fa fa-file-plus' => 'file plus' ),
					array( 'fa fa-file-powerpoint' => 'file powerpoint' ),
					array( 'fa fa-file-prescription' => 'file prescription' ),
					array( 'fa fa-file-search' => 'file search' ),
					array( 'fa fa-file-signature' => 'file signature' ),
					array( 'fa fa-file-spreadsheet' => 'file spreadsheet' ),
					array( 'fa fa-file-times' => 'file times' ),
					array( 'fa fa-file-upload' => 'file upload' ),
					array( 'fa fa-file-user' => 'file user' ),
					array( 'fa fa-file-video' => 'file video' ),
					array( 'fa fa-file-word' => 'file word' ),
					array( 'fa fa-file' => 'file' ),
					array( 'fa fa-files-medical' => 'files medical' ),
					array( 'fa fa-fill-drip' => 'fill drip' ),
					array( 'fa fa-fill' => 'fill' ),
					array( 'fa fa-film-alt' => 'film alt' ),
					array( 'fa fa-film-canister' => 'film canister' ),
					array( 'fa fa-film' => 'film' ),
					array( 'fa fa-filter' => 'filter' ),
					array( 'fa fa-fingerprint' => 'fingerprint' ),
					array( 'fa fa-fire-alt' => 'fire alt' ),
					array( 'fa fa-fire-extinguisher' => 'fire extinguisher' ),
					array( 'fa fa-fire-smoke' => 'fire smoke' ),
					array( 'fa fa-fire' => 'fire' ),
					array( 'fa fa-fireplace' => 'fireplace' ),
					array( 'fa fa-first-aid' => 'first aid' ),
					array( 'fa fa-fish-cooked' => 'fish cooked' ),
					array( 'fa fa-fish' => 'fish' ),
					array( 'fa fa-fist-raised' => 'fist raised' ),
					array( 'fa fa-flag-alt' => 'flag alt' ),
					array( 'fa fa-flag-checkered' => 'flag checkered' ),
					array( 'fa fa-flag-usa' => 'flag usa' ),
					array( 'fa fa-flag' => 'flag' ),
					array( 'fa fa-flame' => 'flame' ),
					array( 'fa fa-flashlight' => 'flashlight' ),
					array( 'fa fa-flask-poison' => 'flask poison' ),
					array( 'fa fa-flask-potion' => 'flask potion' ),
					array( 'fa fa-flask' => 'flask' ),
					array( 'fa fa-flower-daffodil' => 'flower daffodil' ),
					array( 'fa fa-flower-tulip' => 'flower tulip' ),
					array( 'fa fa-flower' => 'flower' ),
					array( 'fa fa-flushed' => 'flushed' ),
					array( 'fa fa-flute' => 'flute' ),
					array( 'fa fa-flux-capacitor' => 'flux capacitor' ),
					array( 'fa fa-fog' => 'fog' ),
					array( 'fa fa-folder-download' => 'folder download' ),
					array( 'fa fa-folder-minus' => 'folder minus' ),
					array( 'fa fa-folder-open' => 'folder open' ),
					array( 'fa fa-folder-plus' => 'folder plus' ),
					array( 'fa fa-folder-times' => 'folder times' ),
					array( 'fa fa-folder-tree' => 'folder tree' ),
					array( 'fa fa-folder-upload' => 'folder upload' ),
					array( 'fa fa-folder' => 'folder' ),
					array( 'fa fa-folders' => 'folders' ),
					array( 'fa fa-font-awesome-logo-full' => 'font awesome logo full' ),
					array( 'fa fa-font-case' => 'font case' ),
					array( 'fa fa-font' => 'font' ),
					array( 'fa fa-football-ball' => 'football ball' ),
					array( 'fa fa-football-helmet' => 'football helmet' ),
					array( 'fa fa-forklift' => 'forklift' ),
					array( 'fa fa-forward' => 'forward' ),
					array( 'fa fa-fragile' => 'fragile' ),
					array( 'fa fa-french-fries' => 'french fries' ),
					array( 'fa fa-frog' => 'frog' ),
					array( 'fa fa-frosty-head' => 'frosty head' ),
					array( 'fa fa-frown-open' => 'frown open' ),
					array( 'fa fa-frown' => 'frown' ),
					array( 'fa fa-function' => 'function' ),
					array( 'fa fa-funnel-dollar' => 'funnel dollar' ),
					array( 'fa fa-futbol' => 'futbol' ),
					array( 'fa fa-galaxy' => 'galaxy' ),
					array( 'fa fa-game-board-alt' => 'game board alt' ),
					array( 'fa fa-game-board' => 'game board' ),
					array( 'fa fa-game-console-handheld' => 'game console handheld' ),
					array( 'fa fa-gamepad-alt' => 'gamepad alt' ),
					array( 'fa fa-gamepad' => 'gamepad' ),
					array( 'fa fa-garage-car' => 'garage car' ),
					array( 'fa fa-garage-open' => 'garage open' ),
					array( 'fa fa-garage' => 'garage' ),
					array( 'fa fa-gas-pump-slash' => 'gas pump slash' ),
					array( 'fa fa-gas-pump' => 'gas pump' ),
					array( 'fa fa-gavel' => 'gavel' ),
					array( 'fa fa-gem' => 'gem' ),
					array( 'fa fa-genderless' => 'genderless' ),
					array( 'fa fa-ghost' => 'ghost' ),
					array( 'fa fa-gift-card' => 'gift card' ),
					array( 'fa fa-gift' => 'gift' ),
					array( 'fa fa-gifts' => 'gifts' ),
					array( 'fa fa-gingerbread-man' => 'gingerbread man' ),
					array( 'fa fa-glass-champagne' => 'glass champagne' ),
					array( 'fa fa-glass-cheers' => 'glass cheers' ),
					array( 'fa fa-glass-citrus' => 'glass citrus' ),
					array( 'fa fa-glass-martini-alt' => 'glass martini alt' ),
					array( 'fa fa-glass-martini' => 'glass martini' ),
					array( 'fa fa-glass-whiskey-rocks' => 'glass whiskey rocks' ),
					array( 'fa fa-glass-whiskey' => 'glass whiskey' ),
					array( 'fa fa-glass' => 'glass' ),
					array( 'fa fa-glasses-alt' => 'glasses alt' ),
					array( 'fa fa-glasses' => 'glasses' ),
					array( 'fa fa-globe-africa' => 'globe africa' ),
					array( 'fa fa-globe-americas' => 'globe americas' ),
					array( 'fa fa-globe-asia' => 'globe asia' ),
					array( 'fa fa-globe-europe' => 'globe europe' ),
					array( 'fa fa-globe-snow' => 'globe snow' ),
					array( 'fa fa-globe-stand' => 'globe stand' ),
					array( 'fa fa-globe' => 'globe' ),
					array( 'fa fa-golf-ball' => 'golf ball' ),
					array( 'fa fa-golf-club' => 'golf club' ),
					array( 'fa fa-gopuram' => 'gopuram' ),
					array( 'fa fa-graduation-cap' => 'graduation cap' ),
					array( 'fa fa-gramophone' => 'gramophone' ),
					array( 'fa fa-greater-than-equal' => 'greater than equal' ),
					array( 'fa fa-greater-than' => 'greater than' ),
					array( 'fa fa-grimace' => 'grimace' ),
					array( 'fa fa-grin-alt' => 'grin alt' ),
					array( 'fa fa-grin-beam-sweat' => 'grin beam sweat' ),
					array( 'fa fa-grin-beam' => 'grin beam' ),
					array( 'fa fa-grin-hearts' => 'grin hearts' ),
					array( 'fa fa-grin-squint-tears' => 'grin squint tears' ),
					array( 'fa fa-grin-squint' => 'grin squint' ),
					array( 'fa fa-grin-stars' => 'grin stars' ),
					array( 'fa fa-grin-tears' => 'grin tears' ),
					array( 'fa fa-grin-tongue-squint' => 'grin tongue squint' ),
					array( 'fa fa-grin-tongue-wink' => 'grin tongue wink' ),
					array( 'fa fa-grin-tongue' => 'grin tongue' ),
					array( 'fa fa-grin-wink' => 'grin wink' ),
					array( 'fa fa-grin' => 'grin' ),
					array( 'fa fa-grip-horizontal' => 'grip horizontal' ),
					array( 'fa fa-grip-lines-vertical' => 'grip lines vertical' ),
					array( 'fa fa-grip-lines' => 'grip lines' ),
					array( 'fa fa-grip-vertical' => 'grip vertical' ),
					array( 'fa fa-guitar-electric' => 'guitar electric' ),
					array( 'fa fa-guitar' => 'guitar' ),
					array( 'fa fa-guitars' => 'guitars' ),
					array( 'fa fa-h-square' => 'h square' ),
					array( 'fa fa-h1' => 'h1' ),
					array( 'fa fa-h2' => 'h2' ),
					array( 'fa fa-h3' => 'h3' ),
					array( 'fa fa-h4' => 'h4' ),
					array( 'fa fa-hamburger' => 'hamburger' ),
					array( 'fa fa-hammer-war' => 'hammer war' ),
					array( 'fa fa-hammer' => 'hammer' ),
					array( 'fa fa-hamsa' => 'hamsa' ),
					array( 'fa fa-hand-heart' => 'hand heart' ),
					array( 'fa fa-hand-holding-box' => 'hand holding box' ),
					array( 'fa fa-hand-holding-heart' => 'hand holding heart' ),
					array( 'fa fa-hand-holding-magic' => 'hand holding magic' ),
					array( 'fa fa-hand-holding-medical' => 'hand holding medical' ),
					array( 'fa fa-hand-holding-seedling' => 'hand holding seedling' ),
					array( 'fa fa-hand-holding-usd' => 'hand holding usd' ),
					array( 'fa fa-hand-holding-water' => 'hand holding water' ),
					array( 'fa fa-hand-holding' => 'hand holding' ),
					array( 'fa fa-hand-lizard' => 'hand lizard' ),
					array( 'fa fa-hand-middle-finger' => 'hand middle finger' ),
					array( 'fa fa-hand-paper' => 'hand paper' ),
					array( 'fa fa-hand-peace' => 'hand peace' ),
					array( 'fa fa-hand-point-down' => 'hand point down' ),
					array( 'fa fa-hand-point-left' => 'hand point left' ),
					array( 'fa fa-hand-point-right' => 'hand point right' ),
					array( 'fa fa-hand-point-up' => 'hand point up' ),
					array( 'fa fa-hand-pointer' => 'hand pointer' ),
					array( 'fa fa-hand-receiving' => 'hand receiving' ),
					array( 'fa fa-hand-rock' => 'hand rock' ),
					array( 'fa fa-hand-scissors' => 'hand scissors' ),
					array( 'fa fa-hand-sparkles' => 'hand sparkles' ),
					array( 'fa fa-hand-spock' => 'hand spock' ),
					array( 'fa fa-hands-heart' => 'hands heart' ),
					array( 'fa fa-hands-helping' => 'hands helping' ),
					array( 'fa fa-hands-usd' => 'hands usd' ),
					array( 'fa fa-hands-wash' => 'hands wash' ),
					array( 'fa fa-hands' => 'hands' ),
					array( 'fa fa-handshake-alt-slash' => 'handshake alt slash' ),
					array( 'fa fa-handshake-alt' => 'handshake alt' ),
					array( 'fa fa-handshake-slash' => 'handshake slash' ),
					array( 'fa fa-handshake' => 'handshake' ),
					array( 'fa fa-hanukiah' => 'hanukiah' ),
					array( 'fa fa-hard-hat' => 'hard hat' ),
					array( 'fa fa-hashtag' => 'hashtag' ),
					array( 'fa fa-hat-chef' => 'hat chef' ),
					array( 'fa fa-hat-cowboy-side' => 'hat cowboy side' ),
					array( 'fa fa-hat-cowboy' => 'hat cowboy' ),
					array( 'fa fa-hat-santa' => 'hat santa' ),
					array( 'fa fa-hat-winter' => 'hat winter' ),
					array( 'fa fa-hat-witch' => 'hat witch' ),
					array( 'fa fa-hat-wizard' => 'hat wizard' ),
					array( 'fa fa-hdd' => 'hdd' ),
					array( 'fa fa-head-side-brain' => 'head side brain' ),
					array( 'fa fa-head-side-cough-slash' => 'head side cough slash' ),
					array( 'fa fa-head-side-cough' => 'head side cough' ),
					array( 'fa fa-head-side-headphones' => 'head side headphones' ),
					array( 'fa fa-head-side-mask' => 'head side mask' ),
					array( 'fa fa-head-side-medical' => 'head side medical' ),
					array( 'fa fa-head-side-virus' => 'head side virus' ),
					array( 'fa fa-head-side' => 'head side' ),
					array( 'fa fa-head-vr' => 'head vr' ),
					array( 'fa fa-heading' => 'heading' ),
					array( 'fa fa-headphones-alt' => 'headphones alt' ),
					array( 'fa fa-headphones' => 'headphones' ),
					array( 'fa fa-headset' => 'headset' ),
					array( 'fa fa-heart-broken' => 'heart broken' ),
					array( 'fa fa-heart-circle' => 'heart circle' ),
					array( 'fa fa-heart-rate' => 'heart rate' ),
					array( 'fa fa-heart-square' => 'heart square' ),
					array( 'fa fa-heart' => 'heart' ),
					array( 'fa fa-heartbeat' => 'heartbeat' ),
					array( 'fa fa-heat' => 'heat' ),
					array( 'fa fa-helicopter' => 'helicopter' ),
					array( 'fa fa-helmet-battle' => 'helmet battle' ),
					array( 'fa fa-hexagon' => 'hexagon' ),
					array( 'fa fa-highlighter' => 'highlighter' ),
					array( 'fa fa-hiking' => 'hiking' ),
					array( 'fa fa-hippo' => 'hippo' ),
					array( 'fa fa-history' => 'history' ),
					array( 'fa fa-hockey-mask' => 'hockey mask' ),
					array( 'fa fa-hockey-puck' => 'hockey puck' ),
					array( 'fa fa-hockey-sticks' => 'hockey sticks' ),
					array( 'fa fa-holly-berry' => 'holly berry' ),
					array( 'fa fa-home-alt' => 'home alt' ),
					array( 'fa fa-home-heart' => 'home heart' ),
					array( 'fa fa-home-lg-alt' => 'home lg alt' ),
					array( 'fa fa-home-lg' => 'home lg' ),
					array( 'fa fa-home' => 'home' ),
					array( 'fa fa-hood-cloak' => 'hood cloak' ),
					array( 'fa fa-horizontal-rule' => 'horizontal rule' ),
					array( 'fa fa-horse-head' => 'horse head' ),
					array( 'fa fa-horse-saddle' => 'horse saddle' ),
					array( 'fa fa-horse' => 'horse' ),
					array( 'fa fa-hospital-alt' => 'hospital alt' ),
					array( 'fa fa-hospital-symbol' => 'hospital symbol' ),
					array( 'fa fa-hospital-user' => 'hospital user' ),
					array( 'fa fa-hospital' => 'hospital' ),
					array( 'fa fa-hospitals' => 'hospitals' ),
					array( 'fa fa-hot-tub' => 'hot tub' ),
					array( 'fa fa-hotdog' => 'hotdog' ),
					array( 'fa fa-hotel' => 'hotel' ),
					array( 'fa fa-hourglass-end' => 'hourglass end' ),
					array( 'fa fa-hourglass-half' => 'hourglass half' ),
					array( 'fa fa-hourglass-start' => 'hourglass start' ),
					array( 'fa fa-hourglass' => 'hourglass' ),
					array( 'fa fa-house-damage' => 'house damage' ),
					array( 'fa fa-house-day' => 'house day' ),
					array( 'fa fa-house-flood' => 'house flood' ),
					array( 'fa fa-house-leave' => 'house leave' ),
					array( 'fa fa-house-night' => 'house night' ),
					array( 'fa fa-house-return' => 'house return' ),
					array( 'fa fa-house-signal' => 'house signal' ),
					array( 'fa fa-house-user' => 'house user' ),
					array( 'fa fa-house' => 'house' ),
					array( 'fa fa-hryvnia' => 'hryvnia' ),
					array( 'fa fa-humidity' => 'humidity' ),
					array( 'fa fa-hurricane' => 'hurricane' ),
					array( 'fa fa-i-cursor' => 'i cursor' ),
					array( 'fa fa-ice-cream' => 'ice cream' ),
					array( 'fa fa-ice-skate' => 'ice skate' ),
					array( 'fa fa-icicles' => 'icicles' ),
					array( 'fa fa-icons-alt' => 'icons alt' ),
					array( 'fa fa-icons' => 'icons' ),
					array( 'fa fa-id-badge' => 'id badge' ),
					array( 'fa fa-id-card-alt' => 'id card alt' ),
					array( 'fa fa-id-card' => 'id card' ),
					array( 'fa fa-igloo' => 'igloo' ),
					array( 'fa fa-image-polaroid' => 'image polaroid' ),
					array( 'fa fa-image' => 'image' ),
					array( 'fa fa-images' => 'images' ),
					array( 'fa fa-inbox-in' => 'inbox in' ),
					array( 'fa fa-inbox-out' => 'inbox out' ),
					array( 'fa fa-inbox' => 'inbox' ),
					array( 'fa fa-indent' => 'indent' ),
					array( 'fa fa-industry-alt' => 'industry alt' ),
					array( 'fa fa-industry' => 'industry' ),
					array( 'fa fa-infinity' => 'infinity' ),
					array( 'fa fa-info-circle' => 'info circle' ),
					array( 'fa fa-info-square' => 'info square' ),
					array( 'fa fa-info' => 'info' ),
					array( 'fa fa-inhaler' => 'inhaler' ),
					array( 'fa fa-integral' => 'integral' ),
					array( 'fa fa-intersection' => 'intersection' ),
					array( 'fa fa-inventory' => 'inventory' ),
					array( 'fa fa-island-tropical' => 'island tropical' ),
					array( 'fa fa-italic' => 'italic' ),
					array( 'fa fa-jack-o-lantern' => 'jack o lantern' ),
					array( 'fa fa-jedi' => 'jedi' ),
					array( 'fa fa-joint' => 'joint' ),
					array( 'fa fa-journal-whills' => 'journal whills' ),
					array( 'fa fa-joystick' => 'joystick' ),
					array( 'fa fa-jug' => 'jug' ),
					array( 'fa fa-kaaba' => 'kaaba' ),
					array( 'fa fa-kazoo' => 'kazoo' ),
					array( 'fa fa-kerning' => 'kerning' ),
					array( 'fa fa-key-skeleton' => 'key skeleton' ),
					array( 'fa fa-key' => 'key' ),
					array( 'fa fa-keyboard' => 'keyboard' ),
					array( 'fa fa-keynote' => 'keynote' ),
					array( 'fa fa-khanda' => 'khanda' ),
					array( 'fa fa-kidneys' => 'kidneys' ),
					array( 'fa fa-kiss-beam' => 'kiss beam' ),
					array( 'fa fa-kiss-wink-heart' => 'kiss wink heart' ),
					array( 'fa fa-kiss' => 'kiss' ),
					array( 'fa fa-kite' => 'kite' ),
					array( 'fa fa-kiwi-bird' => 'kiwi bird' ),
					array( 'fa fa-knife-kitchen' => 'knife kitchen' ),
					array( 'fa fa-lambda' => 'lambda' ),
					array( 'fa fa-lamp-desk' => 'lamp desk' ),
					array( 'fa fa-lamp-floor' => 'lamp floor' ),
					array( 'fa fa-lamp' => 'lamp' ),
					array( 'fa fa-landmark-alt' => 'landmark alt' ),
					array( 'fa fa-landmark' => 'landmark' ),
					array( 'fa fa-language' => 'language' ),
					array( 'fa fa-laptop-code' => 'laptop code' ),
					array( 'fa fa-laptop-house' => 'laptop house' ),
					array( 'fa fa-laptop-medical' => 'laptop medical' ),
					array( 'fa fa-laptop' => 'laptop' ),
					array( 'fa fa-lasso' => 'lasso' ),
					array( 'fa fa-laugh-beam' => 'laugh beam' ),
					array( 'fa fa-laugh-squint' => 'laugh squint' ),
					array( 'fa fa-laugh-wink' => 'laugh wink' ),
					array( 'fa fa-laugh' => 'laugh' ),
					array( 'fa fa-layer-group' => 'layer group' ),
					array( 'fa fa-layer-minus' => 'layer minus' ),
					array( 'fa fa-layer-plus' => 'layer plus' ),
					array( 'fa fa-leaf-heart' => 'leaf heart' ),
					array( 'fa fa-leaf-maple' => 'leaf maple' ),
					array( 'fa fa-leaf-oak' => 'leaf oak' ),
					array( 'fa fa-leaf' => 'leaf' ),
					array( 'fa fa-lemon' => 'lemon' ),
					array( 'fa fa-less-than-equal' => 'less than equal' ),
					array( 'fa fa-less-than' => 'less than' ),
					array( 'fa fa-level-down-alt' => 'level down alt' ),
					array( 'fa fa-level-down' => 'level down' ),
					array( 'fa fa-level-up-alt' => 'level up alt' ),
					array( 'fa fa-level-up' => 'level up' ),
					array( 'fa fa-life-ring' => 'life ring' ),
					array( 'fa fa-light-ceiling' => 'light ceiling' ),
					array( 'fa fa-light-switch-off' => 'light switch off' ),
					array( 'fa fa-light-switch-on' => 'light switch on' ),
					array( 'fa fa-light-switch' => 'light switch' ),
					array( 'fa fa-lightbulb-dollar' => 'lightbulb dollar' ),
					array( 'fa fa-lightbulb-exclamation' => 'lightbulb exclamation' ),
					array( 'fa fa-lightbulb-on' => 'lightbulb on' ),
					array( 'fa fa-lightbulb-slash' => 'lightbulb slash' ),
					array( 'fa fa-lightbulb' => 'lightbulb' ),
					array( 'fa fa-lights-holiday' => 'lights holiday' ),
					array( 'fa fa-line-columns' => 'line columns' ),
					array( 'fa fa-line-height' => 'line height' ),
					array( 'fa fa-link' => 'link' ),
					array( 'fa fa-lips' => 'lips' ),
					array( 'fa fa-lira-sign' => 'lira sign' ),
					array( 'fa fa-list-alt' => 'list alt' ),
					array( 'fa fa-list-music' => 'list music' ),
					array( 'fa fa-list-ol' => 'list ol' ),
					array( 'fa fa-list-ul' => 'list ul' ),
					array( 'fa fa-list' => 'list' ),
					array( 'fa fa-location-arrow' => 'location arrow' ),
					array( 'fa fa-location-circle' => 'location circle' ),
					array( 'fa fa-location-slash' => 'location slash' ),
					array( 'fa fa-location' => 'location' ),
					array( 'fa fa-lock-alt' => 'lock alt' ),
					array( 'fa fa-lock-open-alt' => 'lock open alt' ),
					array( 'fa fa-lock-open' => 'lock open' ),
					array( 'fa fa-lock' => 'lock' ),
					array( 'fa fa-long-arrow-alt-down' => 'long arrow alt down' ),
					array( 'fa fa-long-arrow-alt-left' => 'long arrow alt left' ),
					array( 'fa fa-long-arrow-alt-right' => 'long arrow alt right' ),
					array( 'fa fa-long-arrow-alt-up' => 'long arrow alt up' ),
					array( 'fa fa-long-arrow-down' => 'long arrow down' ),
					array( 'fa fa-long-arrow-left' => 'long arrow left' ),
					array( 'fa fa-long-arrow-right' => 'long arrow right' ),
					array( 'fa fa-long-arrow-up' => 'long arrow up' ),
					array( 'fa fa-loveseat' => 'loveseat' ),
					array( 'fa fa-low-vision' => 'low vision' ),
					array( 'fa fa-luchador' => 'luchador' ),
					array( 'fa fa-luggage-cart' => 'luggage cart' ),
					array( 'fa fa-lungs-virus' => 'lungs virus' ),
					array( 'fa fa-lungs' => 'lungs' ),
					array( 'fa fa-mace' => 'mace' ),
					array( 'fa fa-magic' => 'magic' ),
					array( 'fa fa-magnet' => 'magnet' ),
					array( 'fa fa-mail-bulk' => 'mail bulk' ),
					array( 'fa fa-mailbox' => 'mailbox' ),
					array( 'fa fa-male' => 'male' ),
					array( 'fa fa-mandolin' => 'mandolin' ),
					array( 'fa fa-map-marked-alt' => 'map marked alt' ),
					array( 'fa fa-map-marked' => 'map marked' ),
					array( 'fa fa-map-marker-alt-slash' => 'map marker alt slash' ),
					array( 'fa fa-map-marker-alt' => 'map marker alt' ),
					array( 'fa fa-map-marker-check' => 'map marker check' ),
					array( 'fa fa-map-marker-edit' => 'map marker edit' ),
					array( 'fa fa-map-marker-exclamation' => 'map marker exclamation' ),
					array( 'fa fa-map-marker-minus' => 'map marker minus' ),
					array( 'fa fa-map-marker-plus' => 'map marker plus' ),
					array( 'fa fa-map-marker-question' => 'map marker question' ),
					array( 'fa fa-map-marker-slash' => 'map marker slash' ),
					array( 'fa fa-map-marker-smile' => 'map marker smile' ),
					array( 'fa fa-map-marker-times' => 'map marker times' ),
					array( 'fa fa-map-marker' => 'map marker' ),
					array( 'fa fa-map-pin' => 'map pin' ),
					array( 'fa fa-map-signs' => 'map signs' ),
					array( 'fa fa-map' => 'map' ),
					array( 'fa fa-marker' => 'marker' ),
					array( 'fa fa-mars-double' => 'mars double' ),
					array( 'fa fa-mars-stroke-h' => 'mars stroke h' ),
					array( 'fa fa-mars-stroke-v' => 'mars stroke v' ),
					array( 'fa fa-mars-stroke' => 'mars stroke' ),
					array( 'fa fa-mars' => 'mars' ),
					array( 'fa fa-mask' => 'mask' ),
					array( 'fa fa-meat' => 'meat' ),
					array( 'fa fa-medal' => 'medal' ),
					array( 'fa fa-medkit' => 'medkit' ),
					array( 'fa fa-megaphone' => 'megaphone' ),
					array( 'fa fa-meh-blank' => 'meh blank' ),
					array( 'fa fa-meh-rolling-eyes' => 'meh rolling eyes' ),
					array( 'fa fa-meh' => 'meh' ),
					array( 'fa fa-memory' => 'memory' ),
					array( 'fa fa-menorah' => 'menorah' ),
					array( 'fa fa-mercury' => 'mercury' ),
					array( 'fa fa-meteor' => 'meteor' ),
					array( 'fa fa-microchip' => 'microchip' ),
					array( 'fa fa-microphone-alt-slash' => 'microphone alt slash' ),
					array( 'fa fa-microphone-alt' => 'microphone alt' ),
					array( 'fa fa-microphone-slash' => 'microphone slash' ),
					array( 'fa fa-microphone-stand' => 'microphone stand' ),
					array( 'fa fa-microphone' => 'microphone' ),
					array( 'fa fa-microscope' => 'microscope' ),
					array( 'fa fa-microwave' => 'microwave' ),
					array( 'fa fa-mind-share' => 'mind share' ),
					array( 'fa fa-minus-circle' => 'minus circle' ),
					array( 'fa fa-minus-hexagon' => 'minus hexagon' ),
					array( 'fa fa-minus-octagon' => 'minus octagon' ),
					array( 'fa fa-minus-square' => 'minus square' ),
					array( 'fa fa-minus' => 'minus' ),
					array( 'fa fa-mistletoe' => 'mistletoe' ),
					array( 'fa fa-mitten' => 'mitten' ),
					array( 'fa fa-mobile-alt' => 'mobile alt' ),
					array( 'fa fa-mobile-android-alt' => 'mobile android alt' ),
					array( 'fa fa-mobile-android' => 'mobile android' ),
					array( 'fa fa-mobile' => 'mobile' ),
					array( 'fa fa-money-bill-alt' => 'money bill alt' ),
					array( 'fa fa-money-bill-wave-alt' => 'money bill wave alt' ),
					array( 'fa fa-money-bill-wave' => 'money bill wave' ),
					array( 'fa fa-money-bill' => 'money bill' ),
					array( 'fa fa-money-check-alt' => 'money check alt' ),
					array( 'fa fa-money-check-edit-alt' => 'money check edit alt' ),
					array( 'fa fa-money-check-edit' => 'money check edit' ),
					array( 'fa fa-money-check' => 'money check' ),
					array( 'fa fa-monitor-heart-rate' => 'monitor heart rate' ),
					array( 'fa fa-monkey' => 'monkey' ),
					array( 'fa fa-monument' => 'monument' ),
					array( 'fa fa-moon-cloud' => 'moon cloud' ),
					array( 'fa fa-moon-stars' => 'moon stars' ),
					array( 'fa fa-moon' => 'moon' ),
					array( 'fa fa-mortar-pestle' => 'mortar pestle' ),
					array( 'fa fa-mosque' => 'mosque' ),
					array( 'fa fa-motorcycle' => 'motorcycle' ),
					array( 'fa fa-mountain' => 'mountain' ),
					array( 'fa fa-mountains' => 'mountains' ),
					array( 'fa fa-mouse-alt' => 'mouse alt' ),
					array( 'fa fa-mouse-pointer' => 'mouse pointer' ),
					array( 'fa fa-mouse' => 'mouse' ),
					array( 'fa fa-mp3-player' => 'mp3 player' ),
					array( 'fa fa-mug-hot' => 'mug hot' ),
					array( 'fa fa-mug-marshmallows' => 'mug marshmallows' ),
					array( 'fa fa-mug-tea' => 'mug tea' ),
					array( 'fa fa-mug' => 'mug' ),
					array( 'fa fa-music-alt-slash' => 'music alt slash' ),
					array( 'fa fa-music-alt' => 'music alt' ),
					array( 'fa fa-music-slash' => 'music slash' ),
					array( 'fa fa-music' => 'music' ),
					array( 'fa fa-narwhal' => 'narwhal' ),
					array( 'fa fa-network-wired' => 'network wired' ),
					array( 'fa fa-neuter' => 'neuter' ),
					array( 'fa fa-newspaper' => 'newspaper' ),
					array( 'fa fa-not-equal' => 'not equal' ),
					array( 'fa fa-notes-medical' => 'notes medical' ),
					array( 'fa fa-object-group' => 'object group' ),
					array( 'fa fa-object-ungroup' => 'object ungroup' ),
					array( 'fa fa-octagon' => 'octagon' ),
					array( 'fa fa-oil-can' => 'oil can' ),
					array( 'fa fa-oil-temp' => 'oil temp' ),
					array( 'fa fa-om' => 'om' ),
					array( 'fa fa-omega' => 'omega' ),
					array( 'fa fa-ornament' => 'ornament' ),
					array( 'fa fa-otter' => 'otter' ),
					array( 'fa fa-outdent' => 'outdent' ),
					array( 'fa fa-outlet' => 'outlet' ),
					array( 'fa fa-oven' => 'oven' ),
					array( 'fa fa-overline' => 'overline' ),
					array( 'fa fa-page-break' => 'page break' ),
					array( 'fa fa-pager' => 'pager' ),
					array( 'fa fa-paint-brush-alt' => 'paint brush alt' ),
					array( 'fa fa-paint-brush' => 'paint brush' ),
					array( 'fa fa-paint-roller' => 'paint roller' ),
					array( 'fa fa-palette' => 'palette' ),
					array( 'fa fa-pallet-alt' => 'pallet alt' ),
					array( 'fa fa-pallet' => 'pallet' ),
					array( 'fa fa-paper-plane' => 'paper plane' ),
					array( 'fa fa-paperclip' => 'paperclip' ),
					array( 'fa fa-parachute-box' => 'parachute box' ),
					array( 'fa fa-paragraph-rtl' => 'paragraph rtl' ),
					array( 'fa fa-paragraph' => 'paragraph' ),
					array( 'fa fa-parking-circle-slash' => 'parking circle slash' ),
					array( 'fa fa-parking-circle' => 'parking circle' ),
					array( 'fa fa-parking-slash' => 'parking slash' ),
					array( 'fa fa-parking' => 'parking' ),
					array( 'fa fa-passport' => 'passport' ),
					array( 'fa fa-pastafarianism' => 'pastafarianism' ),
					array( 'fa fa-paste' => 'paste' ),
					array( 'fa fa-pause-circle' => 'pause circle' ),
					array( 'fa fa-pause' => 'pause' ),
					array( 'fa fa-paw-alt' => 'paw alt' ),
					array( 'fa fa-paw-claws' => 'paw claws' ),
					array( 'fa fa-paw' => 'paw' ),
					array( 'fa fa-peace' => 'peace' ),
					array( 'fa fa-pegasus' => 'pegasus' ),
					array( 'fa fa-pen-alt' => 'pen alt' ),
					array( 'fa fa-pen-fancy' => 'pen fancy' ),
					array( 'fa fa-pen-nib' => 'pen nib' ),
					array( 'fa fa-pen-square' => 'pen square' ),
					array( 'fa fa-pen' => 'pen' ),
					array( 'fa fa-pencil-alt' => 'pencil alt' ),
					array( 'fa fa-pencil-paintbrush' => 'pencil paintbrush' ),
					array( 'fa fa-pencil-ruler' => 'pencil ruler' ),
					array( 'fa fa-pencil' => 'pencil' ),
					array( 'fa fa-pennant' => 'pennant' ),
					array( 'fa fa-people-arrows' => 'people arrows' ),
					array( 'fa fa-people-carry' => 'people carry' ),
					array( 'fa fa-pepper-hot' => 'pepper hot' ),
					array( 'fa fa-percent' => 'percent' ),
					array( 'fa fa-percentage' => 'percentage' ),
					array( 'fa fa-person-booth' => 'person booth' ),
					array( 'fa fa-person-carry' => 'person carry' ),
					array( 'fa fa-person-dolly-empty' => 'person dolly empty' ),
					array( 'fa fa-person-dolly' => 'person dolly' ),
					array( 'fa fa-person-sign' => 'person sign' ),
					array( 'fa fa-phone-alt' => 'phone alt' ),
					array( 'fa fa-phone-laptop' => 'phone laptop' ),
					array( 'fa fa-phone-office' => 'phone office' ),
					array( 'fa fa-phone-plus' => 'phone plus' ),
					array( 'fa fa-phone-rotary' => 'phone rotary' ),
					array( 'fa fa-phone-slash' => 'phone slash' ),
					array( 'fa fa-phone-square-alt' => 'phone square alt' ),
					array( 'fa fa-phone-square' => 'phone square' ),
					array( 'fa fa-phone-volume' => 'phone volume' ),
					array( 'fa fa-phone' => 'phone' ),
					array( 'fa fa-photo-video' => 'photo video' ),
					array( 'fa fa-pi' => 'pi' ),
					array( 'fa fa-piano-keyboard' => 'piano keyboard' ),
					array( 'fa fa-piano' => 'piano' ),
					array( 'fa fa-pie' => 'pie' ),
					array( 'fa fa-pig' => 'pig' ),
					array( 'fa fa-piggy-bank' => 'piggy bank' ),
					array( 'fa fa-pills' => 'pills' ),
					array( 'fa fa-pizza-slice' => 'pizza slice' ),
					array( 'fa fa-pizza' => 'pizza' ),
					array( 'fa fa-place-of-worship' => 'place of worship' ),
					array( 'fa fa-plane-alt' => 'plane alt' ),
					array( 'fa fa-plane-arrival' => 'plane arrival' ),
					array( 'fa fa-plane-departure' => 'plane departure' ),
					array( 'fa fa-plane-slash' => 'plane slash' ),
					array( 'fa fa-plane' => 'plane' ),
					array( 'fa fa-planet-moon' => 'planet moon' ),
					array( 'fa fa-planet-ringed' => 'planet ringed' ),
					array( 'fa fa-play-circle' => 'play circle' ),
					array( 'fa fa-play' => 'play' ),
					array( 'fa fa-plug' => 'plug' ),
					array( 'fa fa-plus-circle' => 'plus circle' ),
					array( 'fa fa-plus-hexagon' => 'plus hexagon' ),
					array( 'fa fa-plus-octagon' => 'plus octagon' ),
					array( 'fa fa-plus-square' => 'plus square' ),
					array( 'fa fa-plus' => 'plus' ),
					array( 'fa fa-podcast' => 'podcast' ),
					array( 'fa fa-podium-star' => 'podium star' ),
					array( 'fa fa-podium' => 'podium' ),
					array( 'fa fa-police-box' => 'police box' ),
					array( 'fa fa-poll-h' => 'poll h' ),
					array( 'fa fa-poll-people' => 'poll people' ),
					array( 'fa fa-poll' => 'poll' ),
					array( 'fa fa-poo-storm' => 'poo storm' ),
					array( 'fa fa-poo' => 'poo' ),
					array( 'fa fa-poop' => 'poop' ),
					array( 'fa fa-popcorn' => 'popcorn' ),
					array( 'fa fa-portal-enter' => 'portal enter' ),
					array( 'fa fa-portal-exit' => 'portal exit' ),
					array( 'fa fa-portrait' => 'portrait' ),
					array( 'fa fa-pound-sign' => 'pound sign' ),
					array( 'fa fa-power-off' => 'power off' ),
					array( 'fa fa-pray' => 'pray' ),
					array( 'fa fa-praying-hands' => 'praying hands' ),
					array( 'fa fa-prescription-bottle-alt' => 'prescription bottle alt' ),
					array( 'fa fa-prescription-bottle' => 'prescription bottle' ),
					array( 'fa fa-prescription' => 'prescription' ),
					array( 'fa fa-presentation' => 'presentation' ),
					array( 'fa fa-print-search' => 'print search' ),
					array( 'fa fa-print-slash' => 'print slash' ),
					array( 'fa fa-print' => 'print' ),
					array( 'fa fa-procedures' => 'procedures' ),
					array( 'fa fa-project-diagram' => 'project diagram' ),
					array( 'fa fa-projector' => 'projector' ),
					array( 'fa fa-pump-medical' => 'pump medical' ),
					array( 'fa fa-pump-soap' => 'pump soap' ),
					array( 'fa fa-pumpkin' => 'pumpkin' ),
					array( 'fa fa-puzzle-piece' => 'puzzle piece' ),
					array( 'fa fa-qrcode' => 'qrcode' ),
					array( 'fa fa-question-circle' => 'question circle' ),
					array( 'fa fa-question-square' => 'question square' ),
					array( 'fa fa-question' => 'question' ),
					array( 'fa fa-quidditch' => 'quidditch' ),
					array( 'fa fa-quote-left' => 'quote left' ),
					array( 'fa fa-quote-right' => 'quote right' ),
					array( 'fa fa-quran' => 'quran' ),
					array( 'fa fa-rabbit-fast' => 'rabbit fast' ),
					array( 'fa fa-rabbit' => 'rabbit' ),
					array( 'fa fa-racquet' => 'racquet' ),
					array( 'fa fa-radar' => 'radar' ),
					array( 'fa fa-radiation-alt' => 'radiation alt' ),
					array( 'fa fa-radiation' => 'radiation' ),
					array( 'fa fa-radio-alt' => 'radio alt' ),
					array( 'fa fa-radio' => 'radio' ),
					array( 'fa fa-rainbow' => 'rainbow' ),
					array( 'fa fa-raindrops' => 'raindrops' ),
					array( 'fa fa-ram' => 'ram' ),
					array( 'fa fa-ramp-loading' => 'ramp loading' ),
					array( 'fa fa-random' => 'random' ),
					array( 'fa fa-raygun' => 'raygun' ),
					array( 'fa fa-receipt' => 'receipt' ),
					array( 'fa fa-record-vinyl' => 'record vinyl' ),
					array( 'fa fa-rectangle-landscape' => 'rectangle landscape' ),
					array( 'fa fa-rectangle-portrait' => 'rectangle portrait' ),
					array( 'fa fa-rectangle-wide' => 'rectangle wide' ),
					array( 'fa fa-recycle' => 'recycle' ),
					array( 'fa fa-redo-alt' => 'redo alt' ),
					array( 'fa fa-redo' => 'redo' ),
					array( 'fa fa-refrigerator' => 'refrigerator' ),
					array( 'fa fa-registered' => 'registered' ),
					array( 'fa fa-remove-format' => 'remove format' ),
					array( 'fa fa-repeat-1-alt' => 'repeat 1 alt' ),
					array( 'fa fa-repeat-1' => 'repeat 1' ),
					array( 'fa fa-repeat-alt' => 'repeat alt' ),
					array( 'fa fa-repeat' => 'repeat' ),
					array( 'fa fa-reply-all' => 'reply all' ),
					array( 'fa fa-reply' => 'reply' ),
					array( 'fa fa-republican' => 'republican' ),
					array( 'fa fa-restroom' => 'restroom' ),
					array( 'fa fa-retweet-alt' => 'retweet alt' ),
					array( 'fa fa-retweet' => 'retweet' ),
					array( 'fa fa-ribbon' => 'ribbon' ),
					array( 'fa fa-ring' => 'ring' ),
					array( 'fa fa-rings-wedding' => 'rings wedding' ),
					array( 'fa fa-road' => 'road' ),
					array( 'fa fa-robot' => 'robot' ),
					array( 'fa fa-rocket-launch' => 'rocket launch' ),
					array( 'fa fa-rocket' => 'rocket' ),
					array( 'fa fa-route-highway' => 'route highway' ),
					array( 'fa fa-route-interstate' => 'route interstate' ),
					array( 'fa fa-route' => 'route' ),
					array( 'fa fa-router' => 'router' ),
					array( 'fa fa-rss-square' => 'rss square' ),
					array( 'fa fa-rss' => 'rss' ),
					array( 'fa fa-ruble-sign' => 'ruble sign' ),
					array( 'fa fa-ruler-combined' => 'ruler combined' ),
					array( 'fa fa-ruler-horizontal' => 'ruler horizontal' ),
					array( 'fa fa-ruler-triangle' => 'ruler triangle' ),
					array( 'fa fa-ruler-vertical' => 'ruler vertical' ),
					array( 'fa fa-ruler' => 'ruler' ),
					array( 'fa fa-running' => 'running' ),
					array( 'fa fa-rupee-sign' => 'rupee sign' ),
					array( 'fa fa-rv' => 'rv' ),
					array( 'fa fa-sack-dollar' => 'sack dollar' ),
					array( 'fa fa-sack' => 'sack' ),
					array( 'fa fa-sad-cry' => 'sad cry' ),
					array( 'fa fa-sad-tear' => 'sad tear' ),
					array( 'fa fa-salad' => 'salad' ),
					array( 'fa fa-sandwich' => 'sandwich' ),
					array( 'fa fa-satellite-dish' => 'satellite dish' ),
					array( 'fa fa-satellite' => 'satellite' ),
					array( 'fa fa-sausage' => 'sausage' ),
					array( 'fa fa-save' => 'save' ),
					array( 'fa fa-sax-hot' => 'sax hot' ),
					array( 'fa fa-saxophone' => 'saxophone' ),
					array( 'fa fa-scalpel-path' => 'scalpel path' ),
					array( 'fa fa-scalpel' => 'scalpel' ),
					array( 'fa fa-scanner-image' => 'scanner image' ),
					array( 'fa fa-scanner-keyboard' => 'scanner keyboard' ),
					array( 'fa fa-scanner-touchscreen' => 'scanner touchscreen' ),
					array( 'fa fa-scanner' => 'scanner' ),
					array( 'fa fa-scarecrow' => 'scarecrow' ),
					array( 'fa fa-scarf' => 'scarf' ),
					array( 'fa fa-school' => 'school' ),
					array( 'fa fa-screwdriver' => 'screwdriver' ),
					array( 'fa fa-scroll-old' => 'scroll old' ),
					array( 'fa fa-scroll' => 'scroll' ),
					array( 'fa fa-scrubber' => 'scrubber' ),
					array( 'fa fa-scythe' => 'scythe' ),
					array( 'fa fa-sd-card' => 'sd card' ),
					array( 'fa fa-search-dollar' => 'search dollar' ),
					array( 'fa fa-search-location' => 'search location' ),
					array( 'fa fa-search-minus' => 'search minus' ),
					array( 'fa fa-search-plus' => 'search plus' ),
					array( 'fa fa-search' => 'search' ),
					array( 'fa fa-seedling' => 'seedling' ),
					array( 'fa fa-send-back' => 'send back' ),
					array( 'fa fa-send-backward' => 'send backward' ),
					array( 'fa fa-sensor-alert' => 'sensor alert' ),
					array( 'fa fa-sensor-fire' => 'sensor fire' ),
					array( 'fa fa-sensor-on' => 'sensor on' ),
					array( 'fa fa-sensor-smoke' => 'sensor smoke' ),
					array( 'fa fa-sensor' => 'sensor' ),
					array( 'fa fa-server' => 'server' ),
					array( 'fa fa-shapes' => 'shapes' ),
					array( 'fa fa-share-all' => 'share all' ),
					array( 'fa fa-share-alt-square' => 'share alt square' ),
					array( 'fa fa-share-alt' => 'share alt' ),
					array( 'fa fa-share-square' => 'share square' ),
					array( 'fa fa-share' => 'share' ),
					array( 'fa fa-sheep' => 'sheep' ),
					array( 'fa fa-shekel-sign' => 'shekel sign' ),
					array( 'fa fa-shield-alt' => 'shield alt' ),
					array( 'fa fa-shield-check' => 'shield check' ),
					array( 'fa fa-shield-cross' => 'shield cross' ),
					array( 'fa fa-shield-virus' => 'shield virus' ),
					array( 'fa fa-shield' => 'shield' ),
					array( 'fa fa-ship' => 'ship' ),
					array( 'fa fa-shipping-fast' => 'shipping fast' ),
					array( 'fa fa-shipping-timed' => 'shipping timed' ),
					array( 'fa fa-shish-kebab' => 'shish kebab' ),
					array( 'fa fa-shoe-prints' => 'shoe prints' ),
					array( 'fa fa-shopping-bag' => 'shopping bag' ),
					array( 'fa fa-shopping-basket' => 'shopping basket' ),
					array( 'fa fa-shopping-cart' => 'shopping cart' ),
					array( 'fa fa-shovel-snow' => 'shovel snow' ),
					array( 'fa fa-shovel' => 'shovel' ),
					array( 'fa fa-shower' => 'shower' ),
					array( 'fa fa-shredder' => 'shredder' ),
					array( 'fa fa-shuttle-van' => 'shuttle van' ),
					array( 'fa fa-shuttlecock' => 'shuttlecock' ),
					array( 'fa fa-sickle' => 'sickle' ),
					array( 'fa fa-sigma' => 'sigma' ),
					array( 'fa fa-sign-in-alt' => 'sign in alt' ),
					array( 'fa fa-sign-in' => 'sign in' ),
					array( 'fa fa-sign-language' => 'sign language' ),
					array( 'fa fa-sign-out-alt' => 'sign out alt' ),
					array( 'fa fa-sign-out' => 'sign out' ),
					array( 'fa fa-sign' => 'sign' ),
					array( 'fa fa-signal-1' => 'signal 1' ),
					array( 'fa fa-signal-2' => 'signal 2' ),
					array( 'fa fa-signal-3' => 'signal 3' ),
					array( 'fa fa-signal-4' => 'signal 4' ),
					array( 'fa fa-signal-alt-1' => 'signal alt 1' ),
					array( 'fa fa-signal-alt-2' => 'signal alt 2' ),
					array( 'fa fa-signal-alt-3' => 'signal alt 3' ),
					array( 'fa fa-signal-alt-slash' => 'signal alt slash' ),
					array( 'fa fa-signal-alt' => 'signal alt' ),
					array( 'fa fa-signal-slash' => 'signal slash' ),
					array( 'fa fa-signal-stream' => 'signal stream' ),
					array( 'fa fa-signal' => 'signal' ),
					array( 'fa fa-signature' => 'signature' ),
					array( 'fa fa-sim-card' => 'sim card' ),
					array( 'fa fa-sink' => 'sink' ),
					array( 'fa fa-siren-on' => 'siren on' ),
					array( 'fa fa-siren' => 'siren' ),
					array( 'fa fa-sitemap' => 'sitemap' ),
					array( 'fa fa-skating' => 'skating' ),
					array( 'fa fa-skeleton' => 'skeleton' ),
					array( 'fa fa-ski-jump' => 'ski jump' ),
					array( 'fa fa-ski-lift' => 'ski lift' ),
					array( 'fa fa-skiing-nordic' => 'skiing nordic' ),
					array( 'fa fa-skiing' => 'skiing' ),
					array( 'fa fa-skull-cow' => 'skull cow' ),
					array( 'fa fa-skull-crossbones' => 'skull crossbones' ),
					array( 'fa fa-skull' => 'skull' ),
					array( 'fa fa-slash' => 'slash' ),
					array( 'fa fa-sledding' => 'sledding' ),
					array( 'fa fa-sleigh' => 'sleigh' ),
					array( 'fa fa-sliders-h-square' => 'sliders h square' ),
					array( 'fa fa-sliders-h' => 'sliders h' ),
					array( 'fa fa-sliders-v-square' => 'sliders v square' ),
					array( 'fa fa-sliders-v' => 'sliders v' ),
					array( 'fa fa-smile-beam' => 'smile beam' ),
					array( 'fa fa-smile-plus' => 'smile plus' ),
					array( 'fa fa-smile-wink' => 'smile wink' ),
					array( 'fa fa-smile' => 'smile' ),
					array( 'fa fa-smog' => 'smog' ),
					array( 'fa fa-smoke' => 'smoke' ),
					array( 'fa fa-smoking-ban' => 'smoking ban' ),
					array( 'fa fa-smoking' => 'smoking' ),
					array( 'fa fa-sms' => 'sms' ),
					array( 'fa fa-snake' => 'snake' ),
					array( 'fa fa-snooze' => 'snooze' ),
					array( 'fa fa-snow-blowing' => 'snow blowing' ),
					array( 'fa fa-snowboarding' => 'snowboarding' ),
					array( 'fa fa-snowflake' => 'snowflake' ),
					array( 'fa fa-snowflakes' => 'snowflakes' ),
					array( 'fa fa-snowman' => 'snowman' ),
					array( 'fa fa-snowmobile' => 'snowmobile' ),
					array( 'fa fa-snowplow' => 'snowplow' ),
					array( 'fa fa-soap' => 'soap' ),
					array( 'fa fa-socks' => 'socks' ),
					array( 'fa fa-solar-panel' => 'solar panel' ),
					array( 'fa fa-solar-system' => 'solar system' ),
					array( 'fa fa-sort-alpha-down-alt' => 'sort alpha down alt' ),
					array( 'fa fa-sort-alpha-down' => 'sort alpha down' ),
					array( 'fa fa-sort-alpha-up-alt' => 'sort alpha up alt' ),
					array( 'fa fa-sort-alpha-up' => 'sort alpha up' ),
					array( 'fa fa-sort-alt' => 'sort alt' ),
					array( 'fa fa-sort-amount-down-alt' => 'sort amount down alt' ),
					array( 'fa fa-sort-amount-down' => 'sort amount down' ),
					array( 'fa fa-sort-amount-up-alt' => 'sort amount up alt' ),
					array( 'fa fa-sort-amount-up' => 'sort amount up' ),
					array( 'fa fa-sort-circle-down' => 'sort circle down' ),
					array( 'fa fa-sort-circle-up' => 'sort circle up' ),
					array( 'fa fa-sort-circle' => 'sort circle' ),
					array( 'fa fa-sort-down' => 'sort down' ),
					array( 'fa fa-sort-numeric-down-alt' => 'sort numeric down alt' ),
					array( 'fa fa-sort-numeric-down' => 'sort numeric down' ),
					array( 'fa fa-sort-numeric-up-alt' => 'sort numeric up alt' ),
					array( 'fa fa-sort-numeric-up' => 'sort numeric up' ),
					array( 'fa fa-sort-shapes-down-alt' => 'sort shapes down alt' ),
					array( 'fa fa-sort-shapes-down' => 'sort shapes down' ),
					array( 'fa fa-sort-shapes-up-alt' => 'sort shapes up alt' ),
					array( 'fa fa-sort-shapes-up' => 'sort shapes up' ),
					array( 'fa fa-sort-size-down-alt' => 'sort size down alt' ),
					array( 'fa fa-sort-size-down' => 'sort size down' ),
					array( 'fa fa-sort-size-up-alt' => 'sort size up alt' ),
					array( 'fa fa-sort-size-up' => 'sort size up' ),
					array( 'fa fa-sort-up' => 'sort up' ),
					array( 'fa fa-sort' => 'sort' ),
					array( 'fa fa-soup' => 'soup' ),
					array( 'fa fa-spa' => 'spa' ),
					array( 'fa fa-space-shuttle' => 'space shuttle' ),
					array( 'fa fa-space-station-moon-alt' => 'space station moon alt' ),
					array( 'fa fa-space-station-moon' => 'space station moon' ),
					array( 'fa fa-spade' => 'spade' ),
					array( 'fa fa-sparkles' => 'sparkles' ),
					array( 'fa fa-speaker' => 'speaker' ),
					array( 'fa fa-speakers' => 'speakers' ),
					array( 'fa fa-spell-check' => 'spell check' ),
					array( 'fa fa-spider-black-widow' => 'spider black widow' ),
					array( 'fa fa-spider-web' => 'spider web' ),
					array( 'fa fa-spider' => 'spider' ),
					array( 'fa fa-spinner-third' => 'spinner third' ),
					array( 'fa fa-spinner' => 'spinner' ),
					array( 'fa fa-splotch' => 'splotch' ),
					array( 'fa fa-spray-can' => 'spray can' ),
					array( 'fa fa-sprinkler' => 'sprinkler' ),
					array( 'fa fa-square-full' => 'square full' ),
					array( 'fa fa-square-root-alt' => 'square root alt' ),
					array( 'fa fa-square-root' => 'square root' ),
					array( 'fa fa-square' => 'square' ),
					array( 'fa fa-squirrel' => 'squirrel' ),
					array( 'fa fa-staff' => 'staff' ),
					array( 'fa fa-stamp' => 'stamp' ),
					array( 'fa fa-star-and-crescent' => 'star and crescent' ),
					array( 'fa fa-star-christmas' => 'star christmas' ),
					array( 'fa fa-star-exclamation' => 'star exclamation' ),
					array( 'fa fa-star-half-alt' => 'star half alt' ),
					array( 'fa fa-star-half' => 'star half' ),
					array( 'fa fa-star-of-david' => 'star of david' ),
					array( 'fa fa-star-of-life' => 'star of life' ),
					array( 'fa fa-star-shooting' => 'star shooting' ),
					array( 'fa fa-star' => 'star' ),
					array( 'fa fa-starfighter-alt' => 'starfighter alt' ),
					array( 'fa fa-starfighter' => 'starfighter' ),
					array( 'fa fa-stars' => 'stars' ),
					array( 'fa fa-starship-freighter' => 'starship freighter' ),
					array( 'fa fa-starship' => 'starship' ),
					array( 'fa fa-steak' => 'steak' ),
					array( 'fa fa-steering-wheel' => 'steering wheel' ),
					array( 'fa fa-step-backward' => 'step backward' ),
					array( 'fa fa-step-forward' => 'step forward' ),
					array( 'fa fa-stethoscope' => 'stethoscope' ),
					array( 'fa fa-sticky-note' => 'sticky note' ),
					array( 'fa fa-stocking' => 'stocking' ),
					array( 'fa fa-stomach' => 'stomach' ),
					array( 'fa fa-stop-circle' => 'stop circle' ),
					array( 'fa fa-stop' => 'stop' ),
					array( 'fa fa-stopwatch-20' => 'stopwatch 20' ),
					array( 'fa fa-stopwatch' => 'stopwatch' ),
					array( 'fa fa-store-alt-slash' => 'store alt slash' ),
					array( 'fa fa-store-alt' => 'store alt' ),
					array( 'fa fa-store-slash' => 'store slash' ),
					array( 'fa fa-store' => 'store' ),
					array( 'fa fa-stream' => 'stream' ),
					array( 'fa fa-street-view' => 'street view' ),
					array( 'fa fa-stretcher' => 'stretcher' ),
					array( 'fa fa-strikethrough' => 'strikethrough' ),
					array( 'fa fa-stroopwafel' => 'stroopwafel' ),
					array( 'fa fa-subscript' => 'subscript' ),
					array( 'fa fa-subway' => 'subway' ),
					array( 'fa fa-suitcase-rolling' => 'suitcase rolling' ),
					array( 'fa fa-suitcase' => 'suitcase' ),
					array( 'fa fa-sun-cloud' => 'sun cloud' ),
					array( 'fa fa-sun-dust' => 'sun dust' ),
					array( 'fa fa-sun-haze' => 'sun haze' ),
					array( 'fa fa-sun' => 'sun' ),
					array( 'fa fa-sunglasses' => 'sunglasses' ),
					array( 'fa fa-sunrise' => 'sunrise' ),
					array( 'fa fa-sunset' => 'sunset' ),
					array( 'fa fa-superscript' => 'superscript' ),
					array( 'fa fa-surprise' => 'surprise' ),
					array( 'fa fa-swatchbook' => 'swatchbook' ),
					array( 'fa fa-swimmer' => 'swimmer' ),
					array( 'fa fa-swimming-pool' => 'swimming pool' ),
					array( 'fa fa-sword-laser-alt' => 'sword laser alt' ),
					array( 'fa fa-sword-laser' => 'sword laser' ),
					array( 'fa fa-sword' => 'sword' ),
					array( 'fa fa-swords-laser' => 'swords laser' ),
					array( 'fa fa-swords' => 'swords' ),
					array( 'fa fa-synagogue' => 'synagogue' ),
					array( 'fa fa-sync-alt' => 'sync alt' ),
					array( 'fa fa-sync' => 'sync' ),
					array( 'fa fa-syringe' => 'syringe' ),
					array( 'fa fa-table-tennis' => 'table tennis' ),
					array( 'fa fa-table' => 'table' ),
					array( 'fa fa-tablet-alt' => 'tablet alt' ),
					array( 'fa fa-tablet-android-alt' => 'tablet android alt' ),
					array( 'fa fa-tablet-android' => 'tablet android' ),
					array( 'fa fa-tablet-rugged' => 'tablet rugged' ),
					array( 'fa fa-tablet' => 'tablet' ),
					array( 'fa fa-tablets' => 'tablets' ),
					array( 'fa fa-tachometer-alt-average' => 'tachometer alt average' ),
					array( 'fa fa-tachometer-alt-fast' => 'tachometer alt fast' ),
					array( 'fa fa-tachometer-alt-fastest' => 'tachometer alt fastest' ),
					array( 'fa fa-tachometer-alt-slow' => 'tachometer alt slow' ),
					array( 'fa fa-tachometer-alt-slowest' => 'tachometer alt slowest' ),
					array( 'fa fa-tachometer-alt' => 'tachometer alt' ),
					array( 'fa fa-tachometer-average' => 'tachometer average' ),
					array( 'fa fa-tachometer-fast' => 'tachometer fast' ),
					array( 'fa fa-tachometer-fastest' => 'tachometer fastest' ),
					array( 'fa fa-tachometer-slow' => 'tachometer slow' ),
					array( 'fa fa-tachometer-slowest' => 'tachometer slowest' ),
					array( 'fa fa-tachometer' => 'tachometer' ),
					array( 'fa fa-taco' => 'taco' ),
					array( 'fa fa-tag' => 'tag' ),
					array( 'fa fa-tags' => 'tags' ),
					array( 'fa fa-tally' => 'tally' ),
					array( 'fa fa-tanakh' => 'tanakh' ),
					array( 'fa fa-tape' => 'tape' ),
					array( 'fa fa-tasks-alt' => 'tasks alt' ),
					array( 'fa fa-tasks' => 'tasks' ),
					array( 'fa fa-taxi' => 'taxi' ),
					array( 'fa fa-teeth-open' => 'teeth open' ),
					array( 'fa fa-teeth' => 'teeth' ),
					array( 'fa fa-telescope' => 'telescope' ),
					array( 'fa fa-temperature-down' => 'temperature down' ),
					array( 'fa fa-temperature-frigid' => 'temperature frigid' ),
					array( 'fa fa-temperature-high' => 'temperature high' ),
					array( 'fa fa-temperature-hot' => 'temperature hot' ),
					array( 'fa fa-temperature-low' => 'temperature low' ),
					array( 'fa fa-temperature-up' => 'temperature up' ),
					array( 'fa fa-tenge' => 'tenge' ),
					array( 'fa fa-tennis-ball' => 'tennis ball' ),
					array( 'fa fa-terminal' => 'terminal' ),
					array( 'fa fa-text-height' => 'text height' ),
					array( 'fa fa-text-size' => 'text size' ),
					array( 'fa fa-text-width' => 'text width' ),
					array( 'fa fa-text' => 'text' ),
					array( 'fa fa-th-large' => 'th large' ),
					array( 'fa fa-th-list' => 'th list' ),
					array( 'fa fa-th' => 'th' ),
					array( 'fa fa-theater-masks' => 'theater masks' ),
					array( 'fa fa-thermometer-empty' => 'thermometer empty' ),
					array( 'fa fa-thermometer-full' => 'thermometer full' ),
					array( 'fa fa-thermometer-half' => 'thermometer half' ),
					array( 'fa fa-thermometer-quarter' => 'thermometer quarter' ),
					array( 'fa fa-thermometer-three-quarters' => 'thermometer three quarters' ),
					array( 'fa fa-thermometer' => 'thermometer' ),
					array( 'fa fa-theta' => 'theta' ),
					array( 'fa fa-thumbs-down' => 'thumbs down' ),
					array( 'fa fa-thumbs-up' => 'thumbs up' ),
					array( 'fa fa-thumbtack' => 'thumbtack' ),
					array( 'fa fa-thunderstorm-moon' => 'thunderstorm moon' ),
					array( 'fa fa-thunderstorm-sun' => 'thunderstorm sun' ),
					array( 'fa fa-thunderstorm' => 'thunderstorm' ),
					array( 'fa fa-ticket-alt' => 'ticket alt' ),
					array( 'fa fa-ticket' => 'ticket' ),
					array( 'fa fa-tilde' => 'tilde' ),
					array( 'fa fa-times-circle' => 'times circle' ),
					array( 'fa fa-times-hexagon' => 'times hexagon' ),
					array( 'fa fa-times-octagon' => 'times octagon' ),
					array( 'fa fa-times-square' => 'times square' ),
					array( 'fa fa-times' => 'times' ),
					array( 'fa fa-tint-slash' => 'tint slash' ),
					array( 'fa fa-tint' => 'tint' ),
					array( 'fa fa-tire-flat' => 'tire flat' ),
					array( 'fa fa-tire-pressure-warning' => 'tire pressure warning' ),
					array( 'fa fa-tire-rugged' => 'tire rugged' ),
					array( 'fa fa-tire' => 'tire' ),
					array( 'fa fa-tired' => 'tired' ),
					array( 'fa fa-toggle-off' => 'toggle off' ),
					array( 'fa fa-toggle-on' => 'toggle on' ),
					array( 'fa fa-toilet-paper-alt' => 'toilet paper alt' ),
					array( 'fa fa-toilet-paper-slash' => 'toilet paper slash' ),
					array( 'fa fa-toilet-paper' => 'toilet paper' ),
					array( 'fa fa-toilet' => 'toilet' ),
					array( 'fa fa-tombstone-alt' => 'tombstone alt' ),
					array( 'fa fa-tombstone' => 'tombstone' ),
					array( 'fa fa-toolbox' => 'toolbox' ),
					array( 'fa fa-tools' => 'tools' ),
					array( 'fa fa-tooth' => 'tooth' ),
					array( 'fa fa-toothbrush' => 'toothbrush' ),
					array( 'fa fa-torah' => 'torah' ),
					array( 'fa fa-torii-gate' => 'torii gate' ),
					array( 'fa fa-tornado' => 'tornado' ),
					array( 'fa fa-tractor' => 'tractor' ),
					array( 'fa fa-trademark' => 'trademark' ),
					array( 'fa fa-traffic-cone' => 'traffic cone' ),
					array( 'fa fa-traffic-light-go' => 'traffic light go' ),
					array( 'fa fa-traffic-light-slow' => 'traffic light slow' ),
					array( 'fa fa-traffic-light-stop' => 'traffic light stop' ),
					array( 'fa fa-traffic-light' => 'traffic light' ),
					array( 'fa fa-trailer' => 'trailer' ),
					array( 'fa fa-train' => 'train' ),
					array( 'fa fa-tram' => 'tram' ),
					array( 'fa fa-transgender-alt' => 'transgender alt' ),
					array( 'fa fa-transgender' => 'transgender' ),
					array( 'fa fa-transporter-1' => 'transporter 1' ),
					array( 'fa fa-transporter-2' => 'transporter 2' ),
					array( 'fa fa-transporter-3' => 'transporter 3' ),
					array( 'fa fa-transporter-empty' => 'transporter empty' ),
					array( 'fa fa-transporter' => 'transporter' ),
					array( 'fa fa-trash-alt' => 'trash alt' ),
					array( 'fa fa-trash-restore-alt' => 'trash restore alt' ),
					array( 'fa fa-trash-restore' => 'trash restore' ),
					array( 'fa fa-trash-undo-alt' => 'trash undo alt' ),
					array( 'fa fa-trash-undo' => 'trash undo' ),
					array( 'fa fa-trash' => 'trash' ),
					array( 'fa fa-treasure-chest' => 'treasure chest' ),
					array( 'fa fa-tree-alt' => 'tree alt' ),
					array( 'fa fa-tree-christmas' => 'tree christmas' ),
					array( 'fa fa-tree-decorated' => 'tree decorated' ),
					array( 'fa fa-tree-large' => 'tree large' ),
					array( 'fa fa-tree-palm' => 'tree palm' ),
					array( 'fa fa-tree' => 'tree' ),
					array( 'fa fa-trees' => 'trees' ),
					array( 'fa fa-triangle-music' => 'triangle music' ),
					array( 'fa fa-triangle' => 'triangle' ),
					array( 'fa fa-trophy-alt' => 'trophy alt' ),
					array( 'fa fa-trophy' => 'trophy' ),
					array( 'fa fa-truck-container' => 'truck container' ),
					array( 'fa fa-truck-couch' => 'truck couch' ),
					array( 'fa fa-truck-loading' => 'truck loading' ),
					array( 'fa fa-truck-monster' => 'truck monster' ),
					array( 'fa fa-truck-moving' => 'truck moving' ),
					array( 'fa fa-truck-pickup' => 'truck pickup' ),
					array( 'fa fa-truck-plow' => 'truck plow' ),
					array( 'fa fa-truck-ramp' => 'truck ramp' ),
					array( 'fa fa-truck' => 'truck' ),
					array( 'fa fa-trumpet' => 'trumpet' ),
					array( 'fa fa-tshirt' => 'tshirt' ),
					array( 'fa fa-tty' => 'tty' ),
					array( 'fa fa-turkey' => 'turkey' ),
					array( 'fa fa-turntable' => 'turntable' ),
					array( 'fa fa-turtle' => 'turtle' ),
					array( 'fa fa-tv-alt' => 'tv alt' ),
					array( 'fa fa-tv-music' => 'tv music' ),
					array( 'fa fa-tv-retro' => 'tv retro' ),
					array( 'fa fa-tv' => 'tv' ),
					array( 'fa fa-typewriter' => 'typewriter' ),
					array( 'fa fa-ufo-beam' => 'ufo beam' ),
					array( 'fa fa-ufo' => 'ufo' ),
					array( 'fa fa-umbrella-beach' => 'umbrella beach' ),
					array( 'fa fa-umbrella' => 'umbrella' ),
					array( 'fa fa-underline' => 'underline' ),
					array( 'fa fa-undo-alt' => 'undo alt' ),
					array( 'fa fa-undo' => 'undo' ),
					array( 'fa fa-unicorn' => 'unicorn' ),
					array( 'fa fa-union' => 'union' ),
					array( 'fa fa-universal-access' => 'universal access' ),
					array( 'fa fa-university' => 'university' ),
					array( 'fa fa-unlink' => 'unlink' ),
					array( 'fa fa-unlock-alt' => 'unlock alt' ),
					array( 'fa fa-unlock' => 'unlock' ),
					array( 'fa fa-upload' => 'upload' ),
					array( 'fa fa-usb-drive' => 'usb drive' ),
					array( 'fa fa-usd-circle' => 'usd circle' ),
					array( 'fa fa-usd-square' => 'usd square' ),
					array( 'fa fa-user-alien' => 'user alien' ),
					array( 'fa fa-user-alt-slash' => 'user alt slash' ),
					array( 'fa fa-user-alt' => 'user alt' ),
					array( 'fa fa-user-astronaut' => 'user astronaut' ),
					array( 'fa fa-user-chart' => 'user chart' ),
					array( 'fa fa-user-check' => 'user check' ),
					array( 'fa fa-user-circle' => 'user circle' ),
					array( 'fa fa-user-clock' => 'user clock' ),
					array( 'fa fa-user-cog' => 'user cog' ),
					array( 'fa fa-user-cowboy' => 'user cowboy' ),
					array( 'fa fa-user-crown' => 'user crown' ),
					array( 'fa fa-user-edit' => 'user edit' ),
					array( 'fa fa-user-friends' => 'user friends' ),
					array( 'fa fa-user-graduate' => 'user graduate' ),
					array( 'fa fa-user-hard-hat' => 'user hard hat' ),
					array( 'fa fa-user-headset' => 'user headset' ),
					array( 'fa fa-user-injured' => 'user injured' ),
					array( 'fa fa-user-lock' => 'user lock' ),
					array( 'fa fa-user-md-chat' => 'user md chat' ),
					array( 'fa fa-user-md' => 'user md' ),
					array( 'fa fa-user-minus' => 'user minus' ),
					array( 'fa fa-user-music' => 'user music' ),
					array( 'fa fa-user-ninja' => 'user ninja' ),
					array( 'fa fa-user-nurse' => 'user nurse' ),
					array( 'fa fa-user-plus' => 'user plus' ),
					array( 'fa fa-user-robot' => 'user robot' ),
					array( 'fa fa-user-secret' => 'user secret' ),
					array( 'fa fa-user-shield' => 'user shield' ),
					array( 'fa fa-user-slash' => 'user slash' ),
					array( 'fa fa-user-tag' => 'user tag' ),
					array( 'fa fa-user-tie' => 'user tie' ),
					array( 'fa fa-user-times' => 'user times' ),
					array( 'fa fa-user-unlock' => 'user unlock' ),
					array( 'fa fa-user-visor' => 'user visor' ),
					array( 'fa fa-user' => 'user' ),
					array( 'fa fa-users-class' => 'users class' ),
					array( 'fa fa-users-cog' => 'users cog' ),
					array( 'fa fa-users-crown' => 'users crown' ),
					array( 'fa fa-users-medical' => 'users medical' ),
					array( 'fa fa-users-slash' => 'users slash' ),
					array( 'fa fa-users' => 'users' ),
					array( 'fa fa-utensil-fork' => 'utensil fork' ),
					array( 'fa fa-utensil-knife' => 'utensil knife' ),
					array( 'fa fa-utensil-spoon' => 'utensil spoon' ),
					array( 'fa fa-utensils-alt' => 'utensils alt' ),
					array( 'fa fa-utensils' => 'utensils' ),
					array( 'fa fa-vacuum-robot' => 'vacuum robot' ),
					array( 'fa fa-vacuum' => 'vacuum' ),
					array( 'fa fa-value-absolute' => 'value absolute' ),
					array( 'fa fa-vector-square' => 'vector square' ),
					array( 'fa fa-venus-double' => 'venus double' ),
					array( 'fa fa-venus-mars' => 'venus mars' ),
					array( 'fa fa-venus' => 'venus' ),
					array( 'fa fa-vhs' => 'vhs' ),
					array( 'fa fa-vial' => 'vial' ),
					array( 'fa fa-vials' => 'vials' ),
					array( 'fa fa-video-plus' => 'video plus' ),
					array( 'fa fa-video-slash' => 'video slash' ),
					array( 'fa fa-video' => 'video' ),
					array( 'fa fa-vihara' => 'vihara' ),
					array( 'fa fa-violin' => 'violin' ),
					array( 'fa fa-virus-slash' => 'virus slash' ),
					array( 'fa fa-virus' => 'virus' ),
					array( 'fa fa-viruses' => 'viruses' ),
					array( 'fa fa-voicemail' => 'voicemail' ),
					array( 'fa fa-volcano' => 'volcano' ),
					array( 'fa fa-volleyball-ball' => 'volleyball ball' ),
					array( 'fa fa-volume-down' => 'volume down' ),
					array( 'fa fa-volume-mute' => 'volume mute' ),
					array( 'fa fa-volume-off' => 'volume off' ),
					array( 'fa fa-volume-slash' => 'volume slash' ),
					array( 'fa fa-volume-up' => 'volume up' ),
					array( 'fa fa-volume' => 'volume' ),
					array( 'fa fa-vote-nay' => 'vote nay' ),
					array( 'fa fa-vote-yea' => 'vote yea' ),
					array( 'fa fa-vr-cardboard' => 'vr cardboard' ),
					array( 'fa fa-wagon-covered' => 'wagon covered' ),
					array( 'fa fa-walker' => 'walker' ),
					array( 'fa fa-walkie-talkie' => 'walkie talkie' ),
					array( 'fa fa-walking' => 'walking' ),
					array( 'fa fa-wallet' => 'wallet' ),
					array( 'fa fa-wand-magic' => 'wand magic' ),
					array( 'fa fa-wand' => 'wand' ),
					array( 'fa fa-warehouse-alt' => 'warehouse alt' ),
					array( 'fa fa-warehouse' => 'warehouse' ),
					array( 'fa fa-washer' => 'washer' ),
					array( 'fa fa-watch-calculator' => 'watch calculator' ),
					array( 'fa fa-watch-fitness' => 'watch fitness' ),
					array( 'fa fa-watch' => 'watch' ),
					array( 'fa fa-water-lower' => 'water lower' ),
					array( 'fa fa-water-rise' => 'water rise' ),
					array( 'fa fa-water' => 'water' ),
					array( 'fa fa-wave-sine' => 'wave sine' ),
					array( 'fa fa-wave-square' => 'wave square' ),
					array( 'fa fa-wave-triangle' => 'wave triangle' ),
					array( 'fa fa-waveform-path' => 'waveform path' ),
					array( 'fa fa-waveform' => 'waveform' ),
					array( 'fa fa-webcam-slash' => 'webcam slash' ),
					array( 'fa fa-webcam' => 'webcam' ),
					array( 'fa fa-weight-hanging' => 'weight hanging' ),
					array( 'fa fa-weight' => 'weight' ),
					array( 'fa fa-whale' => 'whale' ),
					array( 'fa fa-wheat' => 'wheat' ),
					array( 'fa fa-wheelchair' => 'wheelchair' ),
					array( 'fa fa-whistle' => 'whistle' ),
					array( 'fa fa-wifi-1' => 'wifi 1' ),
					array( 'fa fa-wifi-2' => 'wifi 2' ),
					array( 'fa fa-wifi-slash' => 'wifi slash' ),
					array( 'fa fa-wifi' => 'wifi' ),
					array( 'fa fa-wind-turbine' => 'wind turbine' ),
					array( 'fa fa-wind-warning' => 'wind warning' ),
					array( 'fa fa-wind' => 'wind' ),
					array( 'fa fa-window-alt' => 'window alt' ),
					array( 'fa fa-window-close' => 'window close' ),
					array( 'fa fa-window-frame-open' => 'window frame open' ),
					array( 'fa fa-window-frame' => 'window frame' ),
					array( 'fa fa-window-maximize' => 'window maximize' ),
					array( 'fa fa-window-minimize' => 'window minimize' ),
					array( 'fa fa-window-restore' => 'window restore' ),
					array( 'fa fa-window' => 'window' ),
					array( 'fa fa-windsock' => 'windsock' ),
					array( 'fa fa-wine-bottle' => 'wine bottle' ),
					array( 'fa fa-wine-glass-alt' => 'wine glass alt' ),
					array( 'fa fa-wine-glass' => 'wine glass' ),
					array( 'fa fa-won-sign' => 'won sign' ),
					array( 'fa fa-wreath' => 'wreath' ),
					array( 'fa fa-wrench' => 'wrench' ),
					array( 'fa fa-x-ray' => 'x ray' ),
					array( 'fa fa-yen-sign' => 'yen sign' ),
					array( 'fa fa-yin-yang' => 'yin yang' ),
				),
				esc_html__( 'Light', 'brook' )   => array(
					array( 'fal fa-abacus' => 'abacus' ),
					array( 'fal fa-acorn' => 'acorn' ),
					array( 'fal fa-ad' => 'ad' ),
					array( 'fal fa-address-book' => 'address book' ),
					array( 'fal fa-address-card' => 'address card' ),
					array( 'fal fa-adjust' => 'adjust' ),
					array( 'fal fa-air-conditioner' => 'air conditioner' ),
					array( 'fal fa-air-freshener' => 'air freshener' ),
					array( 'fal fa-alarm-clock' => 'alarm clock' ),
					array( 'fal fa-alarm-exclamation' => 'alarm exclamation' ),
					array( 'fal fa-alarm-plus' => 'alarm plus' ),
					array( 'fal fa-alarm-snooze' => 'alarm snooze' ),
					array( 'fal fa-album-collection' => 'album collection' ),
					array( 'fal fa-album' => 'album' ),
					array( 'fal fa-alicorn' => 'alicorn' ),
					array( 'fal fa-alien-monster' => 'alien monster' ),
					array( 'fal fa-alien' => 'alien' ),
					array( 'fal fa-align-center' => 'align center' ),
					array( 'fal fa-align-justify' => 'align justify' ),
					array( 'fal fa-align-left' => 'align left' ),
					array( 'fal fa-align-right' => 'align right' ),
					array( 'fal fa-align-slash' => 'align slash' ),
					array( 'fal fa-allergies' => 'allergies' ),
					array( 'fal fa-ambulance' => 'ambulance' ),
					array( 'fal fa-american-sign-language-interpreting' => 'american sign language interpreting' ),
					array( 'fal fa-amp-guitar' => 'amp guitar' ),
					array( 'fal fa-analytics' => 'analytics' ),
					array( 'fal fa-anchor' => 'anchor' ),
					array( 'fal fa-angel' => 'angel' ),
					array( 'fal fa-angle-double-down' => 'angle double down' ),
					array( 'fal fa-angle-double-left' => 'angle double left' ),
					array( 'fal fa-angle-double-right' => 'angle double right' ),
					array( 'fal fa-angle-double-up' => 'angle double up' ),
					array( 'fal fa-angle-down' => 'angle down' ),
					array( 'fal fa-angle-left' => 'angle left' ),
					array( 'fal fa-angle-right' => 'angle right' ),
					array( 'fal fa-angle-up' => 'angle up' ),
					array( 'fal fa-angry' => 'angry' ),
					array( 'fal fa-ankh' => 'ankh' ),
					array( 'fal fa-apple-alt' => 'apple alt' ),
					array( 'fal fa-apple-crate' => 'apple crate' ),
					array( 'fal fa-archive' => 'archive' ),
					array( 'fal fa-archway' => 'archway' ),
					array( 'fal fa-arrow-alt-circle-down' => 'arrow alt circle down' ),
					array( 'fal fa-arrow-alt-circle-left' => 'arrow alt circle left' ),
					array( 'fal fa-arrow-alt-circle-right' => 'arrow alt circle right' ),
					array( 'fal fa-arrow-alt-circle-up' => 'arrow alt circle up' ),
					array( 'fal fa-arrow-alt-down' => 'arrow alt down' ),
					array( 'fal fa-arrow-alt-from-bottom' => 'arrow alt from bottom' ),
					array( 'fal fa-arrow-alt-from-left' => 'arrow alt from left' ),
					array( 'fal fa-arrow-alt-from-right' => 'arrow alt from right' ),
					array( 'fal fa-arrow-alt-from-top' => 'arrow alt from top' ),
					array( 'fal fa-arrow-alt-left' => 'arrow alt left' ),
					array( 'fal fa-arrow-alt-right' => 'arrow alt right' ),
					array( 'fal fa-arrow-alt-square-down' => 'arrow alt square down' ),
					array( 'fal fa-arrow-alt-square-left' => 'arrow alt square left' ),
					array( 'fal fa-arrow-alt-square-right' => 'arrow alt square right' ),
					array( 'fal fa-arrow-alt-square-up' => 'arrow alt square up' ),
					array( 'fal fa-arrow-alt-to-bottom' => 'arrow alt to bottom' ),
					array( 'fal fa-arrow-alt-to-left' => 'arrow alt to left' ),
					array( 'fal fa-arrow-alt-to-right' => 'arrow alt to right' ),
					array( 'fal fa-arrow-alt-to-top' => 'arrow alt to top' ),
					array( 'fal fa-arrow-alt-up' => 'arrow alt up' ),
					array( 'fal fa-arrow-circle-down' => 'arrow circle down' ),
					array( 'fal fa-arrow-circle-left' => 'arrow circle left' ),
					array( 'fal fa-arrow-circle-right' => 'arrow circle right' ),
					array( 'fal fa-arrow-circle-up' => 'arrow circle up' ),
					array( 'fal fa-arrow-down' => 'arrow down' ),
					array( 'fal fa-arrow-from-bottom' => 'arrow from bottom' ),
					array( 'fal fa-arrow-from-left' => 'arrow from left' ),
					array( 'fal fa-arrow-from-right' => 'arrow from right' ),
					array( 'fal fa-arrow-from-top' => 'arrow from top' ),
					array( 'fal fa-arrow-left' => 'arrow left' ),
					array( 'fal fa-arrow-right' => 'arrow right' ),
					array( 'fal fa-arrow-square-down' => 'arrow square down' ),
					array( 'fal fa-arrow-square-left' => 'arrow square left' ),
					array( 'fal fa-arrow-square-right' => 'arrow square right' ),
					array( 'fal fa-arrow-square-up' => 'arrow square up' ),
					array( 'fal fa-arrow-to-bottom' => 'arrow to bottom' ),
					array( 'fal fa-arrow-to-left' => 'arrow to left' ),
					array( 'fal fa-arrow-to-right' => 'arrow to right' ),
					array( 'fal fa-arrow-to-top' => 'arrow to top' ),
					array( 'fal fa-arrow-up' => 'arrow up' ),
					array( 'fal fa-arrows-alt-h' => 'arrows alt h' ),
					array( 'fal fa-arrows-alt-v' => 'arrows alt v' ),
					array( 'fal fa-arrows-alt' => 'arrows alt' ),
					array( 'fal fa-arrows-h' => 'arrows h' ),
					array( 'fal fa-arrows-v' => 'arrows v' ),
					array( 'fal fa-arrows' => 'arrows' ),
					array( 'fal fa-assistive-listening-systems' => 'assistive listening systems' ),
					array( 'fal fa-asterisk' => 'asterisk' ),
					array( 'fal fa-at' => 'at' ),
					array( 'fal fa-atlas' => 'atlas' ),
					array( 'fal fa-atom-alt' => 'atom alt' ),
					array( 'fal fa-atom' => 'atom' ),
					array( 'fal fa-audio-description' => 'audio description' ),
					array( 'fal fa-award' => 'award' ),
					array( 'fal fa-axe-battle' => 'axe battle' ),
					array( 'fal fa-axe' => 'axe' ),
					array( 'fal fa-baby-carriage' => 'baby carriage' ),
					array( 'fal fa-baby' => 'baby' ),
					array( 'fal fa-backpack' => 'backpack' ),
					array( 'fal fa-backspace' => 'backspace' ),
					array( 'fal fa-backward' => 'backward' ),
					array( 'fal fa-bacon' => 'bacon' ),
					array( 'fal fa-bacteria' => 'bacteria' ),
					array( 'fal fa-bacterium' => 'bacterium' ),
					array( 'fal fa-badge-check' => 'badge check' ),
					array( 'fal fa-badge-dollar' => 'badge dollar' ),
					array( 'fal fa-badge-percent' => 'badge percent' ),
					array( 'fal fa-badge-sheriff' => 'badge sheriff' ),
					array( 'fal fa-badge' => 'badge' ),
					array( 'fal fa-badger-honey' => 'badger honey' ),
					array( 'fal fa-bags-shopping' => 'bags shopping' ),
					array( 'fal fa-bahai' => 'bahai' ),
					array( 'fal fa-balance-scale-left' => 'balance scale left' ),
					array( 'fal fa-balance-scale-right' => 'balance scale right' ),
					array( 'fal fa-balance-scale' => 'balance scale' ),
					array( 'fal fa-ball-pile' => 'ball pile' ),
					array( 'fal fa-ballot-check' => 'ballot check' ),
					array( 'fal fa-ballot' => 'ballot' ),
					array( 'fal fa-ban' => 'ban' ),
					array( 'fal fa-band-aid' => 'band aid' ),
					array( 'fal fa-banjo' => 'banjo' ),
					array( 'fal fa-barcode-alt' => 'barcode alt' ),
					array( 'fal fa-barcode-read' => 'barcode read' ),
					array( 'fal fa-barcode-scan' => 'barcode scan' ),
					array( 'fal fa-barcode' => 'barcode' ),
					array( 'fal fa-bars' => 'bars' ),
					array( 'fal fa-baseball-ball' => 'baseball ball' ),
					array( 'fal fa-baseball' => 'baseball' ),
					array( 'fal fa-basketball-ball' => 'basketball ball' ),
					array( 'fal fa-basketball-hoop' => 'basketball hoop' ),
					array( 'fal fa-bat' => 'bat' ),
					array( 'fal fa-bath' => 'bath' ),
					array( 'fal fa-battery-bolt' => 'battery bolt' ),
					array( 'fal fa-battery-empty' => 'battery empty' ),
					array( 'fal fa-battery-full' => 'battery full' ),
					array( 'fal fa-battery-half' => 'battery half' ),
					array( 'fal fa-battery-quarter' => 'battery quarter' ),
					array( 'fal fa-battery-slash' => 'battery slash' ),
					array( 'fal fa-battery-three-quarters' => 'battery three quarters' ),
					array( 'fal fa-bed-alt' => 'bed alt' ),
					array( 'fal fa-bed-bunk' => 'bed bunk' ),
					array( 'fal fa-bed-empty' => 'bed empty' ),
					array( 'fal fa-bed' => 'bed' ),
					array( 'fal fa-beer' => 'beer' ),
					array( 'fal fa-bell-exclamation' => 'bell exclamation' ),
					array( 'fal fa-bell-on' => 'bell on' ),
					array( 'fal fa-bell-plus' => 'bell plus' ),
					array( 'fal fa-bell-school-slash' => 'bell school slash' ),
					array( 'fal fa-bell-school' => 'bell school' ),
					array( 'fal fa-bell-slash' => 'bell slash' ),
					array( 'fal fa-bell' => 'bell' ),
					array( 'fal fa-bells' => 'bells' ),
					array( 'fal fa-betamax' => 'betamax' ),
					array( 'fal fa-bezier-curve' => 'bezier curve' ),
					array( 'fal fa-bible' => 'bible' ),
					array( 'fal fa-bicycle' => 'bicycle' ),
					array( 'fal fa-biking-mountain' => 'biking mountain' ),
					array( 'fal fa-biking' => 'biking' ),
					array( 'fal fa-binoculars' => 'binoculars' ),
					array( 'fal fa-biohazard' => 'biohazard' ),
					array( 'fal fa-birthday-cake' => 'birthday cake' ),
					array( 'fal fa-blanket' => 'blanket' ),
					array( 'fal fa-blender-phone' => 'blender phone' ),
					array( 'fal fa-blender' => 'blender' ),
					array( 'fal fa-blind' => 'blind' ),
					array( 'fal fa-blinds-open' => 'blinds open' ),
					array( 'fal fa-blinds-raised' => 'blinds raised' ),
					array( 'fal fa-blinds' => 'blinds' ),
					array( 'fal fa-blog' => 'blog' ),
					array( 'fal fa-bold' => 'bold' ),
					array( 'fal fa-bolt' => 'bolt' ),
					array( 'fal fa-bomb' => 'bomb' ),
					array( 'fal fa-bone-break' => 'bone break' ),
					array( 'fal fa-bone' => 'bone' ),
					array( 'fal fa-bong' => 'bong' ),
					array( 'fal fa-book-alt' => 'book alt' ),
					array( 'fal fa-book-dead' => 'book dead' ),
					array( 'fal fa-book-heart' => 'book heart' ),
					array( 'fal fa-book-medical' => 'book medical' ),
					array( 'fal fa-book-open' => 'book open' ),
					array( 'fal fa-book-reader' => 'book reader' ),
					array( 'fal fa-book-spells' => 'book spells' ),
					array( 'fal fa-book-user' => 'book user' ),
					array( 'fal fa-book' => 'book' ),
					array( 'fal fa-bookmark' => 'bookmark' ),
					array( 'fal fa-books-medical' => 'books medical' ),
					array( 'fal fa-books' => 'books' ),
					array( 'fal fa-boombox' => 'boombox' ),
					array( 'fal fa-boot' => 'boot' ),
					array( 'fal fa-booth-curtain' => 'booth curtain' ),
					array( 'fal fa-border-all' => 'border all' ),
					array( 'fal fa-border-bottom' => 'border bottom' ),
					array( 'fal fa-border-center-h' => 'border center h' ),
					array( 'fal fa-border-center-v' => 'border center v' ),
					array( 'fal fa-border-inner' => 'border inner' ),
					array( 'fal fa-border-left' => 'border left' ),
					array( 'fal fa-border-none' => 'border none' ),
					array( 'fal fa-border-outer' => 'border outer' ),
					array( 'fal fa-border-right' => 'border right' ),
					array( 'fal fa-border-style-alt' => 'border style alt' ),
					array( 'fal fa-border-style' => 'border style' ),
					array( 'fal fa-border-top' => 'border top' ),
					array( 'fal fa-bow-arrow' => 'bow arrow' ),
					array( 'fal fa-bowling-ball' => 'bowling ball' ),
					array( 'fal fa-bowling-pins' => 'bowling pins' ),
					array( 'fal fa-box-alt' => 'box alt' ),
					array( 'fal fa-box-ballot' => 'box ballot' ),
					array( 'fal fa-box-check' => 'box check' ),
					array( 'fal fa-box-fragile' => 'box fragile' ),
					array( 'fal fa-box-full' => 'box full' ),
					array( 'fal fa-box-heart' => 'box heart' ),
					array( 'fal fa-box-open' => 'box open' ),
					array( 'fal fa-box-tissue' => 'box tissue' ),
					array( 'fal fa-box-up' => 'box up' ),
					array( 'fal fa-box-usd' => 'box usd' ),
					array( 'fal fa-box' => 'box' ),
					array( 'fal fa-boxes-alt' => 'boxes alt' ),
					array( 'fal fa-boxes' => 'boxes' ),
					array( 'fal fa-boxing-glove' => 'boxing glove' ),
					array( 'fal fa-brackets-curly' => 'brackets curly' ),
					array( 'fal fa-brackets' => 'brackets' ),
					array( 'fal fa-braille' => 'braille' ),
					array( 'fal fa-brain' => 'brain' ),
					array( 'fal fa-bread-loaf' => 'bread loaf' ),
					array( 'fal fa-bread-slice' => 'bread slice' ),
					array( 'fal fa-briefcase-medical' => 'briefcase medical' ),
					array( 'fal fa-briefcase' => 'briefcase' ),
					array( 'fal fa-bring-forward' => 'bring forward' ),
					array( 'fal fa-bring-front' => 'bring front' ),
					array( 'fal fa-broadcast-tower' => 'broadcast tower' ),
					array( 'fal fa-broom' => 'broom' ),
					array( 'fal fa-browser' => 'browser' ),
					array( 'fal fa-brush' => 'brush' ),
					array( 'fal fa-bug' => 'bug' ),
					array( 'fal fa-building' => 'building' ),
					array( 'fal fa-bullhorn' => 'bullhorn' ),
					array( 'fal fa-bullseye-arrow' => 'bullseye arrow' ),
					array( 'fal fa-bullseye-pointer' => 'bullseye pointer' ),
					array( 'fal fa-bullseye' => 'bullseye' ),
					array( 'fal fa-burger-soda' => 'burger soda' ),
					array( 'fal fa-burn' => 'burn' ),
					array( 'fal fa-burrito' => 'burrito' ),
					array( 'fal fa-bus-alt' => 'bus alt' ),
					array( 'fal fa-bus-school' => 'bus school' ),
					array( 'fal fa-bus' => 'bus' ),
					array( 'fal fa-business-time' => 'business time' ),
					array( 'fal fa-cabinet-filing' => 'cabinet filing' ),
					array( 'fal fa-cactus' => 'cactus' ),
					array( 'fal fa-calculator-alt' => 'calculator alt' ),
					array( 'fal fa-calculator' => 'calculator' ),
					array( 'fal fa-calendar-alt' => 'calendar alt' ),
					array( 'fal fa-calendar-check' => 'calendar check' ),
					array( 'fal fa-calendar-day' => 'calendar day' ),
					array( 'fal fa-calendar-edit' => 'calendar edit' ),
					array( 'fal fa-calendar-exclamation' => 'calendar exclamation' ),
					array( 'fal fa-calendar-minus' => 'calendar minus' ),
					array( 'fal fa-calendar-plus' => 'calendar plus' ),
					array( 'fal fa-calendar-star' => 'calendar star' ),
					array( 'fal fa-calendar-times' => 'calendar times' ),
					array( 'fal fa-calendar-week' => 'calendar week' ),
					array( 'fal fa-calendar' => 'calendar' ),
					array( 'fal fa-camcorder' => 'camcorder' ),
					array( 'fal fa-camera-alt' => 'camera alt' ),
					array( 'fal fa-camera-home' => 'camera home' ),
					array( 'fal fa-camera-movie' => 'camera movie' ),
					array( 'fal fa-camera-polaroid' => 'camera polaroid' ),
					array( 'fal fa-camera-retro' => 'camera retro' ),
					array( 'fal fa-camera' => 'camera' ),
					array( 'fal fa-campfire' => 'campfire' ),
					array( 'fal fa-campground' => 'campground' ),
					array( 'fal fa-candle-holder' => 'candle holder' ),
					array( 'fal fa-candy-cane' => 'candy cane' ),
					array( 'fal fa-candy-corn' => 'candy corn' ),
					array( 'fal fa-cannabis' => 'cannabis' ),
					array( 'fal fa-capsules' => 'capsules' ),
					array( 'fal fa-car-alt' => 'car alt' ),
					array( 'fal fa-car-battery' => 'car battery' ),
					array( 'fal fa-car-building' => 'car building' ),
					array( 'fal fa-car-bump' => 'car bump' ),
					array( 'fal fa-car-bus' => 'car bus' ),
					array( 'fal fa-car-crash' => 'car crash' ),
					array( 'fal fa-car-garage' => 'car garage' ),
					array( 'fal fa-car-mechanic' => 'car mechanic' ),
					array( 'fal fa-car-side' => 'car side' ),
					array( 'fal fa-car-tilt' => 'car tilt' ),
					array( 'fal fa-car-wash' => 'car wash' ),
					array( 'fal fa-car' => 'car' ),
					array( 'fal fa-caravan-alt' => 'caravan alt' ),
					array( 'fal fa-caravan' => 'caravan' ),
					array( 'fal fa-caret-circle-down' => 'caret circle down' ),
					array( 'fal fa-caret-circle-left' => 'caret circle left' ),
					array( 'fal fa-caret-circle-right' => 'caret circle right' ),
					array( 'fal fa-caret-circle-up' => 'caret circle up' ),
					array( 'fal fa-caret-down' => 'caret down' ),
					array( 'fal fa-caret-left' => 'caret left' ),
					array( 'fal fa-caret-right' => 'caret right' ),
					array( 'fal fa-caret-square-down' => 'caret square down' ),
					array( 'fal fa-caret-square-left' => 'caret square left' ),
					array( 'fal fa-caret-square-right' => 'caret square right' ),
					array( 'fal fa-caret-square-up' => 'caret square up' ),
					array( 'fal fa-caret-up' => 'caret up' ),
					array( 'fal fa-carrot' => 'carrot' ),
					array( 'fal fa-cars' => 'cars' ),
					array( 'fal fa-cart-arrow-down' => 'cart arrow down' ),
					array( 'fal fa-cart-plus' => 'cart plus' ),
					array( 'fal fa-cash-register' => 'cash register' ),
					array( 'fal fa-cassette-tape' => 'cassette tape' ),
					array( 'fal fa-cat-space' => 'cat space' ),
					array( 'fal fa-cat' => 'cat' ),
					array( 'fal fa-cauldron' => 'cauldron' ),
					array( 'fal fa-cctv' => 'cctv' ),
					array( 'fal fa-certificate' => 'certificate' ),
					array( 'fal fa-chair-office' => 'chair office' ),
					array( 'fal fa-chair' => 'chair' ),
					array( 'fal fa-chalkboard-teacher' => 'chalkboard teacher' ),
					array( 'fal fa-chalkboard' => 'chalkboard' ),
					array( 'fal fa-charging-station' => 'charging station' ),
					array( 'fal fa-chart-area' => 'chart area' ),
					array( 'fal fa-chart-bar' => 'chart bar' ),
					array( 'fal fa-chart-line-down' => 'chart line down' ),
					array( 'fal fa-chart-line' => 'chart line' ),
					array( 'fal fa-chart-network' => 'chart network' ),
					array( 'fal fa-chart-pie-alt' => 'chart pie alt' ),
					array( 'fal fa-chart-pie' => 'chart pie' ),
					array( 'fal fa-chart-scatter' => 'chart scatter' ),
					array( 'fal fa-check-circle' => 'check circle' ),
					array( 'fal fa-check-double' => 'check double' ),
					array( 'fal fa-check-square' => 'check square' ),
					array( 'fal fa-check' => 'check' ),
					array( 'fal fa-cheese-swiss' => 'cheese swiss' ),
					array( 'fal fa-cheese' => 'cheese' ),
					array( 'fal fa-cheeseburger' => 'cheeseburger' ),
					array( 'fal fa-chess-bishop-alt' => 'chess bishop alt' ),
					array( 'fal fa-chess-bishop' => 'chess bishop' ),
					array( 'fal fa-chess-board' => 'chess board' ),
					array( 'fal fa-chess-clock-alt' => 'chess clock alt' ),
					array( 'fal fa-chess-clock' => 'chess clock' ),
					array( 'fal fa-chess-king-alt' => 'chess king alt' ),
					array( 'fal fa-chess-king' => 'chess king' ),
					array( 'fal fa-chess-knight-alt' => 'chess knight alt' ),
					array( 'fal fa-chess-knight' => 'chess knight' ),
					array( 'fal fa-chess-pawn-alt' => 'chess pawn alt' ),
					array( 'fal fa-chess-pawn' => 'chess pawn' ),
					array( 'fal fa-chess-queen-alt' => 'chess queen alt' ),
					array( 'fal fa-chess-queen' => 'chess queen' ),
					array( 'fal fa-chess-rook-alt' => 'chess rook alt' ),
					array( 'fal fa-chess-rook' => 'chess rook' ),
					array( 'fal fa-chess' => 'chess' ),
					array( 'fal fa-chevron-circle-down' => 'chevron circle down' ),
					array( 'fal fa-chevron-circle-left' => 'chevron circle left' ),
					array( 'fal fa-chevron-circle-right' => 'chevron circle right' ),
					array( 'fal fa-chevron-circle-up' => 'chevron circle up' ),
					array( 'fal fa-chevron-double-down' => 'chevron double down' ),
					array( 'fal fa-chevron-double-left' => 'chevron double left' ),
					array( 'fal fa-chevron-double-right' => 'chevron double right' ),
					array( 'fal fa-chevron-double-up' => 'chevron double up' ),
					array( 'fal fa-chevron-down' => 'chevron down' ),
					array( 'fal fa-chevron-left' => 'chevron left' ),
					array( 'fal fa-chevron-right' => 'chevron right' ),
					array( 'fal fa-chevron-square-down' => 'chevron square down' ),
					array( 'fal fa-chevron-square-left' => 'chevron square left' ),
					array( 'fal fa-chevron-square-right' => 'chevron square right' ),
					array( 'fal fa-chevron-square-up' => 'chevron square up' ),
					array( 'fal fa-chevron-up' => 'chevron up' ),
					array( 'fal fa-child' => 'child' ),
					array( 'fal fa-chimney' => 'chimney' ),
					array( 'fal fa-church' => 'church' ),
					array( 'fal fa-circle-notch' => 'circle notch' ),
					array( 'fal fa-circle' => 'circle' ),
					array( 'fal fa-city' => 'city' ),
					array( 'fal fa-clarinet' => 'clarinet' ),
					array( 'fal fa-claw-marks' => 'claw marks' ),
					array( 'fal fa-clinic-medical' => 'clinic medical' ),
					array( 'fal fa-clipboard-check' => 'clipboard check' ),
					array( 'fal fa-clipboard-list-check' => 'clipboard list check' ),
					array( 'fal fa-clipboard-list' => 'clipboard list' ),
					array( 'fal fa-clipboard-prescription' => 'clipboard prescription' ),
					array( 'fal fa-clipboard-user' => 'clipboard user' ),
					array( 'fal fa-clipboard' => 'clipboard' ),
					array( 'fal fa-clock' => 'clock' ),
					array( 'fal fa-clone' => 'clone' ),
					array( 'fal fa-closed-captioning' => 'closed captioning' ),
					array( 'fal fa-cloud-download-alt' => 'cloud download alt' ),
					array( 'fal fa-cloud-download' => 'cloud download' ),
					array( 'fal fa-cloud-drizzle' => 'cloud drizzle' ),
					array( 'fal fa-cloud-hail-mixed' => 'cloud hail mixed' ),
					array( 'fal fa-cloud-hail' => 'cloud hail' ),
					array( 'fal fa-cloud-meatball' => 'cloud meatball' ),
					array( 'fal fa-cloud-moon-rain' => 'cloud moon rain' ),
					array( 'fal fa-cloud-moon' => 'cloud moon' ),
					array( 'fal fa-cloud-music' => 'cloud music' ),
					array( 'fal fa-cloud-rain' => 'cloud rain' ),
					array( 'fal fa-cloud-rainbow' => 'cloud rainbow' ),
					array( 'fal fa-cloud-showers-heavy' => 'cloud showers heavy' ),
					array( 'fal fa-cloud-showers' => 'cloud showers' ),
					array( 'fal fa-cloud-sleet' => 'cloud sleet' ),
					array( 'fal fa-cloud-snow' => 'cloud snow' ),
					array( 'fal fa-cloud-sun-rain' => 'cloud sun rain' ),
					array( 'fal fa-cloud-sun' => 'cloud sun' ),
					array( 'fal fa-cloud-upload-alt' => 'cloud upload alt' ),
					array( 'fal fa-cloud-upload' => 'cloud upload' ),
					array( 'fal fa-cloud' => 'cloud' ),
					array( 'fal fa-clouds-moon' => 'clouds moon' ),
					array( 'fal fa-clouds-sun' => 'clouds sun' ),
					array( 'fal fa-clouds' => 'clouds' ),
					array( 'fal fa-club' => 'club' ),
					array( 'fal fa-cocktail' => 'cocktail' ),
					array( 'fal fa-code-branch' => 'code branch' ),
					array( 'fal fa-code-commit' => 'code commit' ),
					array( 'fal fa-code-merge' => 'code merge' ),
					array( 'fal fa-code' => 'code' ),
					array( 'fal fa-coffee-pot' => 'coffee pot' ),
					array( 'fal fa-coffee-togo' => 'coffee togo' ),
					array( 'fal fa-coffee' => 'coffee' ),
					array( 'fal fa-coffin-cross' => 'coffin cross' ),
					array( 'fal fa-coffin' => 'coffin' ),
					array( 'fal fa-cog' => 'cog' ),
					array( 'fal fa-cogs' => 'cogs' ),
					array( 'fal fa-coin' => 'coin' ),
					array( 'fal fa-coins' => 'coins' ),
					array( 'fal fa-columns' => 'columns' ),
					array( 'fal fa-comet' => 'comet' ),
					array( 'fal fa-comment-alt-check' => 'comment alt check' ),
					array( 'fal fa-comment-alt-dollar' => 'comment alt dollar' ),
					array( 'fal fa-comment-alt-dots' => 'comment alt dots' ),
					array( 'fal fa-comment-alt-edit' => 'comment alt edit' ),
					array( 'fal fa-comment-alt-exclamation' => 'comment alt exclamation' ),
					array( 'fal fa-comment-alt-lines' => 'comment alt lines' ),
					array( 'fal fa-comment-alt-medical' => 'comment alt medical' ),
					array( 'fal fa-comment-alt-minus' => 'comment alt minus' ),
					array( 'fal fa-comment-alt-music' => 'comment alt music' ),
					array( 'fal fa-comment-alt-plus' => 'comment alt plus' ),
					array( 'fal fa-comment-alt-slash' => 'comment alt slash' ),
					array( 'fal fa-comment-alt-smile' => 'comment alt smile' ),
					array( 'fal fa-comment-alt-times' => 'comment alt times' ),
					array( 'fal fa-comment-alt' => 'comment alt' ),
					array( 'fal fa-comment-check' => 'comment check' ),
					array( 'fal fa-comment-dollar' => 'comment dollar' ),
					array( 'fal fa-comment-dots' => 'comment dots' ),
					array( 'fal fa-comment-edit' => 'comment edit' ),
					array( 'fal fa-comment-exclamation' => 'comment exclamation' ),
					array( 'fal fa-comment-lines' => 'comment lines' ),
					array( 'fal fa-comment-medical' => 'comment medical' ),
					array( 'fal fa-comment-minus' => 'comment minus' ),
					array( 'fal fa-comment-music' => 'comment music' ),
					array( 'fal fa-comment-plus' => 'comment plus' ),
					array( 'fal fa-comment-slash' => 'comment slash' ),
					array( 'fal fa-comment-smile' => 'comment smile' ),
					array( 'fal fa-comment-times' => 'comment times' ),
					array( 'fal fa-comment' => 'comment' ),
					array( 'fal fa-comments-alt-dollar' => 'comments alt dollar' ),
					array( 'fal fa-comments-alt' => 'comments alt' ),
					array( 'fal fa-comments-dollar' => 'comments dollar' ),
					array( 'fal fa-comments' => 'comments' ),
					array( 'fal fa-compact-disc' => 'compact disc' ),
					array( 'fal fa-compass-slash' => 'compass slash' ),
					array( 'fal fa-compass' => 'compass' ),
					array( 'fal fa-compress-alt' => 'compress alt' ),
					array( 'fal fa-compress-arrows-alt' => 'compress arrows alt' ),
					array( 'fal fa-compress-wide' => 'compress wide' ),
					array( 'fal fa-compress' => 'compress' ),
					array( 'fal fa-computer-classic' => 'computer classic' ),
					array( 'fal fa-computer-speaker' => 'computer speaker' ),
					array( 'fal fa-concierge-bell' => 'concierge bell' ),
					array( 'fal fa-construction' => 'construction' ),
					array( 'fal fa-container-storage' => 'container storage' ),
					array( 'fal fa-conveyor-belt-alt' => 'conveyor belt alt' ),
					array( 'fal fa-conveyor-belt' => 'conveyor belt' ),
					array( 'fal fa-cookie-bite' => 'cookie bite' ),
					array( 'fal fa-cookie' => 'cookie' ),
					array( 'fal fa-copy' => 'copy' ),
					array( 'fal fa-copyright' => 'copyright' ),
					array( 'fal fa-corn' => 'corn' ),
					array( 'fal fa-couch' => 'couch' ),
					array( 'fal fa-cow' => 'cow' ),
					array( 'fal fa-cowbell-more' => 'cowbell more' ),
					array( 'fal fa-cowbell' => 'cowbell' ),
					array( 'fal fa-credit-card-blank' => 'credit card blank' ),
					array( 'fal fa-credit-card-front' => 'credit card front' ),
					array( 'fal fa-credit-card' => 'credit card' ),
					array( 'fal fa-cricket' => 'cricket' ),
					array( 'fal fa-croissant' => 'croissant' ),
					array( 'fal fa-crop-alt' => 'crop alt' ),
					array( 'fal fa-crop' => 'crop' ),
					array( 'fal fa-cross' => 'cross' ),
					array( 'fal fa-crosshairs' => 'crosshairs' ),
					array( 'fal fa-crow' => 'crow' ),
					array( 'fal fa-crown' => 'crown' ),
					array( 'fal fa-crutch' => 'crutch' ),
					array( 'fal fa-crutches' => 'crutches' ),
					array( 'fal fa-cube' => 'cube' ),
					array( 'fal fa-cubes' => 'cubes' ),
					array( 'fal fa-curling' => 'curling' ),
					array( 'fal fa-cut' => 'cut' ),
					array( 'fal fa-dagger' => 'dagger' ),
					array( 'fal fa-database' => 'database' ),
					array( 'fal fa-deaf' => 'deaf' ),
					array( 'fal fa-debug' => 'debug' ),
					array( 'fal fa-deer-rudolph' => 'deer rudolph' ),
					array( 'fal fa-deer' => 'deer' ),
					array( 'fal fa-democrat' => 'democrat' ),
					array( 'fal fa-desktop-alt' => 'desktop alt' ),
					array( 'fal fa-desktop' => 'desktop' ),
					array( 'fal fa-dewpoint' => 'dewpoint' ),
					array( 'fal fa-dharmachakra' => 'dharmachakra' ),
					array( 'fal fa-diagnoses' => 'diagnoses' ),
					array( 'fal fa-diamond' => 'diamond' ),
					array( 'fal fa-dice-d10' => 'dice d10' ),
					array( 'fal fa-dice-d12' => 'dice d12' ),
					array( 'fal fa-dice-d20' => 'dice d20' ),
					array( 'fal fa-dice-d4' => 'dice d4' ),
					array( 'fal fa-dice-d6' => 'dice d6' ),
					array( 'fal fa-dice-d8' => 'dice d8' ),
					array( 'fal fa-dice-five' => 'dice five' ),
					array( 'fal fa-dice-four' => 'dice four' ),
					array( 'fal fa-dice-one' => 'dice one' ),
					array( 'fal fa-dice-six' => 'dice six' ),
					array( 'fal fa-dice-three' => 'dice three' ),
					array( 'fal fa-dice-two' => 'dice two' ),
					array( 'fal fa-dice' => 'dice' ),
					array( 'fal fa-digging' => 'digging' ),
					array( 'fal fa-digital-tachograph' => 'digital tachograph' ),
					array( 'fal fa-diploma' => 'diploma' ),
					array( 'fal fa-directions' => 'directions' ),
					array( 'fal fa-disc-drive' => 'disc drive' ),
					array( 'fal fa-disease' => 'disease' ),
					array( 'fal fa-divide' => 'divide' ),
					array( 'fal fa-dizzy' => 'dizzy' ),
					array( 'fal fa-dna' => 'dna' ),
					array( 'fal fa-do-not-enter' => 'do not enter' ),
					array( 'fal fa-dog-leashed' => 'dog leashed' ),
					array( 'fal fa-dog' => 'dog' ),
					array( 'fal fa-dollar-sign' => 'dollar sign' ),
					array( 'fal fa-dolly-empty' => 'dolly empty' ),
					array( 'fal fa-dolly-flatbed-alt' => 'dolly flatbed alt' ),
					array( 'fal fa-dolly-flatbed-empty' => 'dolly flatbed empty' ),
					array( 'fal fa-dolly-flatbed' => 'dolly flatbed' ),
					array( 'fal fa-dolly' => 'dolly' ),
					array( 'fal fa-donate' => 'donate' ),
					array( 'fal fa-door-closed' => 'door closed' ),
					array( 'fal fa-door-open' => 'door open' ),
					array( 'fal fa-dot-circle' => 'dot circle' ),
					array( 'fal fa-dove' => 'dove' ),
					array( 'fal fa-download' => 'download' ),
					array( 'fal fa-drafting-compass' => 'drafting compass' ),
					array( 'fal fa-dragon' => 'dragon' ),
					array( 'fal fa-draw-circle' => 'draw circle' ),
					array( 'fal fa-draw-polygon' => 'draw polygon' ),
					array( 'fal fa-draw-square' => 'draw square' ),
					array( 'fal fa-dreidel' => 'dreidel' ),
					array( 'fal fa-drone-alt' => 'drone alt' ),
					array( 'fal fa-drone' => 'drone' ),
					array( 'fal fa-drum-steelpan' => 'drum steelpan' ),
					array( 'fal fa-drum' => 'drum' ),
					array( 'fal fa-drumstick-bite' => 'drumstick bite' ),
					array( 'fal fa-drumstick' => 'drumstick' ),
					array( 'fal fa-dryer-alt' => 'dryer alt' ),
					array( 'fal fa-dryer' => 'dryer' ),
					array( 'fal fa-duck' => 'duck' ),
					array( 'fal fa-dumbbell' => 'dumbbell' ),
					array( 'fal fa-dumpster-fire' => 'dumpster fire' ),
					array( 'fal fa-dumpster' => 'dumpster' ),
					array( 'fal fa-dungeon' => 'dungeon' ),
					array( 'fal fa-ear-muffs' => 'ear muffs' ),
					array( 'fal fa-ear' => 'ear' ),
					array( 'fal fa-eclipse-alt' => 'eclipse alt' ),
					array( 'fal fa-eclipse' => 'eclipse' ),
					array( 'fal fa-edit' => 'edit' ),
					array( 'fal fa-egg-fried' => 'egg fried' ),
					array( 'fal fa-egg' => 'egg' ),
					array( 'fal fa-eject' => 'eject' ),
					array( 'fal fa-elephant' => 'elephant' ),
					array( 'fal fa-ellipsis-h-alt' => 'ellipsis h alt' ),
					array( 'fal fa-ellipsis-h' => 'ellipsis h' ),
					array( 'fal fa-ellipsis-v-alt' => 'ellipsis v alt' ),
					array( 'fal fa-ellipsis-v' => 'ellipsis v' ),
					array( 'fal fa-empty-set' => 'empty set' ),
					array( 'fal fa-engine-warning' => 'engine warning' ),
					array( 'fal fa-envelope-open-dollar' => 'envelope open dollar' ),
					array( 'fal fa-envelope-open-text' => 'envelope open text' ),
					array( 'fal fa-envelope-open' => 'envelope open' ),
					array( 'fal fa-envelope-square' => 'envelope square' ),
					array( 'fal fa-envelope' => 'envelope' ),
					array( 'fal fa-equals' => 'equals' ),
					array( 'fal fa-eraser' => 'eraser' ),
					array( 'fal fa-ethernet' => 'ethernet' ),
					array( 'fal fa-euro-sign' => 'euro sign' ),
					array( 'fal fa-exchange-alt' => 'exchange alt' ),
					array( 'fal fa-exchange' => 'exchange' ),
					array( 'fal fa-exclamation-circle' => 'exclamation circle' ),
					array( 'fal fa-exclamation-square' => 'exclamation square' ),
					array( 'fal fa-exclamation-triangle' => 'exclamation triangle' ),
					array( 'fal fa-exclamation' => 'exclamation' ),
					array( 'fal fa-expand-alt' => 'expand alt' ),
					array( 'fal fa-expand-arrows-alt' => 'expand arrows alt' ),
					array( 'fal fa-expand-arrows' => 'expand arrows' ),
					array( 'fal fa-expand-wide' => 'expand wide' ),
					array( 'fal fa-expand' => 'expand' ),
					array( 'fal fa-external-link-alt' => 'external link alt' ),
					array( 'fal fa-external-link-square-alt' => 'external link square alt' ),
					array( 'fal fa-external-link-square' => 'external link square' ),
					array( 'fal fa-external-link' => 'external link' ),
					array( 'fal fa-eye-dropper' => 'eye dropper' ),
					array( 'fal fa-eye-evil' => 'eye evil' ),
					array( 'fal fa-eye-slash' => 'eye slash' ),
					array( 'fal fa-eye' => 'eye' ),
					array( 'fal fa-fan-table' => 'fan table' ),
					array( 'fal fa-fan' => 'fan' ),
					array( 'fal fa-farm' => 'farm' ),
					array( 'fal fa-fast-backward' => 'fast backward' ),
					array( 'fal fa-fast-forward' => 'fast forward' ),
					array( 'fal fa-faucet-drip' => 'faucet drip' ),
					array( 'fal fa-faucet' => 'faucet' ),
					array( 'fal fa-fax' => 'fax' ),
					array( 'fal fa-feather-alt' => 'feather alt' ),
					array( 'fal fa-feather' => 'feather' ),
					array( 'fal fa-female' => 'female' ),
					array( 'fal fa-field-hockey' => 'field hockey' ),
					array( 'fal fa-fighter-jet' => 'fighter jet' ),
					array( 'fal fa-file-alt' => 'file alt' ),
					array( 'fal fa-file-archive' => 'file archive' ),
					array( 'fal fa-file-audio' => 'file audio' ),
					array( 'fal fa-file-certificate' => 'file certificate' ),
					array( 'fal fa-file-chart-line' => 'file chart line' ),
					array( 'fal fa-file-chart-pie' => 'file chart pie' ),
					array( 'fal fa-file-check' => 'file check' ),
					array( 'fal fa-file-code' => 'file code' ),
					array( 'fal fa-file-contract' => 'file contract' ),
					array( 'fal fa-file-csv' => 'file csv' ),
					array( 'fal fa-file-download' => 'file download' ),
					array( 'fal fa-file-edit' => 'file edit' ),
					array( 'fal fa-file-excel' => 'file excel' ),
					array( 'fal fa-file-exclamation' => 'file exclamation' ),
					array( 'fal fa-file-export' => 'file export' ),
					array( 'fal fa-file-image' => 'file image' ),
					array( 'fal fa-file-import' => 'file import' ),
					array( 'fal fa-file-invoice-dollar' => 'file invoice dollar' ),
					array( 'fal fa-file-invoice' => 'file invoice' ),
					array( 'fal fa-file-medical-alt' => 'file medical alt' ),
					array( 'fal fa-file-medical' => 'file medical' ),
					array( 'fal fa-file-minus' => 'file minus' ),
					array( 'fal fa-file-music' => 'file music' ),
					array( 'fal fa-file-pdf' => 'file pdf' ),
					array( 'fal fa-file-plus' => 'file plus' ),
					array( 'fal fa-file-powerpoint' => 'file powerpoint' ),
					array( 'fal fa-file-prescription' => 'file prescription' ),
					array( 'fal fa-file-search' => 'file search' ),
					array( 'fal fa-file-signature' => 'file signature' ),
					array( 'fal fa-file-spreadsheet' => 'file spreadsheet' ),
					array( 'fal fa-file-times' => 'file times' ),
					array( 'fal fa-file-upload' => 'file upload' ),
					array( 'fal fa-file-user' => 'file user' ),
					array( 'fal fa-file-video' => 'file video' ),
					array( 'fal fa-file-word' => 'file word' ),
					array( 'fal fa-file' => 'file' ),
					array( 'fal fa-files-medical' => 'files medical' ),
					array( 'fal fa-fill-drip' => 'fill drip' ),
					array( 'fal fa-fill' => 'fill' ),
					array( 'fal fa-film-alt' => 'film alt' ),
					array( 'fal fa-film-canister' => 'film canister' ),
					array( 'fal fa-film' => 'film' ),
					array( 'fal fa-filter' => 'filter' ),
					array( 'fal fa-fingerprint' => 'fingerprint' ),
					array( 'fal fa-fire-alt' => 'fire alt' ),
					array( 'fal fa-fire-extinguisher' => 'fire extinguisher' ),
					array( 'fal fa-fire-smoke' => 'fire smoke' ),
					array( 'fal fa-fire' => 'fire' ),
					array( 'fal fa-fireplace' => 'fireplace' ),
					array( 'fal fa-first-aid' => 'first aid' ),
					array( 'fal fa-fish-cooked' => 'fish cooked' ),
					array( 'fal fa-fish' => 'fish' ),
					array( 'fal fa-fist-raised' => 'fist raised' ),
					array( 'fal fa-flag-alt' => 'flag alt' ),
					array( 'fal fa-flag-checkered' => 'flag checkered' ),
					array( 'fal fa-flag-usa' => 'flag usa' ),
					array( 'fal fa-flag' => 'flag' ),
					array( 'fal fa-flame' => 'flame' ),
					array( 'fal fa-flashlight' => 'flashlight' ),
					array( 'fal fa-flask-poison' => 'flask poison' ),
					array( 'fal fa-flask-potion' => 'flask potion' ),
					array( 'fal fa-flask' => 'flask' ),
					array( 'fal fa-flower-daffodil' => 'flower daffodil' ),
					array( 'fal fa-flower-tulip' => 'flower tulip' ),
					array( 'fal fa-flower' => 'flower' ),
					array( 'fal fa-flushed' => 'flushed' ),
					array( 'fal fa-flute' => 'flute' ),
					array( 'fal fa-flux-capacitor' => 'flux capacitor' ),
					array( 'fal fa-fog' => 'fog' ),
					array( 'fal fa-folder-download' => 'folder download' ),
					array( 'fal fa-folder-minus' => 'folder minus' ),
					array( 'fal fa-folder-open' => 'folder open' ),
					array( 'fal fa-folder-plus' => 'folder plus' ),
					array( 'fal fa-folder-times' => 'folder times' ),
					array( 'fal fa-folder-tree' => 'folder tree' ),
					array( 'fal fa-folder-upload' => 'folder upload' ),
					array( 'fal fa-folder' => 'folder' ),
					array( 'fal fa-folders' => 'folders' ),
					array( 'fal fa-font-awesome-logo-full' => 'font awesome logo full' ),
					array( 'fal fa-font-case' => 'font case' ),
					array( 'fal fa-font' => 'font' ),
					array( 'fal fa-football-ball' => 'football ball' ),
					array( 'fal fa-football-helmet' => 'football helmet' ),
					array( 'fal fa-forklift' => 'forklift' ),
					array( 'fal fa-forward' => 'forward' ),
					array( 'fal fa-fragile' => 'fragile' ),
					array( 'fal fa-french-fries' => 'french fries' ),
					array( 'fal fa-frog' => 'frog' ),
					array( 'fal fa-frosty-head' => 'frosty head' ),
					array( 'fal fa-frown-open' => 'frown open' ),
					array( 'fal fa-frown' => 'frown' ),
					array( 'fal fa-function' => 'function' ),
					array( 'fal fa-funnel-dollar' => 'funnel dollar' ),
					array( 'fal fa-futbol' => 'futbol' ),
					array( 'fal fa-galaxy' => 'galaxy' ),
					array( 'fal fa-game-board-alt' => 'game board alt' ),
					array( 'fal fa-game-board' => 'game board' ),
					array( 'fal fa-game-console-handheld' => 'game console handheld' ),
					array( 'fal fa-gamepad-alt' => 'gamepad alt' ),
					array( 'fal fa-gamepad' => 'gamepad' ),
					array( 'fal fa-garage-car' => 'garage car' ),
					array( 'fal fa-garage-open' => 'garage open' ),
					array( 'fal fa-garage' => 'garage' ),
					array( 'fal fa-gas-pump-slash' => 'gas pump slash' ),
					array( 'fal fa-gas-pump' => 'gas pump' ),
					array( 'fal fa-gavel' => 'gavel' ),
					array( 'fal fa-gem' => 'gem' ),
					array( 'fal fa-genderless' => 'genderless' ),
					array( 'fal fa-ghost' => 'ghost' ),
					array( 'fal fa-gift-card' => 'gift card' ),
					array( 'fal fa-gift' => 'gift' ),
					array( 'fal fa-gifts' => 'gifts' ),
					array( 'fal fa-gingerbread-man' => 'gingerbread man' ),
					array( 'fal fa-glass-champagne' => 'glass champagne' ),
					array( 'fal fa-glass-cheers' => 'glass cheers' ),
					array( 'fal fa-glass-citrus' => 'glass citrus' ),
					array( 'fal fa-glass-martini-alt' => 'glass martini alt' ),
					array( 'fal fa-glass-martini' => 'glass martini' ),
					array( 'fal fa-glass-whiskey-rocks' => 'glass whiskey rocks' ),
					array( 'fal fa-glass-whiskey' => 'glass whiskey' ),
					array( 'fal fa-glass' => 'glass' ),
					array( 'fal fa-glasses-alt' => 'glasses alt' ),
					array( 'fal fa-glasses' => 'glasses' ),
					array( 'fal fa-globe-africa' => 'globe africa' ),
					array( 'fal fa-globe-americas' => 'globe americas' ),
					array( 'fal fa-globe-asia' => 'globe asia' ),
					array( 'fal fa-globe-europe' => 'globe europe' ),
					array( 'fal fa-globe-snow' => 'globe snow' ),
					array( 'fal fa-globe-stand' => 'globe stand' ),
					array( 'fal fa-globe' => 'globe' ),
					array( 'fal fa-golf-ball' => 'golf ball' ),
					array( 'fal fa-golf-club' => 'golf club' ),
					array( 'fal fa-gopuram' => 'gopuram' ),
					array( 'fal fa-graduation-cap' => 'graduation cap' ),
					array( 'fal fa-gramophone' => 'gramophone' ),
					array( 'fal fa-greater-than-equal' => 'greater than equal' ),
					array( 'fal fa-greater-than' => 'greater than' ),
					array( 'fal fa-grimace' => 'grimace' ),
					array( 'fal fa-grin-alt' => 'grin alt' ),
					array( 'fal fa-grin-beam-sweat' => 'grin beam sweat' ),
					array( 'fal fa-grin-beam' => 'grin beam' ),
					array( 'fal fa-grin-hearts' => 'grin hearts' ),
					array( 'fal fa-grin-squint-tears' => 'grin squint tears' ),
					array( 'fal fa-grin-squint' => 'grin squint' ),
					array( 'fal fa-grin-stars' => 'grin stars' ),
					array( 'fal fa-grin-tears' => 'grin tears' ),
					array( 'fal fa-grin-tongue-squint' => 'grin tongue squint' ),
					array( 'fal fa-grin-tongue-wink' => 'grin tongue wink' ),
					array( 'fal fa-grin-tongue' => 'grin tongue' ),
					array( 'fal fa-grin-wink' => 'grin wink' ),
					array( 'fal fa-grin' => 'grin' ),
					array( 'fal fa-grip-horizontal' => 'grip horizontal' ),
					array( 'fal fa-grip-lines-vertical' => 'grip lines vertical' ),
					array( 'fal fa-grip-lines' => 'grip lines' ),
					array( 'fal fa-grip-vertical' => 'grip vertical' ),
					array( 'fal fa-guitar-electric' => 'guitar electric' ),
					array( 'fal fa-guitar' => 'guitar' ),
					array( 'fal fa-guitars' => 'guitars' ),
					array( 'fal fa-h-square' => 'h square' ),
					array( 'fal fa-h1' => 'h1' ),
					array( 'fal fa-h2' => 'h2' ),
					array( 'fal fa-h3' => 'h3' ),
					array( 'fal fa-h4' => 'h4' ),
					array( 'fal fa-hamburger' => 'hamburger' ),
					array( 'fal fa-hammer-war' => 'hammer war' ),
					array( 'fal fa-hammer' => 'hammer' ),
					array( 'fal fa-hamsa' => 'hamsa' ),
					array( 'fal fa-hand-heart' => 'hand heart' ),
					array( 'fal fa-hand-holding-box' => 'hand holding box' ),
					array( 'fal fa-hand-holding-heart' => 'hand holding heart' ),
					array( 'fal fa-hand-holding-magic' => 'hand holding magic' ),
					array( 'fal fa-hand-holding-medical' => 'hand holding medical' ),
					array( 'fal fa-hand-holding-seedling' => 'hand holding seedling' ),
					array( 'fal fa-hand-holding-usd' => 'hand holding usd' ),
					array( 'fal fa-hand-holding-water' => 'hand holding water' ),
					array( 'fal fa-hand-holding' => 'hand holding' ),
					array( 'fal fa-hand-lizard' => 'hand lizard' ),
					array( 'fal fa-hand-middle-finger' => 'hand middle finger' ),
					array( 'fal fa-hand-paper' => 'hand paper' ),
					array( 'fal fa-hand-peace' => 'hand peace' ),
					array( 'fal fa-hand-point-down' => 'hand point down' ),
					array( 'fal fa-hand-point-left' => 'hand point left' ),
					array( 'fal fa-hand-point-right' => 'hand point right' ),
					array( 'fal fa-hand-point-up' => 'hand point up' ),
					array( 'fal fa-hand-pointer' => 'hand pointer' ),
					array( 'fal fa-hand-receiving' => 'hand receiving' ),
					array( 'fal fa-hand-rock' => 'hand rock' ),
					array( 'fal fa-hand-scissors' => 'hand scissors' ),
					array( 'fal fa-hand-sparkles' => 'hand sparkles' ),
					array( 'fal fa-hand-spock' => 'hand spock' ),
					array( 'fal fa-hands-heart' => 'hands heart' ),
					array( 'fal fa-hands-helping' => 'hands helping' ),
					array( 'fal fa-hands-usd' => 'hands usd' ),
					array( 'fal fa-hands-wash' => 'hands wash' ),
					array( 'fal fa-hands' => 'hands' ),
					array( 'fal fa-handshake-alt-slash' => 'handshake alt slash' ),
					array( 'fal fa-handshake-alt' => 'handshake alt' ),
					array( 'fal fa-handshake-slash' => 'handshake slash' ),
					array( 'fal fa-handshake' => 'handshake' ),
					array( 'fal fa-hanukiah' => 'hanukiah' ),
					array( 'fal fa-hard-hat' => 'hard hat' ),
					array( 'fal fa-hashtag' => 'hashtag' ),
					array( 'fal fa-hat-chef' => 'hat chef' ),
					array( 'fal fa-hat-cowboy-side' => 'hat cowboy side' ),
					array( 'fal fa-hat-cowboy' => 'hat cowboy' ),
					array( 'fal fa-hat-santa' => 'hat santa' ),
					array( 'fal fa-hat-winter' => 'hat winter' ),
					array( 'fal fa-hat-witch' => 'hat witch' ),
					array( 'fal fa-hat-wizard' => 'hat wizard' ),
					array( 'fal fa-hdd' => 'hdd' ),
					array( 'fal fa-head-side-brain' => 'head side brain' ),
					array( 'fal fa-head-side-cough-slash' => 'head side cough slash' ),
					array( 'fal fa-head-side-cough' => 'head side cough' ),
					array( 'fal fa-head-side-headphones' => 'head side headphones' ),
					array( 'fal fa-head-side-mask' => 'head side mask' ),
					array( 'fal fa-head-side-medical' => 'head side medical' ),
					array( 'fal fa-head-side-virus' => 'head side virus' ),
					array( 'fal fa-head-side' => 'head side' ),
					array( 'fal fa-head-vr' => 'head vr' ),
					array( 'fal fa-heading' => 'heading' ),
					array( 'fal fa-headphones-alt' => 'headphones alt' ),
					array( 'fal fa-headphones' => 'headphones' ),
					array( 'fal fa-headset' => 'headset' ),
					array( 'fal fa-heart-broken' => 'heart broken' ),
					array( 'fal fa-heart-circle' => 'heart circle' ),
					array( 'fal fa-heart-rate' => 'heart rate' ),
					array( 'fal fa-heart-square' => 'heart square' ),
					array( 'fal fa-heart' => 'heart' ),
					array( 'fal fa-heartbeat' => 'heartbeat' ),
					array( 'fal fa-heat' => 'heat' ),
					array( 'fal fa-helicopter' => 'helicopter' ),
					array( 'fal fa-helmet-battle' => 'helmet battle' ),
					array( 'fal fa-hexagon' => 'hexagon' ),
					array( 'fal fa-highlighter' => 'highlighter' ),
					array( 'fal fa-hiking' => 'hiking' ),
					array( 'fal fa-hippo' => 'hippo' ),
					array( 'fal fa-history' => 'history' ),
					array( 'fal fa-hockey-mask' => 'hockey mask' ),
					array( 'fal fa-hockey-puck' => 'hockey puck' ),
					array( 'fal fa-hockey-sticks' => 'hockey sticks' ),
					array( 'fal fa-holly-berry' => 'holly berry' ),
					array( 'fal fa-home-alt' => 'home alt' ),
					array( 'fal fa-home-heart' => 'home heart' ),
					array( 'fal fa-home-lg-alt' => 'home lg alt' ),
					array( 'fal fa-home-lg' => 'home lg' ),
					array( 'fal fa-home' => 'home' ),
					array( 'fal fa-hood-cloak' => 'hood cloak' ),
					array( 'fal fa-horizontal-rule' => 'horizontal rule' ),
					array( 'fal fa-horse-head' => 'horse head' ),
					array( 'fal fa-horse-saddle' => 'horse saddle' ),
					array( 'fal fa-horse' => 'horse' ),
					array( 'fal fa-hospital-alt' => 'hospital alt' ),
					array( 'fal fa-hospital-symbol' => 'hospital symbol' ),
					array( 'fal fa-hospital-user' => 'hospital user' ),
					array( 'fal fa-hospital' => 'hospital' ),
					array( 'fal fa-hospitals' => 'hospitals' ),
					array( 'fal fa-hot-tub' => 'hot tub' ),
					array( 'fal fa-hotdog' => 'hotdog' ),
					array( 'fal fa-hotel' => 'hotel' ),
					array( 'fal fa-hourglass-end' => 'hourglass end' ),
					array( 'fal fa-hourglass-half' => 'hourglass half' ),
					array( 'fal fa-hourglass-start' => 'hourglass start' ),
					array( 'fal fa-hourglass' => 'hourglass' ),
					array( 'fal fa-house-damage' => 'house damage' ),
					array( 'fal fa-house-day' => 'house day' ),
					array( 'fal fa-house-flood' => 'house flood' ),
					array( 'fal fa-house-leave' => 'house leave' ),
					array( 'fal fa-house-night' => 'house night' ),
					array( 'fal fa-house-return' => 'house return' ),
					array( 'fal fa-house-signal' => 'house signal' ),
					array( 'fal fa-house-user' => 'house user' ),
					array( 'fal fa-house' => 'house' ),
					array( 'fal fa-hryvnia' => 'hryvnia' ),
					array( 'fal fa-humidity' => 'humidity' ),
					array( 'fal fa-hurricane' => 'hurricane' ),
					array( 'fal fa-i-cursor' => 'i cursor' ),
					array( 'fal fa-ice-cream' => 'ice cream' ),
					array( 'fal fa-ice-skate' => 'ice skate' ),
					array( 'fal fa-icicles' => 'icicles' ),
					array( 'fal fa-icons-alt' => 'icons alt' ),
					array( 'fal fa-icons' => 'icons' ),
					array( 'fal fa-id-badge' => 'id badge' ),
					array( 'fal fa-id-card-alt' => 'id card alt' ),
					array( 'fal fa-id-card' => 'id card' ),
					array( 'fal fa-igloo' => 'igloo' ),
					array( 'fal fa-image-polaroid' => 'image polaroid' ),
					array( 'fal fa-image' => 'image' ),
					array( 'fal fa-images' => 'images' ),
					array( 'fal fa-inbox-in' => 'inbox in' ),
					array( 'fal fa-inbox-out' => 'inbox out' ),
					array( 'fal fa-inbox' => 'inbox' ),
					array( 'fal fa-indent' => 'indent' ),
					array( 'fal fa-industry-alt' => 'industry alt' ),
					array( 'fal fa-industry' => 'industry' ),
					array( 'fal fa-infinity' => 'infinity' ),
					array( 'fal fa-info-circle' => 'info circle' ),
					array( 'fal fa-info-square' => 'info square' ),
					array( 'fal fa-info' => 'info' ),
					array( 'fal fa-inhaler' => 'inhaler' ),
					array( 'fal fa-integral' => 'integral' ),
					array( 'fal fa-intersection' => 'intersection' ),
					array( 'fal fa-inventory' => 'inventory' ),
					array( 'fal fa-island-tropical' => 'island tropical' ),
					array( 'fal fa-italic' => 'italic' ),
					array( 'fal fa-jack-o-lantern' => 'jack o lantern' ),
					array( 'fal fa-jedi' => 'jedi' ),
					array( 'fal fa-joint' => 'joint' ),
					array( 'fal fa-journal-whills' => 'journal whills' ),
					array( 'fal fa-joystick' => 'joystick' ),
					array( 'fal fa-jug' => 'jug' ),
					array( 'fal fa-kaaba' => 'kaaba' ),
					array( 'fal fa-kazoo' => 'kazoo' ),
					array( 'fal fa-kerning' => 'kerning' ),
					array( 'fal fa-key-skeleton' => 'key skeleton' ),
					array( 'fal fa-key' => 'key' ),
					array( 'fal fa-keyboard' => 'keyboard' ),
					array( 'fal fa-keynote' => 'keynote' ),
					array( 'fal fa-khanda' => 'khanda' ),
					array( 'fal fa-kidneys' => 'kidneys' ),
					array( 'fal fa-kiss-beam' => 'kiss beam' ),
					array( 'fal fa-kiss-wink-heart' => 'kiss wink heart' ),
					array( 'fal fa-kiss' => 'kiss' ),
					array( 'fal fa-kite' => 'kite' ),
					array( 'fal fa-kiwi-bird' => 'kiwi bird' ),
					array( 'fal fa-knife-kitchen' => 'knife kitchen' ),
					array( 'fal fa-lambda' => 'lambda' ),
					array( 'fal fa-lamp-desk' => 'lamp desk' ),
					array( 'fal fa-lamp-floor' => 'lamp floor' ),
					array( 'fal fa-lamp' => 'lamp' ),
					array( 'fal fa-landmark-alt' => 'landmark alt' ),
					array( 'fal fa-landmark' => 'landmark' ),
					array( 'fal fa-language' => 'language' ),
					array( 'fal fa-laptop-code' => 'laptop code' ),
					array( 'fal fa-laptop-house' => 'laptop house' ),
					array( 'fal fa-laptop-medical' => 'laptop medical' ),
					array( 'fal fa-laptop' => 'laptop' ),
					array( 'fal fa-lasso' => 'lasso' ),
					array( 'fal fa-laugh-beam' => 'laugh beam' ),
					array( 'fal fa-laugh-squint' => 'laugh squint' ),
					array( 'fal fa-laugh-wink' => 'laugh wink' ),
					array( 'fal fa-laugh' => 'laugh' ),
					array( 'fal fa-layer-group' => 'layer group' ),
					array( 'fal fa-layer-minus' => 'layer minus' ),
					array( 'fal fa-layer-plus' => 'layer plus' ),
					array( 'fal fa-leaf-heart' => 'leaf heart' ),
					array( 'fal fa-leaf-maple' => 'leaf maple' ),
					array( 'fal fa-leaf-oak' => 'leaf oak' ),
					array( 'fal fa-leaf' => 'leaf' ),
					array( 'fal fa-lemon' => 'lemon' ),
					array( 'fal fa-less-than-equal' => 'less than equal' ),
					array( 'fal fa-less-than' => 'less than' ),
					array( 'fal fa-level-down-alt' => 'level down alt' ),
					array( 'fal fa-level-down' => 'level down' ),
					array( 'fal fa-level-up-alt' => 'level up alt' ),
					array( 'fal fa-level-up' => 'level up' ),
					array( 'fal fa-life-ring' => 'life ring' ),
					array( 'fal fa-light-ceiling' => 'light ceiling' ),
					array( 'fal fa-light-switch-off' => 'light switch off' ),
					array( 'fal fa-light-switch-on' => 'light switch on' ),
					array( 'fal fa-light-switch' => 'light switch' ),
					array( 'fal fa-lightbulb-dollar' => 'lightbulb dollar' ),
					array( 'fal fa-lightbulb-exclamation' => 'lightbulb exclamation' ),
					array( 'fal fa-lightbulb-on' => 'lightbulb on' ),
					array( 'fal fa-lightbulb-slash' => 'lightbulb slash' ),
					array( 'fal fa-lightbulb' => 'lightbulb' ),
					array( 'fal fa-lights-holiday' => 'lights holiday' ),
					array( 'fal fa-line-columns' => 'line columns' ),
					array( 'fal fa-line-height' => 'line height' ),
					array( 'fal fa-link' => 'link' ),
					array( 'fal fa-lips' => 'lips' ),
					array( 'fal fa-lira-sign' => 'lira sign' ),
					array( 'fal fa-list-alt' => 'list alt' ),
					array( 'fal fa-list-music' => 'list music' ),
					array( 'fal fa-list-ol' => 'list ol' ),
					array( 'fal fa-list-ul' => 'list ul' ),
					array( 'fal fa-list' => 'list' ),
					array( 'fal fa-location-arrow' => 'location arrow' ),
					array( 'fal fa-location-circle' => 'location circle' ),
					array( 'fal fa-location-slash' => 'location slash' ),
					array( 'fal fa-location' => 'location' ),
					array( 'fal fa-lock-alt' => 'lock alt' ),
					array( 'fal fa-lock-open-alt' => 'lock open alt' ),
					array( 'fal fa-lock-open' => 'lock open' ),
					array( 'fal fa-lock' => 'lock' ),
					array( 'fal fa-long-arrow-alt-down' => 'long arrow alt down' ),
					array( 'fal fa-long-arrow-alt-left' => 'long arrow alt left' ),
					array( 'fal fa-long-arrow-alt-right' => 'long arrow alt right' ),
					array( 'fal fa-long-arrow-alt-up' => 'long arrow alt up' ),
					array( 'fal fa-long-arrow-down' => 'long arrow down' ),
					array( 'fal fa-long-arrow-left' => 'long arrow left' ),
					array( 'fal fa-long-arrow-right' => 'long arrow right' ),
					array( 'fal fa-long-arrow-up' => 'long arrow up' ),
					array( 'fal fa-loveseat' => 'loveseat' ),
					array( 'fal fa-low-vision' => 'low vision' ),
					array( 'fal fa-luchador' => 'luchador' ),
					array( 'fal fa-luggage-cart' => 'luggage cart' ),
					array( 'fal fa-lungs-virus' => 'lungs virus' ),
					array( 'fal fa-lungs' => 'lungs' ),
					array( 'fal fa-mace' => 'mace' ),
					array( 'fal fa-magic' => 'magic' ),
					array( 'fal fa-magnet' => 'magnet' ),
					array( 'fal fa-mail-bulk' => 'mail bulk' ),
					array( 'fal fa-mailbox' => 'mailbox' ),
					array( 'fal fa-male' => 'male' ),
					array( 'fal fa-mandolin' => 'mandolin' ),
					array( 'fal fa-map-marked-alt' => 'map marked alt' ),
					array( 'fal fa-map-marked' => 'map marked' ),
					array( 'fal fa-map-marker-alt-slash' => 'map marker alt slash' ),
					array( 'fal fa-map-marker-alt' => 'map marker alt' ),
					array( 'fal fa-map-marker-check' => 'map marker check' ),
					array( 'fal fa-map-marker-edit' => 'map marker edit' ),
					array( 'fal fa-map-marker-exclamation' => 'map marker exclamation' ),
					array( 'fal fa-map-marker-minus' => 'map marker minus' ),
					array( 'fal fa-map-marker-plus' => 'map marker plus' ),
					array( 'fal fa-map-marker-question' => 'map marker question' ),
					array( 'fal fa-map-marker-slash' => 'map marker slash' ),
					array( 'fal fa-map-marker-smile' => 'map marker smile' ),
					array( 'fal fa-map-marker-times' => 'map marker times' ),
					array( 'fal fa-map-marker' => 'map marker' ),
					array( 'fal fa-map-pin' => 'map pin' ),
					array( 'fal fa-map-signs' => 'map signs' ),
					array( 'fal fa-map' => 'map' ),
					array( 'fal fa-marker' => 'marker' ),
					array( 'fal fa-mars-double' => 'mars double' ),
					array( 'fal fa-mars-stroke-h' => 'mars stroke h' ),
					array( 'fal fa-mars-stroke-v' => 'mars stroke v' ),
					array( 'fal fa-mars-stroke' => 'mars stroke' ),
					array( 'fal fa-mars' => 'mars' ),
					array( 'fal fa-mask' => 'mask' ),
					array( 'fal fa-meat' => 'meat' ),
					array( 'fal fa-medal' => 'medal' ),
					array( 'fal fa-medkit' => 'medkit' ),
					array( 'fal fa-megaphone' => 'megaphone' ),
					array( 'fal fa-meh-blank' => 'meh blank' ),
					array( 'fal fa-meh-rolling-eyes' => 'meh rolling eyes' ),
					array( 'fal fa-meh' => 'meh' ),
					array( 'fal fa-memory' => 'memory' ),
					array( 'fal fa-menorah' => 'menorah' ),
					array( 'fal fa-mercury' => 'mercury' ),
					array( 'fal fa-meteor' => 'meteor' ),
					array( 'fal fa-microchip' => 'microchip' ),
					array( 'fal fa-microphone-alt-slash' => 'microphone alt slash' ),
					array( 'fal fa-microphone-alt' => 'microphone alt' ),
					array( 'fal fa-microphone-slash' => 'microphone slash' ),
					array( 'fal fa-microphone-stand' => 'microphone stand' ),
					array( 'fal fa-microphone' => 'microphone' ),
					array( 'fal fa-microscope' => 'microscope' ),
					array( 'fal fa-microwave' => 'microwave' ),
					array( 'fal fa-mind-share' => 'mind share' ),
					array( 'fal fa-minus-circle' => 'minus circle' ),
					array( 'fal fa-minus-hexagon' => 'minus hexagon' ),
					array( 'fal fa-minus-octagon' => 'minus octagon' ),
					array( 'fal fa-minus-square' => 'minus square' ),
					array( 'fal fa-minus' => 'minus' ),
					array( 'fal fa-mistletoe' => 'mistletoe' ),
					array( 'fal fa-mitten' => 'mitten' ),
					array( 'fal fa-mobile-alt' => 'mobile alt' ),
					array( 'fal fa-mobile-android-alt' => 'mobile android alt' ),
					array( 'fal fa-mobile-android' => 'mobile android' ),
					array( 'fal fa-mobile' => 'mobile' ),
					array( 'fal fa-money-bill-alt' => 'money bill alt' ),
					array( 'fal fa-money-bill-wave-alt' => 'money bill wave alt' ),
					array( 'fal fa-money-bill-wave' => 'money bill wave' ),
					array( 'fal fa-money-bill' => 'money bill' ),
					array( 'fal fa-money-check-alt' => 'money check alt' ),
					array( 'fal fa-money-check-edit-alt' => 'money check edit alt' ),
					array( 'fal fa-money-check-edit' => 'money check edit' ),
					array( 'fal fa-money-check' => 'money check' ),
					array( 'fal fa-monitor-heart-rate' => 'monitor heart rate' ),
					array( 'fal fa-monkey' => 'monkey' ),
					array( 'fal fa-monument' => 'monument' ),
					array( 'fal fa-moon-cloud' => 'moon cloud' ),
					array( 'fal fa-moon-stars' => 'moon stars' ),
					array( 'fal fa-moon' => 'moon' ),
					array( 'fal fa-mortar-pestle' => 'mortar pestle' ),
					array( 'fal fa-mosque' => 'mosque' ),
					array( 'fal fa-motorcycle' => 'motorcycle' ),
					array( 'fal fa-mountain' => 'mountain' ),
					array( 'fal fa-mountains' => 'mountains' ),
					array( 'fal fa-mouse-alt' => 'mouse alt' ),
					array( 'fal fa-mouse-pointer' => 'mouse pointer' ),
					array( 'fal fa-mouse' => 'mouse' ),
					array( 'fal fa-mp3-player' => 'mp3 player' ),
					array( 'fal fa-mug-hot' => 'mug hot' ),
					array( 'fal fa-mug-marshmallows' => 'mug marshmallows' ),
					array( 'fal fa-mug-tea' => 'mug tea' ),
					array( 'fal fa-mug' => 'mug' ),
					array( 'fal fa-music-alt-slash' => 'music alt slash' ),
					array( 'fal fa-music-alt' => 'music alt' ),
					array( 'fal fa-music-slash' => 'music slash' ),
					array( 'fal fa-music' => 'music' ),
					array( 'fal fa-narwhal' => 'narwhal' ),
					array( 'fal fa-network-wired' => 'network wired' ),
					array( 'fal fa-neuter' => 'neuter' ),
					array( 'fal fa-newspaper' => 'newspaper' ),
					array( 'fal fa-not-equal' => 'not equal' ),
					array( 'fal fa-notes-medical' => 'notes medical' ),
					array( 'fal fa-object-group' => 'object group' ),
					array( 'fal fa-object-ungroup' => 'object ungroup' ),
					array( 'fal fa-octagon' => 'octagon' ),
					array( 'fal fa-oil-can' => 'oil can' ),
					array( 'fal fa-oil-temp' => 'oil temp' ),
					array( 'fal fa-om' => 'om' ),
					array( 'fal fa-omega' => 'omega' ),
					array( 'fal fa-ornament' => 'ornament' ),
					array( 'fal fa-otter' => 'otter' ),
					array( 'fal fa-outdent' => 'outdent' ),
					array( 'fal fa-outlet' => 'outlet' ),
					array( 'fal fa-oven' => 'oven' ),
					array( 'fal fa-overline' => 'overline' ),
					array( 'fal fa-page-break' => 'page break' ),
					array( 'fal fa-pager' => 'pager' ),
					array( 'fal fa-paint-brush-alt' => 'paint brush alt' ),
					array( 'fal fa-paint-brush' => 'paint brush' ),
					array( 'fal fa-paint-roller' => 'paint roller' ),
					array( 'fal fa-palette' => 'palette' ),
					array( 'fal fa-pallet-alt' => 'pallet alt' ),
					array( 'fal fa-pallet' => 'pallet' ),
					array( 'fal fa-paper-plane' => 'paper plane' ),
					array( 'fal fa-paperclip' => 'paperclip' ),
					array( 'fal fa-parachute-box' => 'parachute box' ),
					array( 'fal fa-paragraph-rtl' => 'paragraph rtl' ),
					array( 'fal fa-paragraph' => 'paragraph' ),
					array( 'fal fa-parking-circle-slash' => 'parking circle slash' ),
					array( 'fal fa-parking-circle' => 'parking circle' ),
					array( 'fal fa-parking-slash' => 'parking slash' ),
					array( 'fal fa-parking' => 'parking' ),
					array( 'fal fa-passport' => 'passport' ),
					array( 'fal fa-pastafarianism' => 'pastafarianism' ),
					array( 'fal fa-paste' => 'paste' ),
					array( 'fal fa-pause-circle' => 'pause circle' ),
					array( 'fal fa-pause' => 'pause' ),
					array( 'fal fa-paw-alt' => 'paw alt' ),
					array( 'fal fa-paw-claws' => 'paw claws' ),
					array( 'fal fa-paw' => 'paw' ),
					array( 'fal fa-peace' => 'peace' ),
					array( 'fal fa-pegasus' => 'pegasus' ),
					array( 'fal fa-pen-alt' => 'pen alt' ),
					array( 'fal fa-pen-fancy' => 'pen fancy' ),
					array( 'fal fa-pen-nib' => 'pen nib' ),
					array( 'fal fa-pen-square' => 'pen square' ),
					array( 'fal fa-pen' => 'pen' ),
					array( 'fal fa-pencil-alt' => 'pencil alt' ),
					array( 'fal fa-pencil-paintbrush' => 'pencil paintbrush' ),
					array( 'fal fa-pencil-ruler' => 'pencil ruler' ),
					array( 'fal fa-pencil' => 'pencil' ),
					array( 'fal fa-pennant' => 'pennant' ),
					array( 'fal fa-people-arrows' => 'people arrows' ),
					array( 'fal fa-people-carry' => 'people carry' ),
					array( 'fal fa-pepper-hot' => 'pepper hot' ),
					array( 'fal fa-percent' => 'percent' ),
					array( 'fal fa-percentage' => 'percentage' ),
					array( 'fal fa-person-booth' => 'person booth' ),
					array( 'fal fa-person-carry' => 'person carry' ),
					array( 'fal fa-person-dolly-empty' => 'person dolly empty' ),
					array( 'fal fa-person-dolly' => 'person dolly' ),
					array( 'fal fa-person-sign' => 'person sign' ),
					array( 'fal fa-phone-alt' => 'phone alt' ),
					array( 'fal fa-phone-laptop' => 'phone laptop' ),
					array( 'fal fa-phone-office' => 'phone office' ),
					array( 'fal fa-phone-plus' => 'phone plus' ),
					array( 'fal fa-phone-rotary' => 'phone rotary' ),
					array( 'fal fa-phone-slash' => 'phone slash' ),
					array( 'fal fa-phone-square-alt' => 'phone square alt' ),
					array( 'fal fa-phone-square' => 'phone square' ),
					array( 'fal fa-phone-volume' => 'phone volume' ),
					array( 'fal fa-phone' => 'phone' ),
					array( 'fal fa-photo-video' => 'photo video' ),
					array( 'fal fa-pi' => 'pi' ),
					array( 'fal fa-piano-keyboard' => 'piano keyboard' ),
					array( 'fal fa-piano' => 'piano' ),
					array( 'fal fa-pie' => 'pie' ),
					array( 'fal fa-pig' => 'pig' ),
					array( 'fal fa-piggy-bank' => 'piggy bank' ),
					array( 'fal fa-pills' => 'pills' ),
					array( 'fal fa-pizza-slice' => 'pizza slice' ),
					array( 'fal fa-pizza' => 'pizza' ),
					array( 'fal fa-place-of-worship' => 'place of worship' ),
					array( 'fal fa-plane-alt' => 'plane alt' ),
					array( 'fal fa-plane-arrival' => 'plane arrival' ),
					array( 'fal fa-plane-departure' => 'plane departure' ),
					array( 'fal fa-plane-slash' => 'plane slash' ),
					array( 'fal fa-plane' => 'plane' ),
					array( 'fal fa-planet-moon' => 'planet moon' ),
					array( 'fal fa-planet-ringed' => 'planet ringed' ),
					array( 'fal fa-play-circle' => 'play circle' ),
					array( 'fal fa-play' => 'play' ),
					array( 'fal fa-plug' => 'plug' ),
					array( 'fal fa-plus-circle' => 'plus circle' ),
					array( 'fal fa-plus-hexagon' => 'plus hexagon' ),
					array( 'fal fa-plus-octagon' => 'plus octagon' ),
					array( 'fal fa-plus-square' => 'plus square' ),
					array( 'fal fa-plus' => 'plus' ),
					array( 'fal fa-podcast' => 'podcast' ),
					array( 'fal fa-podium-star' => 'podium star' ),
					array( 'fal fa-podium' => 'podium' ),
					array( 'fal fa-police-box' => 'police box' ),
					array( 'fal fa-poll-h' => 'poll h' ),
					array( 'fal fa-poll-people' => 'poll people' ),
					array( 'fal fa-poll' => 'poll' ),
					array( 'fal fa-poo-storm' => 'poo storm' ),
					array( 'fal fa-poo' => 'poo' ),
					array( 'fal fa-poop' => 'poop' ),
					array( 'fal fa-popcorn' => 'popcorn' ),
					array( 'fal fa-portal-enter' => 'portal enter' ),
					array( 'fal fa-portal-exit' => 'portal exit' ),
					array( 'fal fa-portrait' => 'portrait' ),
					array( 'fal fa-pound-sign' => 'pound sign' ),
					array( 'fal fa-power-off' => 'power off' ),
					array( 'fal fa-pray' => 'pray' ),
					array( 'fal fa-praying-hands' => 'praying hands' ),
					array( 'fal fa-prescription-bottle-alt' => 'prescription bottle alt' ),
					array( 'fal fa-prescription-bottle' => 'prescription bottle' ),
					array( 'fal fa-prescription' => 'prescription' ),
					array( 'fal fa-presentation' => 'presentation' ),
					array( 'fal fa-print-search' => 'print search' ),
					array( 'fal fa-print-slash' => 'print slash' ),
					array( 'fal fa-print' => 'print' ),
					array( 'fal fa-procedures' => 'procedures' ),
					array( 'fal fa-project-diagram' => 'project diagram' ),
					array( 'fal fa-projector' => 'projector' ),
					array( 'fal fa-pump-medical' => 'pump medical' ),
					array( 'fal fa-pump-soap' => 'pump soap' ),
					array( 'fal fa-pumpkin' => 'pumpkin' ),
					array( 'fal fa-puzzle-piece' => 'puzzle piece' ),
					array( 'fal fa-qrcode' => 'qrcode' ),
					array( 'fal fa-question-circle' => 'question circle' ),
					array( 'fal fa-question-square' => 'question square' ),
					array( 'fal fa-question' => 'question' ),
					array( 'fal fa-quidditch' => 'quidditch' ),
					array( 'fal fa-quote-left' => 'quote left' ),
					array( 'fal fa-quote-right' => 'quote right' ),
					array( 'fal fa-quran' => 'quran' ),
					array( 'fal fa-rabbit-fast' => 'rabbit fast' ),
					array( 'fal fa-rabbit' => 'rabbit' ),
					array( 'fal fa-racquet' => 'racquet' ),
					array( 'fal fa-radar' => 'radar' ),
					array( 'fal fa-radiation-alt' => 'radiation alt' ),
					array( 'fal fa-radiation' => 'radiation' ),
					array( 'fal fa-radio-alt' => 'radio alt' ),
					array( 'fal fa-radio' => 'radio' ),
					array( 'fal fa-rainbow' => 'rainbow' ),
					array( 'fal fa-raindrops' => 'raindrops' ),
					array( 'fal fa-ram' => 'ram' ),
					array( 'fal fa-ramp-loading' => 'ramp loading' ),
					array( 'fal fa-random' => 'random' ),
					array( 'fal fa-raygun' => 'raygun' ),
					array( 'fal fa-receipt' => 'receipt' ),
					array( 'fal fa-record-vinyl' => 'record vinyl' ),
					array( 'fal fa-rectangle-landscape' => 'rectangle landscape' ),
					array( 'fal fa-rectangle-portrait' => 'rectangle portrait' ),
					array( 'fal fa-rectangle-wide' => 'rectangle wide' ),
					array( 'fal fa-recycle' => 'recycle' ),
					array( 'fal fa-redo-alt' => 'redo alt' ),
					array( 'fal fa-redo' => 'redo' ),
					array( 'fal fa-refrigerator' => 'refrigerator' ),
					array( 'fal fa-registered' => 'registered' ),
					array( 'fal fa-remove-format' => 'remove format' ),
					array( 'fal fa-repeat-1-alt' => 'repeat 1 alt' ),
					array( 'fal fa-repeat-1' => 'repeat 1' ),
					array( 'fal fa-repeat-alt' => 'repeat alt' ),
					array( 'fal fa-repeat' => 'repeat' ),
					array( 'fal fa-reply-all' => 'reply all' ),
					array( 'fal fa-reply' => 'reply' ),
					array( 'fal fa-republican' => 'republican' ),
					array( 'fal fa-restroom' => 'restroom' ),
					array( 'fal fa-retweet-alt' => 'retweet alt' ),
					array( 'fal fa-retweet' => 'retweet' ),
					array( 'fal fa-ribbon' => 'ribbon' ),
					array( 'fal fa-ring' => 'ring' ),
					array( 'fal fa-rings-wedding' => 'rings wedding' ),
					array( 'fal fa-road' => 'road' ),
					array( 'fal fa-robot' => 'robot' ),
					array( 'fal fa-rocket-launch' => 'rocket launch' ),
					array( 'fal fa-rocket' => 'rocket' ),
					array( 'fal fa-route-highway' => 'route highway' ),
					array( 'fal fa-route-interstate' => 'route interstate' ),
					array( 'fal fa-route' => 'route' ),
					array( 'fal fa-router' => 'router' ),
					array( 'fal fa-rss-square' => 'rss square' ),
					array( 'fal fa-rss' => 'rss' ),
					array( 'fal fa-ruble-sign' => 'ruble sign' ),
					array( 'fal fa-ruler-combined' => 'ruler combined' ),
					array( 'fal fa-ruler-horizontal' => 'ruler horizontal' ),
					array( 'fal fa-ruler-triangle' => 'ruler triangle' ),
					array( 'fal fa-ruler-vertical' => 'ruler vertical' ),
					array( 'fal fa-ruler' => 'ruler' ),
					array( 'fal fa-running' => 'running' ),
					array( 'fal fa-rupee-sign' => 'rupee sign' ),
					array( 'fal fa-rv' => 'rv' ),
					array( 'fal fa-sack-dollar' => 'sack dollar' ),
					array( 'fal fa-sack' => 'sack' ),
					array( 'fal fa-sad-cry' => 'sad cry' ),
					array( 'fal fa-sad-tear' => 'sad tear' ),
					array( 'fal fa-salad' => 'salad' ),
					array( 'fal fa-sandwich' => 'sandwich' ),
					array( 'fal fa-satellite-dish' => 'satellite dish' ),
					array( 'fal fa-satellite' => 'satellite' ),
					array( 'fal fa-sausage' => 'sausage' ),
					array( 'fal fa-save' => 'save' ),
					array( 'fal fa-sax-hot' => 'sax hot' ),
					array( 'fal fa-saxophone' => 'saxophone' ),
					array( 'fal fa-scalpel-path' => 'scalpel path' ),
					array( 'fal fa-scalpel' => 'scalpel' ),
					array( 'fal fa-scanner-image' => 'scanner image' ),
					array( 'fal fa-scanner-keyboard' => 'scanner keyboard' ),
					array( 'fal fa-scanner-touchscreen' => 'scanner touchscreen' ),
					array( 'fal fa-scanner' => 'scanner' ),
					array( 'fal fa-scarecrow' => 'scarecrow' ),
					array( 'fal fa-scarf' => 'scarf' ),
					array( 'fal fa-school' => 'school' ),
					array( 'fal fa-screwdriver' => 'screwdriver' ),
					array( 'fal fa-scroll-old' => 'scroll old' ),
					array( 'fal fa-scroll' => 'scroll' ),
					array( 'fal fa-scrubber' => 'scrubber' ),
					array( 'fal fa-scythe' => 'scythe' ),
					array( 'fal fa-sd-card' => 'sd card' ),
					array( 'fal fa-search-dollar' => 'search dollar' ),
					array( 'fal fa-search-location' => 'search location' ),
					array( 'fal fa-search-minus' => 'search minus' ),
					array( 'fal fa-search-plus' => 'search plus' ),
					array( 'fal fa-search' => 'search' ),
					array( 'fal fa-seedling' => 'seedling' ),
					array( 'fal fa-send-back' => 'send back' ),
					array( 'fal fa-send-backward' => 'send backward' ),
					array( 'fal fa-sensor-alert' => 'sensor alert' ),
					array( 'fal fa-sensor-fire' => 'sensor fire' ),
					array( 'fal fa-sensor-on' => 'sensor on' ),
					array( 'fal fa-sensor-smoke' => 'sensor smoke' ),
					array( 'fal fa-sensor' => 'sensor' ),
					array( 'fal fa-server' => 'server' ),
					array( 'fal fa-shapes' => 'shapes' ),
					array( 'fal fa-share-all' => 'share all' ),
					array( 'fal fa-share-alt-square' => 'share alt square' ),
					array( 'fal fa-share-alt' => 'share alt' ),
					array( 'fal fa-share-square' => 'share square' ),
					array( 'fal fa-share' => 'share' ),
					array( 'fal fa-sheep' => 'sheep' ),
					array( 'fal fa-shekel-sign' => 'shekel sign' ),
					array( 'fal fa-shield-alt' => 'shield alt' ),
					array( 'fal fa-shield-check' => 'shield check' ),
					array( 'fal fa-shield-cross' => 'shield cross' ),
					array( 'fal fa-shield-virus' => 'shield virus' ),
					array( 'fal fa-shield' => 'shield' ),
					array( 'fal fa-ship' => 'ship' ),
					array( 'fal fa-shipping-fast' => 'shipping fast' ),
					array( 'fal fa-shipping-timed' => 'shipping timed' ),
					array( 'fal fa-shish-kebab' => 'shish kebab' ),
					array( 'fal fa-shoe-prints' => 'shoe prints' ),
					array( 'fal fa-shopping-bag' => 'shopping bag' ),
					array( 'fal fa-shopping-basket' => 'shopping basket' ),
					array( 'fal fa-shopping-cart' => 'shopping cart' ),
					array( 'fal fa-shovel-snow' => 'shovel snow' ),
					array( 'fal fa-shovel' => 'shovel' ),
					array( 'fal fa-shower' => 'shower' ),
					array( 'fal fa-shredder' => 'shredder' ),
					array( 'fal fa-shuttle-van' => 'shuttle van' ),
					array( 'fal fa-shuttlecock' => 'shuttlecock' ),
					array( 'fal fa-sickle' => 'sickle' ),
					array( 'fal fa-sigma' => 'sigma' ),
					array( 'fal fa-sign-in-alt' => 'sign in alt' ),
					array( 'fal fa-sign-in' => 'sign in' ),
					array( 'fal fa-sign-language' => 'sign language' ),
					array( 'fal fa-sign-out-alt' => 'sign out alt' ),
					array( 'fal fa-sign-out' => 'sign out' ),
					array( 'fal fa-sign' => 'sign' ),
					array( 'fal fa-signal-1' => 'signal 1' ),
					array( 'fal fa-signal-2' => 'signal 2' ),
					array( 'fal fa-signal-3' => 'signal 3' ),
					array( 'fal fa-signal-4' => 'signal 4' ),
					array( 'fal fa-signal-alt-1' => 'signal alt 1' ),
					array( 'fal fa-signal-alt-2' => 'signal alt 2' ),
					array( 'fal fa-signal-alt-3' => 'signal alt 3' ),
					array( 'fal fa-signal-alt-slash' => 'signal alt slash' ),
					array( 'fal fa-signal-alt' => 'signal alt' ),
					array( 'fal fa-signal-slash' => 'signal slash' ),
					array( 'fal fa-signal-stream' => 'signal stream' ),
					array( 'fal fa-signal' => 'signal' ),
					array( 'fal fa-signature' => 'signature' ),
					array( 'fal fa-sim-card' => 'sim card' ),
					array( 'fal fa-sink' => 'sink' ),
					array( 'fal fa-siren-on' => 'siren on' ),
					array( 'fal fa-siren' => 'siren' ),
					array( 'fal fa-sitemap' => 'sitemap' ),
					array( 'fal fa-skating' => 'skating' ),
					array( 'fal fa-skeleton' => 'skeleton' ),
					array( 'fal fa-ski-jump' => 'ski jump' ),
					array( 'fal fa-ski-lift' => 'ski lift' ),
					array( 'fal fa-skiing-nordic' => 'skiing nordic' ),
					array( 'fal fa-skiing' => 'skiing' ),
					array( 'fal fa-skull-cow' => 'skull cow' ),
					array( 'fal fa-skull-crossbones' => 'skull crossbones' ),
					array( 'fal fa-skull' => 'skull' ),
					array( 'fal fa-slash' => 'slash' ),
					array( 'fal fa-sledding' => 'sledding' ),
					array( 'fal fa-sleigh' => 'sleigh' ),
					array( 'fal fa-sliders-h-square' => 'sliders h square' ),
					array( 'fal fa-sliders-h' => 'sliders h' ),
					array( 'fal fa-sliders-v-square' => 'sliders v square' ),
					array( 'fal fa-sliders-v' => 'sliders v' ),
					array( 'fal fa-smile-beam' => 'smile beam' ),
					array( 'fal fa-smile-plus' => 'smile plus' ),
					array( 'fal fa-smile-wink' => 'smile wink' ),
					array( 'fal fa-smile' => 'smile' ),
					array( 'fal fa-smog' => 'smog' ),
					array( 'fal fa-smoke' => 'smoke' ),
					array( 'fal fa-smoking-ban' => 'smoking ban' ),
					array( 'fal fa-smoking' => 'smoking' ),
					array( 'fal fa-sms' => 'sms' ),
					array( 'fal fa-snake' => 'snake' ),
					array( 'fal fa-snooze' => 'snooze' ),
					array( 'fal fa-snow-blowing' => 'snow blowing' ),
					array( 'fal fa-snowboarding' => 'snowboarding' ),
					array( 'fal fa-snowflake' => 'snowflake' ),
					array( 'fal fa-snowflakes' => 'snowflakes' ),
					array( 'fal fa-snowman' => 'snowman' ),
					array( 'fal fa-snowmobile' => 'snowmobile' ),
					array( 'fal fa-snowplow' => 'snowplow' ),
					array( 'fal fa-soap' => 'soap' ),
					array( 'fal fa-socks' => 'socks' ),
					array( 'fal fa-solar-panel' => 'solar panel' ),
					array( 'fal fa-solar-system' => 'solar system' ),
					array( 'fal fa-sort-alpha-down-alt' => 'sort alpha down alt' ),
					array( 'fal fa-sort-alpha-down' => 'sort alpha down' ),
					array( 'fal fa-sort-alpha-up-alt' => 'sort alpha up alt' ),
					array( 'fal fa-sort-alpha-up' => 'sort alpha up' ),
					array( 'fal fa-sort-alt' => 'sort alt' ),
					array( 'fal fa-sort-amount-down-alt' => 'sort amount down alt' ),
					array( 'fal fa-sort-amount-down' => 'sort amount down' ),
					array( 'fal fa-sort-amount-up-alt' => 'sort amount up alt' ),
					array( 'fal fa-sort-amount-up' => 'sort amount up' ),
					array( 'fal fa-sort-circle-down' => 'sort circle down' ),
					array( 'fal fa-sort-circle-up' => 'sort circle up' ),
					array( 'fal fa-sort-circle' => 'sort circle' ),
					array( 'fal fa-sort-down' => 'sort down' ),
					array( 'fal fa-sort-numeric-down-alt' => 'sort numeric down alt' ),
					array( 'fal fa-sort-numeric-down' => 'sort numeric down' ),
					array( 'fal fa-sort-numeric-up-alt' => 'sort numeric up alt' ),
					array( 'fal fa-sort-numeric-up' => 'sort numeric up' ),
					array( 'fal fa-sort-shapes-down-alt' => 'sort shapes down alt' ),
					array( 'fal fa-sort-shapes-down' => 'sort shapes down' ),
					array( 'fal fa-sort-shapes-up-alt' => 'sort shapes up alt' ),
					array( 'fal fa-sort-shapes-up' => 'sort shapes up' ),
					array( 'fal fa-sort-size-down-alt' => 'sort size down alt' ),
					array( 'fal fa-sort-size-down' => 'sort size down' ),
					array( 'fal fa-sort-size-up-alt' => 'sort size up alt' ),
					array( 'fal fa-sort-size-up' => 'sort size up' ),
					array( 'fal fa-sort-up' => 'sort up' ),
					array( 'fal fa-sort' => 'sort' ),
					array( 'fal fa-soup' => 'soup' ),
					array( 'fal fa-spa' => 'spa' ),
					array( 'fal fa-space-shuttle' => 'space shuttle' ),
					array( 'fal fa-space-station-moon-alt' => 'space station moon alt' ),
					array( 'fal fa-space-station-moon' => 'space station moon' ),
					array( 'fal fa-spade' => 'spade' ),
					array( 'fal fa-sparkles' => 'sparkles' ),
					array( 'fal fa-speaker' => 'speaker' ),
					array( 'fal fa-speakers' => 'speakers' ),
					array( 'fal fa-spell-check' => 'spell check' ),
					array( 'fal fa-spider-black-widow' => 'spider black widow' ),
					array( 'fal fa-spider-web' => 'spider web' ),
					array( 'fal fa-spider' => 'spider' ),
					array( 'fal fa-spinner-third' => 'spinner third' ),
					array( 'fal fa-spinner' => 'spinner' ),
					array( 'fal fa-splotch' => 'splotch' ),
					array( 'fal fa-spray-can' => 'spray can' ),
					array( 'fal fa-sprinkler' => 'sprinkler' ),
					array( 'fal fa-square-full' => 'square full' ),
					array( 'fal fa-square-root-alt' => 'square root alt' ),
					array( 'fal fa-square-root' => 'square root' ),
					array( 'fal fa-square' => 'square' ),
					array( 'fal fa-squirrel' => 'squirrel' ),
					array( 'fal fa-staff' => 'staff' ),
					array( 'fal fa-stamp' => 'stamp' ),
					array( 'fal fa-star-and-crescent' => 'star and crescent' ),
					array( 'fal fa-star-christmas' => 'star christmas' ),
					array( 'fal fa-star-exclamation' => 'star exclamation' ),
					array( 'fal fa-star-half-alt' => 'star half alt' ),
					array( 'fal fa-star-half' => 'star half' ),
					array( 'fal fa-star-of-david' => 'star of david' ),
					array( 'fal fa-star-of-life' => 'star of life' ),
					array( 'fal fa-star-shooting' => 'star shooting' ),
					array( 'fal fa-star' => 'star' ),
					array( 'fal fa-starfighter-alt' => 'starfighter alt' ),
					array( 'fal fa-starfighter' => 'starfighter' ),
					array( 'fal fa-stars' => 'stars' ),
					array( 'fal fa-starship-freighter' => 'starship freighter' ),
					array( 'fal fa-starship' => 'starship' ),
					array( 'fal fa-steak' => 'steak' ),
					array( 'fal fa-steering-wheel' => 'steering wheel' ),
					array( 'fal fa-step-backward' => 'step backward' ),
					array( 'fal fa-step-forward' => 'step forward' ),
					array( 'fal fa-stethoscope' => 'stethoscope' ),
					array( 'fal fa-sticky-note' => 'sticky note' ),
					array( 'fal fa-stocking' => 'stocking' ),
					array( 'fal fa-stomach' => 'stomach' ),
					array( 'fal fa-stop-circle' => 'stop circle' ),
					array( 'fal fa-stop' => 'stop' ),
					array( 'fal fa-stopwatch-20' => 'stopwatch 20' ),
					array( 'fal fa-stopwatch' => 'stopwatch' ),
					array( 'fal fa-store-alt-slash' => 'store alt slash' ),
					array( 'fal fa-store-alt' => 'store alt' ),
					array( 'fal fa-store-slash' => 'store slash' ),
					array( 'fal fa-store' => 'store' ),
					array( 'fal fa-stream' => 'stream' ),
					array( 'fal fa-street-view' => 'street view' ),
					array( 'fal fa-stretcher' => 'stretcher' ),
					array( 'fal fa-strikethrough' => 'strikethrough' ),
					array( 'fal fa-stroopwafel' => 'stroopwafel' ),
					array( 'fal fa-subscript' => 'subscript' ),
					array( 'fal fa-subway' => 'subway' ),
					array( 'fal fa-suitcase-rolling' => 'suitcase rolling' ),
					array( 'fal fa-suitcase' => 'suitcase' ),
					array( 'fal fa-sun-cloud' => 'sun cloud' ),
					array( 'fal fa-sun-dust' => 'sun dust' ),
					array( 'fal fa-sun-haze' => 'sun haze' ),
					array( 'fal fa-sun' => 'sun' ),
					array( 'fal fa-sunglasses' => 'sunglasses' ),
					array( 'fal fa-sunrise' => 'sunrise' ),
					array( 'fal fa-sunset' => 'sunset' ),
					array( 'fal fa-superscript' => 'superscript' ),
					array( 'fal fa-surprise' => 'surprise' ),
					array( 'fal fa-swatchbook' => 'swatchbook' ),
					array( 'fal fa-swimmer' => 'swimmer' ),
					array( 'fal fa-swimming-pool' => 'swimming pool' ),
					array( 'fal fa-sword-laser-alt' => 'sword laser alt' ),
					array( 'fal fa-sword-laser' => 'sword laser' ),
					array( 'fal fa-sword' => 'sword' ),
					array( 'fal fa-swords-laser' => 'swords laser' ),
					array( 'fal fa-swords' => 'swords' ),
					array( 'fal fa-synagogue' => 'synagogue' ),
					array( 'fal fa-sync-alt' => 'sync alt' ),
					array( 'fal fa-sync' => 'sync' ),
					array( 'fal fa-syringe' => 'syringe' ),
					array( 'fal fa-table-tennis' => 'table tennis' ),
					array( 'fal fa-table' => 'table' ),
					array( 'fal fa-tablet-alt' => 'tablet alt' ),
					array( 'fal fa-tablet-android-alt' => 'tablet android alt' ),
					array( 'fal fa-tablet-android' => 'tablet android' ),
					array( 'fal fa-tablet-rugged' => 'tablet rugged' ),
					array( 'fal fa-tablet' => 'tablet' ),
					array( 'fal fa-tablets' => 'tablets' ),
					array( 'fal fa-tachometer-alt-average' => 'tachometer alt average' ),
					array( 'fal fa-tachometer-alt-fast' => 'tachometer alt fast' ),
					array( 'fal fa-tachometer-alt-fastest' => 'tachometer alt fastest' ),
					array( 'fal fa-tachometer-alt-slow' => 'tachometer alt slow' ),
					array( 'fal fa-tachometer-alt-slowest' => 'tachometer alt slowest' ),
					array( 'fal fa-tachometer-alt' => 'tachometer alt' ),
					array( 'fal fa-tachometer-average' => 'tachometer average' ),
					array( 'fal fa-tachometer-fast' => 'tachometer fast' ),
					array( 'fal fa-tachometer-fastest' => 'tachometer fastest' ),
					array( 'fal fa-tachometer-slow' => 'tachometer slow' ),
					array( 'fal fa-tachometer-slowest' => 'tachometer slowest' ),
					array( 'fal fa-tachometer' => 'tachometer' ),
					array( 'fal fa-taco' => 'taco' ),
					array( 'fal fa-tag' => 'tag' ),
					array( 'fal fa-tags' => 'tags' ),
					array( 'fal fa-tally' => 'tally' ),
					array( 'fal fa-tanakh' => 'tanakh' ),
					array( 'fal fa-tape' => 'tape' ),
					array( 'fal fa-tasks-alt' => 'tasks alt' ),
					array( 'fal fa-tasks' => 'tasks' ),
					array( 'fal fa-taxi' => 'taxi' ),
					array( 'fal fa-teeth-open' => 'teeth open' ),
					array( 'fal fa-teeth' => 'teeth' ),
					array( 'fal fa-telescope' => 'telescope' ),
					array( 'fal fa-temperature-down' => 'temperature down' ),
					array( 'fal fa-temperature-frigid' => 'temperature frigid' ),
					array( 'fal fa-temperature-high' => 'temperature high' ),
					array( 'fal fa-temperature-hot' => 'temperature hot' ),
					array( 'fal fa-temperature-low' => 'temperature low' ),
					array( 'fal fa-temperature-up' => 'temperature up' ),
					array( 'fal fa-tenge' => 'tenge' ),
					array( 'fal fa-tennis-ball' => 'tennis ball' ),
					array( 'fal fa-terminal' => 'terminal' ),
					array( 'fal fa-text-height' => 'text height' ),
					array( 'fal fa-text-size' => 'text size' ),
					array( 'fal fa-text-width' => 'text width' ),
					array( 'fal fa-text' => 'text' ),
					array( 'fal fa-th-large' => 'th large' ),
					array( 'fal fa-th-list' => 'th list' ),
					array( 'fal fa-th' => 'th' ),
					array( 'fal fa-theater-masks' => 'theater masks' ),
					array( 'fal fa-thermometer-empty' => 'thermometer empty' ),
					array( 'fal fa-thermometer-full' => 'thermometer full' ),
					array( 'fal fa-thermometer-half' => 'thermometer half' ),
					array( 'fal fa-thermometer-quarter' => 'thermometer quarter' ),
					array( 'fal fa-thermometer-three-quarters' => 'thermometer three quarters' ),
					array( 'fal fa-thermometer' => 'thermometer' ),
					array( 'fal fa-theta' => 'theta' ),
					array( 'fal fa-thumbs-down' => 'thumbs down' ),
					array( 'fal fa-thumbs-up' => 'thumbs up' ),
					array( 'fal fa-thumbtack' => 'thumbtack' ),
					array( 'fal fa-thunderstorm-moon' => 'thunderstorm moon' ),
					array( 'fal fa-thunderstorm-sun' => 'thunderstorm sun' ),
					array( 'fal fa-thunderstorm' => 'thunderstorm' ),
					array( 'fal fa-ticket-alt' => 'ticket alt' ),
					array( 'fal fa-ticket' => 'ticket' ),
					array( 'fal fa-tilde' => 'tilde' ),
					array( 'fal fa-times-circle' => 'times circle' ),
					array( 'fal fa-times-hexagon' => 'times hexagon' ),
					array( 'fal fa-times-octagon' => 'times octagon' ),
					array( 'fal fa-times-square' => 'times square' ),
					array( 'fal fa-times' => 'times' ),
					array( 'fal fa-tint-slash' => 'tint slash' ),
					array( 'fal fa-tint' => 'tint' ),
					array( 'fal fa-tire-flat' => 'tire flat' ),
					array( 'fal fa-tire-pressure-warning' => 'tire pressure warning' ),
					array( 'fal fa-tire-rugged' => 'tire rugged' ),
					array( 'fal fa-tire' => 'tire' ),
					array( 'fal fa-tired' => 'tired' ),
					array( 'fal fa-toggle-off' => 'toggle off' ),
					array( 'fal fa-toggle-on' => 'toggle on' ),
					array( 'fal fa-toilet-paper-alt' => 'toilet paper alt' ),
					array( 'fal fa-toilet-paper-slash' => 'toilet paper slash' ),
					array( 'fal fa-toilet-paper' => 'toilet paper' ),
					array( 'fal fa-toilet' => 'toilet' ),
					array( 'fal fa-tombstone-alt' => 'tombstone alt' ),
					array( 'fal fa-tombstone' => 'tombstone' ),
					array( 'fal fa-toolbox' => 'toolbox' ),
					array( 'fal fa-tools' => 'tools' ),
					array( 'fal fa-tooth' => 'tooth' ),
					array( 'fal fa-toothbrush' => 'toothbrush' ),
					array( 'fal fa-torah' => 'torah' ),
					array( 'fal fa-torii-gate' => 'torii gate' ),
					array( 'fal fa-tornado' => 'tornado' ),
					array( 'fal fa-tractor' => 'tractor' ),
					array( 'fal fa-trademark' => 'trademark' ),
					array( 'fal fa-traffic-cone' => 'traffic cone' ),
					array( 'fal fa-traffic-light-go' => 'traffic light go' ),
					array( 'fal fa-traffic-light-slow' => 'traffic light slow' ),
					array( 'fal fa-traffic-light-stop' => 'traffic light stop' ),
					array( 'fal fa-traffic-light' => 'traffic light' ),
					array( 'fal fa-trailer' => 'trailer' ),
					array( 'fal fa-train' => 'train' ),
					array( 'fal fa-tram' => 'tram' ),
					array( 'fal fa-transgender-alt' => 'transgender alt' ),
					array( 'fal fa-transgender' => 'transgender' ),
					array( 'fal fa-transporter-1' => 'transporter 1' ),
					array( 'fal fa-transporter-2' => 'transporter 2' ),
					array( 'fal fa-transporter-3' => 'transporter 3' ),
					array( 'fal fa-transporter-empty' => 'transporter empty' ),
					array( 'fal fa-transporter' => 'transporter' ),
					array( 'fal fa-trash-alt' => 'trash alt' ),
					array( 'fal fa-trash-restore-alt' => 'trash restore alt' ),
					array( 'fal fa-trash-restore' => 'trash restore' ),
					array( 'fal fa-trash-undo-alt' => 'trash undo alt' ),
					array( 'fal fa-trash-undo' => 'trash undo' ),
					array( 'fal fa-trash' => 'trash' ),
					array( 'fal fa-treasure-chest' => 'treasure chest' ),
					array( 'fal fa-tree-alt' => 'tree alt' ),
					array( 'fal fa-tree-christmas' => 'tree christmas' ),
					array( 'fal fa-tree-decorated' => 'tree decorated' ),
					array( 'fal fa-tree-large' => 'tree large' ),
					array( 'fal fa-tree-palm' => 'tree palm' ),
					array( 'fal fa-tree' => 'tree' ),
					array( 'fal fa-trees' => 'trees' ),
					array( 'fal fa-triangle-music' => 'triangle music' ),
					array( 'fal fa-triangle' => 'triangle' ),
					array( 'fal fa-trophy-alt' => 'trophy alt' ),
					array( 'fal fa-trophy' => 'trophy' ),
					array( 'fal fa-truck-container' => 'truck container' ),
					array( 'fal fa-truck-couch' => 'truck couch' ),
					array( 'fal fa-truck-loading' => 'truck loading' ),
					array( 'fal fa-truck-monster' => 'truck monster' ),
					array( 'fal fa-truck-moving' => 'truck moving' ),
					array( 'fal fa-truck-pickup' => 'truck pickup' ),
					array( 'fal fa-truck-plow' => 'truck plow' ),
					array( 'fal fa-truck-ramp' => 'truck ramp' ),
					array( 'fal fa-truck' => 'truck' ),
					array( 'fal fa-trumpet' => 'trumpet' ),
					array( 'fal fa-tshirt' => 'tshirt' ),
					array( 'fal fa-tty' => 'tty' ),
					array( 'fal fa-turkey' => 'turkey' ),
					array( 'fal fa-turntable' => 'turntable' ),
					array( 'fal fa-turtle' => 'turtle' ),
					array( 'fal fa-tv-alt' => 'tv alt' ),
					array( 'fal fa-tv-music' => 'tv music' ),
					array( 'fal fa-tv-retro' => 'tv retro' ),
					array( 'fal fa-tv' => 'tv' ),
					array( 'fal fa-typewriter' => 'typewriter' ),
					array( 'fal fa-ufo-beam' => 'ufo beam' ),
					array( 'fal fa-ufo' => 'ufo' ),
					array( 'fal fa-umbrella-beach' => 'umbrella beach' ),
					array( 'fal fa-umbrella' => 'umbrella' ),
					array( 'fal fa-underline' => 'underline' ),
					array( 'fal fa-undo-alt' => 'undo alt' ),
					array( 'fal fa-undo' => 'undo' ),
					array( 'fal fa-unicorn' => 'unicorn' ),
					array( 'fal fa-union' => 'union' ),
					array( 'fal fa-universal-access' => 'universal access' ),
					array( 'fal fa-university' => 'university' ),
					array( 'fal fa-unlink' => 'unlink' ),
					array( 'fal fa-unlock-alt' => 'unlock alt' ),
					array( 'fal fa-unlock' => 'unlock' ),
					array( 'fal fa-upload' => 'upload' ),
					array( 'fal fa-usb-drive' => 'usb drive' ),
					array( 'fal fa-usd-circle' => 'usd circle' ),
					array( 'fal fa-usd-square' => 'usd square' ),
					array( 'fal fa-user-alien' => 'user alien' ),
					array( 'fal fa-user-alt-slash' => 'user alt slash' ),
					array( 'fal fa-user-alt' => 'user alt' ),
					array( 'fal fa-user-astronaut' => 'user astronaut' ),
					array( 'fal fa-user-chart' => 'user chart' ),
					array( 'fal fa-user-check' => 'user check' ),
					array( 'fal fa-user-circle' => 'user circle' ),
					array( 'fal fa-user-clock' => 'user clock' ),
					array( 'fal fa-user-cog' => 'user cog' ),
					array( 'fal fa-user-cowboy' => 'user cowboy' ),
					array( 'fal fa-user-crown' => 'user crown' ),
					array( 'fal fa-user-edit' => 'user edit' ),
					array( 'fal fa-user-friends' => 'user friends' ),
					array( 'fal fa-user-graduate' => 'user graduate' ),
					array( 'fal fa-user-hard-hat' => 'user hard hat' ),
					array( 'fal fa-user-headset' => 'user headset' ),
					array( 'fal fa-user-injured' => 'user injured' ),
					array( 'fal fa-user-lock' => 'user lock' ),
					array( 'fal fa-user-md-chat' => 'user md chat' ),
					array( 'fal fa-user-md' => 'user md' ),
					array( 'fal fa-user-minus' => 'user minus' ),
					array( 'fal fa-user-music' => 'user music' ),
					array( 'fal fa-user-ninja' => 'user ninja' ),
					array( 'fal fa-user-nurse' => 'user nurse' ),
					array( 'fal fa-user-plus' => 'user plus' ),
					array( 'fal fa-user-robot' => 'user robot' ),
					array( 'fal fa-user-secret' => 'user secret' ),
					array( 'fal fa-user-shield' => 'user shield' ),
					array( 'fal fa-user-slash' => 'user slash' ),
					array( 'fal fa-user-tag' => 'user tag' ),
					array( 'fal fa-user-tie' => 'user tie' ),
					array( 'fal fa-user-times' => 'user times' ),
					array( 'fal fa-user-unlock' => 'user unlock' ),
					array( 'fal fa-user-visor' => 'user visor' ),
					array( 'fal fa-user' => 'user' ),
					array( 'fal fa-users-class' => 'users class' ),
					array( 'fal fa-users-cog' => 'users cog' ),
					array( 'fal fa-users-crown' => 'users crown' ),
					array( 'fal fa-users-medical' => 'users medical' ),
					array( 'fal fa-users-slash' => 'users slash' ),
					array( 'fal fa-users' => 'users' ),
					array( 'fal fa-utensil-fork' => 'utensil fork' ),
					array( 'fal fa-utensil-knife' => 'utensil knife' ),
					array( 'fal fa-utensil-spoon' => 'utensil spoon' ),
					array( 'fal fa-utensils-alt' => 'utensils alt' ),
					array( 'fal fa-utensils' => 'utensils' ),
					array( 'fal fa-vacuum-robot' => 'vacuum robot' ),
					array( 'fal fa-vacuum' => 'vacuum' ),
					array( 'fal fa-value-absolute' => 'value absolute' ),
					array( 'fal fa-vector-square' => 'vector square' ),
					array( 'fal fa-venus-double' => 'venus double' ),
					array( 'fal fa-venus-mars' => 'venus mars' ),
					array( 'fal fa-venus' => 'venus' ),
					array( 'fal fa-vhs' => 'vhs' ),
					array( 'fal fa-vial' => 'vial' ),
					array( 'fal fa-vials' => 'vials' ),
					array( 'fal fa-video-plus' => 'video plus' ),
					array( 'fal fa-video-slash' => 'video slash' ),
					array( 'fal fa-video' => 'video' ),
					array( 'fal fa-vihara' => 'vihara' ),
					array( 'fal fa-violin' => 'violin' ),
					array( 'fal fa-virus-slash' => 'virus slash' ),
					array( 'fal fa-virus' => 'virus' ),
					array( 'fal fa-viruses' => 'viruses' ),
					array( 'fal fa-voicemail' => 'voicemail' ),
					array( 'fal fa-volcano' => 'volcano' ),
					array( 'fal fa-volleyball-ball' => 'volleyball ball' ),
					array( 'fal fa-volume-down' => 'volume down' ),
					array( 'fal fa-volume-mute' => 'volume mute' ),
					array( 'fal fa-volume-off' => 'volume off' ),
					array( 'fal fa-volume-slash' => 'volume slash' ),
					array( 'fal fa-volume-up' => 'volume up' ),
					array( 'fal fa-volume' => 'volume' ),
					array( 'fal fa-vote-nay' => 'vote nay' ),
					array( 'fal fa-vote-yea' => 'vote yea' ),
					array( 'fal fa-vr-cardboard' => 'vr cardboard' ),
					array( 'fal fa-wagon-covered' => 'wagon covered' ),
					array( 'fal fa-walker' => 'walker' ),
					array( 'fal fa-walkie-talkie' => 'walkie talkie' ),
					array( 'fal fa-walking' => 'walking' ),
					array( 'fal fa-wallet' => 'wallet' ),
					array( 'fal fa-wand-magic' => 'wand magic' ),
					array( 'fal fa-wand' => 'wand' ),
					array( 'fal fa-warehouse-alt' => 'warehouse alt' ),
					array( 'fal fa-warehouse' => 'warehouse' ),
					array( 'fal fa-washer' => 'washer' ),
					array( 'fal fa-watch-calculator' => 'watch calculator' ),
					array( 'fal fa-watch-fitness' => 'watch fitness' ),
					array( 'fal fa-watch' => 'watch' ),
					array( 'fal fa-water-lower' => 'water lower' ),
					array( 'fal fa-water-rise' => 'water rise' ),
					array( 'fal fa-water' => 'water' ),
					array( 'fal fa-wave-sine' => 'wave sine' ),
					array( 'fal fa-wave-square' => 'wave square' ),
					array( 'fal fa-wave-triangle' => 'wave triangle' ),
					array( 'fal fa-waveform-path' => 'waveform path' ),
					array( 'fal fa-waveform' => 'waveform' ),
					array( 'fal fa-webcam-slash' => 'webcam slash' ),
					array( 'fal fa-webcam' => 'webcam' ),
					array( 'fal fa-weight-hanging' => 'weight hanging' ),
					array( 'fal fa-weight' => 'weight' ),
					array( 'fal fa-whale' => 'whale' ),
					array( 'fal fa-wheat' => 'wheat' ),
					array( 'fal fa-wheelchair' => 'wheelchair' ),
					array( 'fal fa-whistle' => 'whistle' ),
					array( 'fal fa-wifi-1' => 'wifi 1' ),
					array( 'fal fa-wifi-2' => 'wifi 2' ),
					array( 'fal fa-wifi-slash' => 'wifi slash' ),
					array( 'fal fa-wifi' => 'wifi' ),
					array( 'fal fa-wind-turbine' => 'wind turbine' ),
					array( 'fal fa-wind-warning' => 'wind warning' ),
					array( 'fal fa-wind' => 'wind' ),
					array( 'fal fa-window-alt' => 'window alt' ),
					array( 'fal fa-window-close' => 'window close' ),
					array( 'fal fa-window-frame-open' => 'window frame open' ),
					array( 'fal fa-window-frame' => 'window frame' ),
					array( 'fal fa-window-maximize' => 'window maximize' ),
					array( 'fal fa-window-minimize' => 'window minimize' ),
					array( 'fal fa-window-restore' => 'window restore' ),
					array( 'fal fa-window' => 'window' ),
					array( 'fal fa-windsock' => 'windsock' ),
					array( 'fal fa-wine-bottle' => 'wine bottle' ),
					array( 'fal fa-wine-glass-alt' => 'wine glass alt' ),
					array( 'fal fa-wine-glass' => 'wine glass' ),
					array( 'fal fa-won-sign' => 'won sign' ),
					array( 'fal fa-wreath' => 'wreath' ),
					array( 'fal fa-wrench' => 'wrench' ),
					array( 'fal fa-x-ray' => 'x ray' ),
					array( 'fal fa-yen-sign' => 'yen sign' ),
					array( 'fal fa-yin-yang' => 'yin yang' ),
				),
			);

			return array_merge( $icons, $new_icons );
		}
	}

	new Brook_VC_Icon_FontAwesome5();
}
